<?php
/**
 * Lawyer Landing Page Pro Meta Box
 * 
 * @package Lawyer_Landing_Page_Pro
 */

 add_action('add_meta_boxes', 'lawyer_landing_page_pro_add_sidebar_layout_box');

function lawyer_landing_page_pro_add_sidebar_layout_box(){    
    
    $screens = array( 'post', 'page' );
    foreach ( $screens as $screen ){
        add_meta_box(
                 'lawyer_landing_page_pro_sidebar_layout', // $id
                 __( 'Sidebar Layout', 'lawyer-landing-page-pro' ), // $title
                 'lawyer_landing_page_pro_sidebar_layout_callback', // $callback
                 $screen, // $page
                 'normal', // $context
                 'high' // $priority
        );
    }
    
    // Meta box to add logo link for "Logo"
    add_meta_box(
                 'lawyer_landing_page_pro_logo_link', // $id
                 __( 'Logo Link', 'lawyer-landing-page-pro' ), // $title
                 'lawyer_landing_page_pro_logo_link_callback', // $callback
                 'logo', // $post_type
                 'normal', // $context
                 'low'// $priority
    );  
    
    // Meta box to add addition detials for "Team"
    add_meta_box(
                 'lawyer_landing_page_pro_team_details', // $id
                 __( 'Additional Details', 'lawyer-landing-page-pro' ), // $title
                 'lawyer_landing_page_pro_team_details_callback', // $callback
                 'team', // $post_type
                 'normal', // $context
                 'high'// $priority
    ); 
}

$lawyer_landing_page_pro_sidebar_layout = array(         
    'default-sidebar' => array(
                            'value' => 'default-sidebar',
                            'thumbnail' => get_template_directory_uri() . '/images/default-sidebar.png'
                        ),
    'left-sidebar' => array(
                            'value' => 'left-sidebar',
                            'thumbnail' => get_template_directory_uri() . '/images/left-sidebar.png'
                        ),
    'right-sidebar' => array(
                            'value' => 'right-sidebar',
                            'thumbnail' => get_template_directory_uri() . '/images/right-sidebar.png'
                        )
    );

function lawyer_landing_page_pro_sidebar_layout_callback(){
    
    global $post , $lawyer_landing_page_pro_sidebar_layout;
    wp_nonce_field( basename( __FILE__ ), 'lawyer_landing_page_pro_sidebar_layout_nonce' ); 
    
    $sidebars = lawyer_landing_page_pro_get_dynamnic_sidebar( true, true, true );
    $sidebar  = get_post_meta( $post->ID, '_lawyer_landing_page_pro_sidebar', true );
?>
<table class="form-table page-meta-box">
    <tr>
        <td colspan="4"><em class="f13"><?php _e( 'Choose Sidebar Template', 'lawyer-landing-page-pro' ); ?></em></td>
    </tr>

    <tr>
        <td>
        <?php  
            foreach( $lawyer_landing_page_pro_sidebar_layout as $field ){  
                $layout = get_post_meta( $post->ID, '_lawyer_landing_page_pro_sidebar_layout', true ); ?>

            <div class="hide-radio radio-image-wrapper" style="float:left; margin-right:30px;">
                <input id="<?php echo esc_attr( $field['value'] ); ?>" type="radio" name="lawyer_landing_page_pro_sidebar_layout" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'], $layout ); if( empty( $layout ) ){ checked( $field['value'], 'default-sidebar' ); }?>/>
                <label class="description" for="<?php echo esc_attr( $field['value'] ); ?>">
                    <img src="<?php echo esc_url( $field['thumbnail'] ); ?>" alt="<?php echo esc_attr( $field['value'] ); ?>" />
                </label>
            </div>
            <?php } // end foreach 
            ?>
            <div class="clear"></div>
        </td>
    </tr>
    
    <tr>
        <td colspan="3"><em class="f13"><?php esc_html_e('Choose Sidebar', 'lawyer-landing-page-pro'); ?></em></td>
    </tr>
    
    <tr>
        <td>
            <select name="lawyer_landing_page_pro_sidebar">
            <?php 
                foreach( $sidebars as $k => $v ){ ?>
                    <option value="<?php echo esc_attr( $k ); ?>" <?php selected( $sidebar, $k ); if( empty( $sidebar ) && $k == 'default-sidebar' ){ echo "selected='selected'";}?> ><?php echo esc_html( $v ); ?></option>
                <?php }
            ?>
            </select>
        </td>    
    </tr>
    
    <tr>
        <td><em class="f13"><?php printf( esc_html__( 'You can set up the sidebar content from %s', 'lawyer-landing-page-pro' ), '<a href="'. esc_url( admin_url( 'widgets.php' ) ) .'">here</a>' ); ?></em></td>
    </tr>
    
</table>
<?php        
}

/**
 * save the custom metabox data
 * @hooked to save_post hook
 */
function lawyer_landing_page_pro_save_sidebar_layout( $post_id ) { 
    
    global $lawyer_landing_page_pro_sidebar_layout, $post; 

    // Verify the nonce before proceeding.
    if ( !isset( $_POST[ 'lawyer_landing_page_pro_sidebar_layout_nonce' ] ) || !wp_verify_nonce( $_POST[ 'lawyer_landing_page_pro_sidebar_layout_nonce' ], basename( __FILE__ ) ) )
        return;

    // Stop WP from clearing custom fields on autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )  
        return;
        
    if ('page' == $_POST['post_type']) {  
        if ( !current_user_can( 'edit_page', $post_id ) )  
            return $post_id;  
    } elseif ( !current_user_can( 'edit_post', $post_id ) ) {  
            return $post_id;  
    }  
    
    // Make sure that it is set.
	if ( ! isset( $_POST['lawyer_landing_page_pro_sidebar'] ) ) {
		return;
	}
    
    foreach( $lawyer_landing_page_pro_sidebar_layout as $field ){  
        //Execute this saving function
        $old = get_post_meta( $post_id, '_lawyer_landing_page_pro_sidebar_layout', true ); 
        $new = sanitize_text_field( $_POST['lawyer_landing_page_pro_sidebar_layout'] );
        if ( $new && $new != $old ){  
            update_post_meta( $post_id, '_lawyer_landing_page_pro_sidebar_layout', $new );  
        } elseif( '' == $new && $old ){  
            delete_post_meta( $post_id, '_lawyer_landing_page_pro_sidebar_layout', $old );  
        } 
    } // end foreach
    
    // Sanitize user input.
	$sidebar = sanitize_text_field( $_POST['lawyer_landing_page_pro_sidebar'] );

	// Update the meta field in the database.
	update_post_meta( $post_id, '_lawyer_landing_page_pro_sidebar', $sidebar );   
}
add_action( 'save_post', 'lawyer_landing_page_pro_save_sidebar_layout' ); 

/**
 * Callback for Logo Link
*/
function lawyer_landing_page_pro_logo_link_callback(){
    global $post;
    wp_nonce_field( basename( __FILE__ ), 'lawyer_landing_page_pro_logo_link_nonce' );
    
    $link = get_post_meta( $post->ID, '_lawyer_landing_page_pro_logo_link', true );
    ?>
    <div>
        <div class="clearfix">
            <label class="bold-label float-left input_label" for="lawyer_landing_page_pro_logo_link"><?php _e( 'Link', 'lawyer-landing-page-pro' ); ?></label>
            <div class="below_row_input float-left"><input type="text" id="lawyer_landing_page_pro_logo_link" name="lawyer_landing_page_pro_logo_link" value="<?php echo esc_url( $link ); ?>" /></div>
        </div>
    </div>
    <?php    
}

function lawyer_landing_page_pro_save_logo_link( $post_id ){
    // Check if our nonce is set.
	if ( ! isset( $_POST['lawyer_landing_page_pro_logo_link_nonce'] ) || ! wp_verify_nonce( $_POST['lawyer_landing_page_pro_logo_link_nonce'], basename( __FILE__ ) ) ) {
		return;
	}

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) return;		
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) return;
	}
    
    if ( ! isset( $_POST['lawyer_landing_page_pro_logo_link'] ) ) {
		return;
	}
    
    // Sanitize user input.
	$link = esc_url_raw( $_POST['lawyer_landing_page_pro_logo_link'] );

	// Update the meta field in the database.
	update_post_meta( $post_id, '_lawyer_landing_page_pro_logo_link', $link );

}
add_action( 'save_post', 'lawyer_landing_page_pro_save_logo_link' );

/**
 * Callback for Additional Info for Team
*/
function lawyer_landing_page_pro_team_details_callback(){
    global $post;
    wp_nonce_field( basename( __FILE__ ), 'lawyer_landing_page_pro_team_details_nonce' );
    
    $practice = get_post_meta( $post->ID, '_lawyer_landing_page_pro_team_practice', true );
    ?>
        
    <div class="clearfix">
        <label class="bold-label float-left input_label" for="lawyer_landing_page_pro_team_practice"><?php _e( 'Area of Practice :', 'lawyer-landing-page-pro' ); ?></label>
        <div class="below_row_input float-left">
            <textarea id="lawyer_landing_page_pro_team_practice" name="lawyer_landing_page_pro_team_practice"><?php echo esc_textarea( $practice ); ?></textarea>
        </div>
    </div>
    <?php
}

function lawyer_landing_page_pro_save_team_details( $post_id ){
    // Check if our nonce is set.
	if ( ! isset( $_POST['lawyer_landing_page_pro_team_details_nonce'] ) || ! wp_verify_nonce( $_POST['lawyer_landing_page_pro_team_details_nonce'], basename( __FILE__ ) ) ) {
		return;
	}

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) return;		
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) return;
	}
    
    if ( ! isset( $_POST['lawyer_landing_page_pro_team_practice'] ) ) {
		return;
	}
    
    // Sanitize user input.
	$practice = sanitize_textarea_field( $_POST['lawyer_landing_page_pro_team_practice'] );
    
	// Update the meta field in the database.
	update_post_meta( $post_id, '_lawyer_landing_page_pro_team_practice', $practice );
    
}
add_action( 'save_post', 'lawyer_landing_page_pro_save_team_details' );