<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * @package Lawyer_Landing_Page_Pro
 */

/**
 * Show/Hide Admin Bar in frontend.
*/
if( ! get_theme_mod( 'ed_adminbar', '1' ) ) add_filter( 'show_admin_bar', '__return_false' );

if ( ! function_exists( 'lawyer_landing_page_pro_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function lawyer_landing_page_pro_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Lawyer Landing Page, use a find and replace
	 * to change 'lawyer-landing-page-pro' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'lawyer-landing-page-pro', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary'   => esc_html__( 'Primary', 'lawyer-landing-page-pro' ),
        'secondary' => esc_html__( 'Secondary', 'lawyer-landing-page-pro' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-list',
		'gallery',
		'caption',
	) );

    add_theme_support( 'post-formats', array( 'aside', 'status' ) );

	// Custom Image Size
    add_image_size( 'lawyer-landing-page-banner', 1914, 719, true );
    add_image_size( 'lawyer-landing-page-contact', 1914, 380, true );
    add_image_size( 'lawyer-landing-page-about', 456, 268, true );
    add_image_size( 'lawyer-landing-page-team', 261, 264, true );
    add_image_size( 'lawyer-landing-page-blog', 361, 250, true );
    add_image_size( 'lawyer-landing-page-without-sidebar', 1170, 464, true );
    add_image_size( 'lawyer-landing-page-portfolio', 360, 365, true );
    add_image_size( 'lawyer-landing-page-about-intro', 438, 340, true );
    add_image_size( 'lawyer-landing-page-single-team', 750, 430, true );
    add_image_size( 'lawyer-landing-page-schema', 600, 60, true );
    
    /** Custom Logo */
    add_theme_support( 'custom-logo', array(    	
    	'header-text' => array( 'site-title', 'site-description' ),
    ) );


}
endif;
add_action( 'after_setup_theme', 'lawyer_landing_page_pro_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function lawyer_landing_page_pro_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'lawyer_landing_page_pro_content_width', 830 );
}
add_action( 'after_setup_theme', 'lawyer_landing_page_pro_content_width', 0 );

/**
* Adjust content_width value according to template.
*
* @return void
*/
function lawyer_landing_page_pro_template_redirect_content_width() {
    // Full Width in the absence of sidebar.
	$sidebar = lawyer_landing_page_pro_sidebar( true );
    if( $sidebar ){
	   $GLOBALS['content_width'] = 830;
	}elseif ( ! ( is_active_sidebar( 'right-sidebar' ) ) ) {
	   $GLOBALS['content_width'] = 1170;
	}

}
add_action( 'template_redirect', 'lawyer_landing_page_pro_template_redirect_content_width' );

if( ! function_exists( 'lawyer_landing_page_pro_scripts' ) ) :
/**
 * Enqueue scripts and styles.
 */
function lawyer_landing_page_pro_scripts(){
		
    $map_api = get_theme_mod( 'map_api' );
    $key     = $map_api ? '?key='.esc_attr( $map_api ) : '' ;        
    $build  = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '/build' : '';
    $suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

   
	wp_enqueue_style( 'meanmenu', get_template_directory_uri(). '/css' . $build . '/meanmenu' . $suffix . '.css' );

	wp_enqueue_style( 'jquery-sidr-light', get_template_directory_uri(). '/css/' . $build . 'jquery.sidr.light' . $suffix . '.css' );

    wp_enqueue_style( 'jquery-mCustomScrollbar', get_template_directory_uri(). '/css' . $build . '/jquery.mCustomScrollbar' . $suffix . '.css' );
	wp_enqueue_style( 'lawyer-landing-page-pro', get_stylesheet_uri(), array(), LAWYER_LANDING_PAGE_PRO_THEME_VERSION );
    
    if( is_woocommerce_activated() )
    wp_enqueue_style( 'lawyer-landing-page-pro-worcommerce', get_template_directory_uri(). '/css' . $build . '/woocommerce' . $suffix . '.css', array( 'lawyer-landing-page-pro' ), LAWYER_LANDING_PAGE_PRO_THEME_VERSION );
    
    

    //Fancy Box
    if( get_theme_mod( 'ed_lightbox') ){
        wp_enqueue_style( 'jquery-fancybox', get_template_directory_uri() . '/js/fancybox/jquery.fancybox.css', '', '2.1.5' );
        wp_enqueue_script( 'jquery-fancybox-pack', get_template_directory_uri() . '/js/fancybox/jquery.fancybox.pack.js', array('jquery'), '2.1.5', true );
    }

    if( is_front_page() || is_post_type_archive( 'portfolio' ) ){

        wp_enqueue_script( 'masonry' );

        wp_enqueue_script( 'isotope-pkgd', get_template_directory_uri() . '/js' . $build . '/isotope.pkgd' . $suffix . '.js', array('jquery'), '3.0.1', true );
    }

    if( get_theme_mod( 'ed_lazy_load', false ) || get_theme_mod( 'ed_lazy_load_cimage', false ) ) {

        wp_enqueue_script( 'layzr', get_template_directory_uri() . '/js' . $build . '/layzr' . $suffix . '.js', array('jquery'), '2.0.4', true );
    }

    if( is_front_page() || is_page_template( 'templates/template-about.php' ) ){

        wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/css' . $build . '/owl.carousel' . $suffix . '.css', '', '2.2.1' );

        wp_enqueue_style( 'owl-theme-default', get_template_directory_uri() . '/css' . $build . '/owl.theme.default' . $suffix . '.css', '', '2.2.1' );

        wp_enqueue_style( 'animate', get_template_directory_uri() . '/css' . $build . '/animate' . $suffix . '.css', '', LAWYER_LANDING_PAGE_PRO_THEME_VERSION );

        wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js' . $build . '/owl.carousel' . $suffix . '.js', array('jquery'), '2.2.1', true );
    }

    if( ( is_front_page() && ! is_home() ) || is_page_template( 'templates/template-contact.php' ) ){
        
    wp_enqueue_script( 'lawyer-landing-page-pro-googlemap', '//maps.googleapis.com/maps/api/js'.$key, array('jquery'), '3.0', false );
    }

     wp_enqueue_script( 'all', get_template_directory_uri() . '/js' . $build . '/all' . $suffix . '.js', array( 'jquery' ), '5.3.1', true );
     wp_enqueue_script( 'v4-shims', get_template_directory_uri() . '/js' . $build . '/v4-shims' . $suffix . '.js', array( 'jquery' ), '5.3.1', true ); 

    wp_enqueue_script( 'jquery-sidr', get_template_directory_uri() . '/js' . $build . '/jquery.sidr' . $suffix . '.js', array('jquery'), '2.2.1', true );

    wp_enqueue_script( 'scroll-nav', get_template_directory_uri() . '/js' . $build . '/scroll-nav' . $suffix . '.js', array('jquery'), '3.0.0', true );

    wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js' . $build . '/jquery.fitvids' . $suffix . '.js', array('jquery'), '1.1', true );

    wp_enqueue_script( 'equal-height', get_template_directory_uri() . '/js' . $build . '/equal-height' . $suffix . '.js', array('jquery'), '0.7.0', true );

    wp_enqueue_script( 'jquery-meanmenu', get_template_directory_uri() . '/js' . $build . '/jquery.meanmenu' . $suffix . '.js', array('jquery'), '2.0.8', true );

    wp_enqueue_script( 'jquery-mCustomScrollbar', get_template_directory_uri() . '/js' . $build . '/jquery.mCustomScrollbar' . $suffix . '.js', array('jquery'), '3.1.5', true );

    wp_enqueue_script( 'lawyer-landing-page-pro-custom', get_template_directory_uri() . '/js' . $build . '/custom' . $suffix . '.js', array('jquery'), LAWYER_LANDING_PAGE_PRO_THEME_VERSION, true );
	
    $slider_auto = get_theme_mod( 'slider_auto', '1' );
    $slider_loop = get_theme_mod( 'slider_loop', '1' );
    $slider_drag = get_theme_mod( 'slider_drag' );
    $animation   = get_theme_mod( 'slider_animation', 'hinge' );
    $header_layout  = get_theme_mod( 'header_layout', 'one' );
    $sticky_header  = get_theme_mod( 'ed_sticky_header' );
    
    $array = array(
		'lightbox'  => esc_attr( get_theme_mod( 'ed_lightbox') ),
        'auto'      => esc_attr( $slider_auto ),
		'loop'      => esc_attr( $slider_loop ),
        'drag'      => esc_attr( $slider_drag ),
        'animation' => esc_attr( $animation ),
        'hlayout'   => $header_layout,
        'sticky'    => $sticky_header,
        'url'       => admin_url( 'admin-ajax.php' ),
        'rtl'       => is_rtl(),
	);
    wp_localize_script( 'lawyer-landing-page-pro-custom', 'lawyer_landing_page_pro_data', $array );
    
    $pagination = get_theme_mod( 'pagination_type', 'default' );
    $loadmore   = get_theme_mod( 'load_more_label', __( 'Load More Posts', 'lawyer-landing-page-pro' ) );
    $loading    = get_theme_mod( 'loading_label', __( 'Loading...', 'lawyer-landing-page-pro' ) );
    $nomore     = get_theme_mod( 'nomore_post_label', __( 'No More Post', 'lawyer-landing-page-pro' ) );
    
    if( get_theme_mod( 'ed_ajax_search' ) || $pagination == 'load_more' || $pagination == 'infinite_scroll' ){
        
        // Add parameters for the JS
        global $wp_query;
        $max = $wp_query->max_num_pages;
        $paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
        
        wp_enqueue_script( 'lawyer-landing-page-pro-ajax', get_template_directory_uri() . '/js' . $build . '/ajax' . $suffix . '.js', array('jquery'), LAWYER_LANDING_PAGE_PRO_THEME_VERSION, true );
        
        wp_localize_script( 
            'lawyer-landing-page-pro-ajax', 
            'lawyer_landing_page_pro_ajax',
            array(
                'url'        => admin_url( 'admin-ajax.php' ),
                'startPage'  => $paged,
                'maxPages'   => $max,
                'nextLink'   => next_posts( $max, false ),
                'autoLoad'   => $pagination,
                'loadmore'   => $loadmore,
                'loading'    => $loading,
                'nomore'     => $nomore,
                'plugin_url' => plugins_url(),                
             )
        );
        
        if ( is_jetpack_activated( true ) ) {
            wp_enqueue_style( 'tiled-gallery', plugins_url() . '/jetpack/modules/tiled-gallery/tiled-gallery/tiled-gallery.css' );            
        }
    }
    
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
endif;
add_action( 'wp_enqueue_scripts', 'lawyer_landing_page_pro_scripts' );

if( ! function_exists( 'lawyer_landing_page_pro_admin_scripts' ) ) :
/**
 * Enqueue admin scripts and styles.
 */
function lawyer_landing_page_pro_admin_scripts($hook){
    global $post;
    if( $hook == 'post-new.php' || $hook == 'post.php' ){
    wp_enqueue_style( 'lawyer-landing-page-pro-admin-style', get_template_directory_uri() . '/inc/css/admin.css', array(), LAWYER_LANDING_PAGE_PRO_THEME_VERSION );
    wp_enqueue_script( 'lawyer-landing-page-pro-admin-js', get_template_directory_uri() . '/inc/js/admin.js', array('jquery'), LAWYER_LANDING_PAGE_PRO_THEME_VERSION, true );
    $array = array( 'post_type' => $post->post_type );
    wp_localize_script( 'lawyer-landing-page-pro-admin-js', 'llpp_admin', $array );
    }
}
endif;
add_action( 'admin_enqueue_scripts', 'lawyer_landing_page_pro_admin_scripts' );


/**
 * Customizer Scripts
*/
function lawyer_landing_page_pro_customizer_script(){
    wp_enqueue_style( 'lawyer-landing-page-pro-customizer-style', get_template_directory_uri() . '/inc/css/customizer.css', array(), LAWYER_LANDING_PAGE_PRO_THEME_VERSION );
    wp_enqueue_script( 'lawyer-landing-page-pro-customizer-js', get_template_directory_uri() . '/inc/js/customizer.js', array('jquery'), LAWYER_LANDING_PAGE_PRO_THEME_VERSION, true  );

    //localizing for templates in the customizer
      $contact_page_url  = lawyer_landing_page_pro_get_template_page_url( 'templates/template-contact.php', 'page' );
      $about_page_url    = lawyer_landing_page_pro_get_template_page_url( 'templates/template-about.php', 'page' );
      $frontpage_url     = get_home_url();
      $array = array(
          'front'          => $frontpage_url,
          'contact'        => $contact_page_url,
          'about'          => $about_page_url,
      );

      wp_localize_script( 'lawyer-landing-page-pro-customizer-js', 'llpp_customizer_data', $array );
}
add_action( 'customize_controls_enqueue_scripts', 'lawyer_landing_page_pro_customizer_script' );

/**
 * Enqueue google fonts
*/
function lawyer_landing_page_pro_scripts_styles() {
    wp_enqueue_style( 'lawyer-landing-page-pro-google-fonts', lawyer_landing_page_pro_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'lawyer_landing_page_pro_scripts_styles' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function lawyer_landing_page_pro_body_classes( $classes ) {
	
    $ed_banner  = get_theme_mod( 'ed_banner_section', 'static_banner' );
    $bg_color   = get_theme_mod( 'bg_color', '#ffffff' );
    $bg_image   = get_theme_mod( 'bg_image' );
    $bg_pattern = get_theme_mod( 'bg_pattern', 'nobg' );
    $bg         = get_theme_mod( 'body_bg', 'image' );
    
    // Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
    
    if( ! is_front_page() || $ed_banner == 'no_banner' ){
        $classes[] = 'no-banner';
    }
    
    // Adds a class for custom background Color
    if( $bg_color != '#ffffff' ){
        $classes[] = 'custom-background-color custom-background';
    }
    
    // Adds a class for custom background Color
    if( ( $bg == 'image' && $bg_image ) || (  $bg == 'pattern' && $bg_pattern != 'nobg' ) ){
        $classes[] = 'custom-background-image custom-background';
    }
    
    $classes[] = lawyer_landing_page_pro_sidebar( false, true );

	return $classes;
}
add_filter( 'body_class', 'lawyer_landing_page_pro_body_classes' );

if( ! function_exists( 'lawyer_landing_page_pro_post_classes' ) ) :
/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function lawyer_landing_page_pro_post_classes( $classes ) {
    
    $classes[] = 'latest_post';
    
    if( is_post_type_archive( array( 'portfolio', 'service', 'team' ) ) ){
        $classes[] = 'col';
    }
    
    if( is_post_type_archive( 'testimonial' ) ){
        $classes[] = 'testimonial-holder';
    }
    
    return $classes;
}
endif;
add_filter( 'post_class', 'lawyer_landing_page_pro_post_classes' );

/**
 * Flush out the transients used in lawyer_landing_page_pro_categorized_blog.
 */
function lawyer_landing_page_pro_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'lawyer_landing_page_pro_categories' );
}
add_action( 'edit_category', 'lawyer_landing_page_pro_category_transient_flusher' );
add_action( 'save_post',     'lawyer_landing_page_pro_category_transient_flusher' );

if( ! function_exists( 'lawyer_landing_page_pro_ajax_search' ) ) :
/**
 * AJAX Search results
 */ 
function lawyer_landing_page_pro_ajax_search() {
    $query = $_REQUEST['q']; // It goes through esc_sql() in WP_Query
    $search_query = new WP_Query( array( 's' => $query, 'posts_per_page' => 3, 'post_status' => 'publish' )); 
    $search_count = new WP_Query( array( 's' => $query, 'posts_per_page' => -1, 'post_status' => 'publish' ));
    $search_count = $search_count->post_count;
    if ( !empty( $query ) && $search_query->have_posts() ) : 
        
        echo '<ul class="ajax-search-results">';
        while ( $search_query->have_posts() ) : $search_query->the_post(); ?>
        <li><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></li>   
        <?php
        endwhile;
        echo '</ul>';
        
        echo '<div class="ajax-search-meta"><span class="results-count">'.$search_count.' '.__( 'Results', 'lawyer-landing-page-pro' ).'</span><a href="' . esc_url( get_search_link( $query ) ) . '" class="results-link">'.__( 'Show all results.', 'lawyer-landing-page-pro' ).'</a></div>';
    else:
        echo '<div class="no-results">'.__( 'No results found.', 'lawyer-landing-page-pro' ).'</div>';
    endif;
    
    wp_die(); // this is required to terminate immediately and return a proper response
}
endif;
if( get_theme_mod( 'ed_ajax_search' ) ) {
    add_action( 'wp_ajax_lawyer_landing_page_pro_search', 'lawyer_landing_page_pro_ajax_search' );
    add_action( 'wp_ajax_nopriv_lawyer_landing_page_pro_search', 'lawyer_landing_page_pro_ajax_search' );
}

if( ! function_exists( 'lawyer_landing_page_pro_custom_js' ) ) :
/**
 * Custom Script
*/
function lawyer_landing_page_pro_custom_js(){
    $custom_script = get_theme_mod( 'custom_script' );
    if( $custom_script ){
        echo '<script type="text/javascript">';
		echo wp_strip_all_tags( $custom_script );
		echo '</script>';
    }
}
endif;
add_action( 'wp_footer', 'lawyer_landing_page_pro_custom_js', 500 );

if ( ! function_exists( 'lawyer_landing_page_pro_excerpt_more' ) ) :
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... * 
 */
function lawyer_landing_page_pro_excerpt_more($more) {
	return is_admin() ? $more : ' &hellip; ';
}
endif;
add_filter( 'excerpt_more', 'lawyer_landing_page_pro_excerpt_more' );

if ( ! function_exists( 'lawyer_landing_page_pro_excerpt_length' ) ) :
/**
 * Changes the default 55 character in excerpt 
*/
function lawyer_landing_page_pro_excerpt_length( $length ) {
	return is_admin() ? $length : 40;    
}
endif;
add_filter( 'excerpt_length', 'lawyer_landing_page_pro_excerpt_length', 999 );

if( ! function_exists( 'lawyer_landing_page_pro_change_comment_form_default_fields' ) ) :
/**
 * Change Comment form default fields i.e. author, email & url.
 * https://blog.josemcastaneda.com/2016/08/08/copy-paste-hurting-theme/
*/
function lawyer_landing_page_pro_change_comment_form_default_fields( $fields ){
    
    // get the current commenter if available
    $commenter = wp_get_current_commenter();
 
    // core functionality
    $req = get_option( 'require_name_email' );
    $aria_req = ( $req ? " aria-required='true'" : '' );    
 
    // Change just the author field
    $fields['author'] = '<p class="comment-form-author"><input id="author" name="author" placeholder="' . esc_attr__( 'Name*', 'lawyer-landing-page-pro' ) . '" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';
    
    $fields['email'] = '<p class="comment-form-email"><input id="email" name="email" placeholder="' . esc_attr__( 'Email*', 'lawyer-landing-page-pro' ) . '" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';
    
    $fields['url'] = '<p class="comment-form-url"><input id="url" name="url" placeholder="' . esc_attr__( 'Website', 'lawyer-landing-page-pro' ) . '" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>'; 
    
    return $fields;
    
}
endif;
add_filter( 'comment_form_default_fields', 'lawyer_landing_page_pro_change_comment_form_default_fields' );

if( ! function_exists( 'lawyer_landing_page_pro_change_comment_form_defaults' ) ) :
/**
 * Change Comment Form defaults
 * https://blog.josemcastaneda.com/2016/08/08/copy-paste-hurting-theme/
*/
function lawyer_landing_page_pro_change_comment_form_defaults( $defaults ){
    
    $defaults['comment_field'] = '<p class="comment-form-comment"><label for="comment"></label><textarea id="comment" name="comment" placeholder="' . esc_attr__( 'Comment', 'lawyer-landing-page-pro' ) . '" cols="45" rows="8" aria-required="true"></textarea></p>';
    
    return $defaults;
    
}
endif;
add_filter( 'comment_form_defaults', 'lawyer_landing_page_pro_change_comment_form_defaults' );

if( ! function_exists( 'lawyer_landing_page_pro_logo_metabox' ) ) :
/**
 * Function that removes the default thumbnail and add custom thumbnail meta box 
 */
function lawyer_landing_page_pro_logo_metabox(){
   remove_meta_box( 'postimagediv', 'logo', 'side' );
   add_meta_box( 'postimagediv', __( 'Featured Image', 'lawyer-landing-page-pro' ), 'post_thumbnail_meta_box', 'logo', 'normal', 'high' );
}
endif;
add_action( 'do_meta_boxes', 'lawyer_landing_page_pro_logo_metabox' );

/**
 * Function to add excerpt field in pages
*/
function lawyer_landing_page_pro_excerpts_in_pages() {
     add_post_type_support( 'page', 'excerpt' );
}
add_action( 'init', 'lawyer_landing_page_pro_excerpts_in_pages' );

if( ! function_exists( 'lawyer_landing_page_pro_google_map' ) ) :
/**
 * Callback Function for Google Map 
*/
function lawyer_landing_page_pro_google_map(){
    if( ( is_front_page() && ! is_home() ) || is_page_template( 'templates/template-contact.php' ) ){
        
        $ed_google_map   = get_theme_mod( 'ed_google_map' );
        $ed_google_mapse = get_theme_mod( 'ed_google_map_section', '1' );
        $latitude        = get_theme_mod( 'latitude', 27.730511 );
        $longitude       = get_theme_mod( 'longitude', 85.3300588 );
        $map_height      = get_theme_mod( 'map_height', 380 );
        $map_zoom        = get_theme_mod( 'map_zoom', '17' );
        $map_type        = get_theme_mod( 'map_type', 'ROADMAP' );
        $map_scroll      = ( get_theme_mod( 'ed_map_scroll', '1' ) == 1 ) ? 'true' : 'false';
        $map_control     = ( get_theme_mod( 'ed_map_controls', '1' ) != 1 ) ? 'true' : 'false';
        $map_control_inv = ( get_theme_mod( 'ed_map_controls', '1' ) == 1 ) ? 'true' : 'false';
        $ed_map_marker   = get_theme_mod( 'ed_map_marker' );
        $marker_title    = get_theme_mod( 'marker_title' );
        
        if( $ed_google_map || $ed_google_mapse ){ ?>
        <style>
          #map {
            width: 100%;
            height: <?php echo $map_height; ?>px;
          }
        </style>
        <script type="text/javascript">
        
            var map;
            var myLatLng = {lat: <?php echo $latitude;?>, lng: <?php echo $longitude;?>};
            
            function initialize() {
                var mapOptions = {
                    zoom: <?php echo $map_zoom; ?>,
                    center: new google.maps.LatLng(<?php echo $latitude;?>, <?php echo $longitude;?> ),
                    mapTypeId: google.maps.MapTypeId.<?php echo $map_type; ?>,
                    scrollwheel: <?php echo $map_scroll ?>,
                    zoomControl: <?php echo $map_control_inv ?>,
                    zoomControlOptions: {
                        style: google.maps.ZoomControlStyle.SMALL
                    },
                    mapTypeControl: <?php echo $map_control_inv ?>,
                    mapTypeControlOptions: {
                        style: google.maps.MapTypeControlStyle.DROPDOWN_MENU
                    },
                    disableDefaultUI: <?php echo $map_control ?>,
                };
                map = new google.maps.Map(document.getElementById('map'), mapOptions);
                
                <?php if( $ed_map_marker ){ ?>
                var marker = new google.maps.Marker({
                  position: myLatLng,
                  map: map,
                  <?php if( $marker_title ) echo 'title: "' . esc_html( $marker_title ) . '"' ?>
                });
                <?php } ?>
                
            }
            google.maps.event.addDomListener(window, 'load', initialize); 
          
        </script>
    <?php }
    }    
}
endif;
add_action( 'wp_head', 'lawyer_landing_page_pro_google_map' );

if( ! function_exists( 'lawyer_landing_page_pro_exclude_cat' ) ) :
/**
 * Exclude post with Category from blog and archive page. 
*/
function lawyer_landing_page_pro_exclude_cat( $query ){
    $cat       = get_theme_mod( 'exclude_categories' );
    $faq_order = get_theme_mod( 'faq_order', 'date' );
    
    if( $cat && ! is_admin() && $query->is_main_query() ){
        $cat = array_diff( array_unique( $cat ), array('') );
        if( $query->is_home() || $query->is_archive() ) {
			$query->set( 'category__not_in', $cat );
		}
    }    
    
    if( ! is_admin() && is_archive( 'faq' ) && ( $faq_order == 'menu_order' ) ){
        $query->set( 'orderby', 'menu_order title' );
        $query->set( 'order', 'ASC' );
    }
}
endif;
add_filter( 'pre_get_posts', 'lawyer_landing_page_pro_exclude_cat' );

if( ! function_exists( 'lawyer_landing_page_pro_custom_category_widget' ) ) :
/** 
 * Exclude Categories from Category Widget 
*/ 
function lawyer_landing_page_pro_custom_category_widget( $arg ) {
	$cat = get_theme_mod( 'exclude_categories' );
    
    if( $cat ){
        $cat = array_diff( array_unique( $cat ), array('') );
        $arg["exclude"] = $cat;
    }
	return $arg;
}
endif;
add_filter( "widget_categories_args", "lawyer_landing_page_pro_custom_category_widget" );
add_filter( "widget_categories_dropdown_args", "lawyer_landing_page_pro_custom_category_widget" );

if( ! function_exists( 'lawyer_landing_page_pro_exclude_posts_from_recentPostWidget_by_cat' ) ) :
/**
 * Exclude post from recent post widget of excluded catergory
 * 
 * @link http://blog.grokdd.com/exclude-recent-posts-by-category/
*/
function lawyer_landing_page_pro_exclude_posts_from_recentPostWidget_by_cat( $arg ){
    
    $cat = get_theme_mod( 'exclude_categories' );
   
    if( $cat ){
        $cat = array_diff( array_unique( $cat ), array('') );
        $arg["category__not_in"] = $cat;
    }
    
    return $arg;   
}
endif;
add_filter( "widget_posts_args", "lawyer_landing_page_pro_exclude_posts_from_recentPostWidget_by_cat" );

if( ! function_exists( 'lawyer_landing_page_pro_setup_pages' ) ) :
/**
 * Setup Contact and About Us Page Programatically
*/
function lawyer_landing_page_pro_setup_pages(){
    
    $pages = array(
        'contact-us' => array( 
            'page_name'     => 'Contact Us',
            'page_template' => 'templates/template-contact.php'
        ),
        'about-us' => array( 
            'page_name'     => 'About Us',
            'page_template' => 'templates/template-about.php'
        )
    );
    
    foreach( $pages as $page => $val ){
        lawyer_landing_page_pro_create_post( $val['page_name'], $page, $val['page_template'] );
    }
    
}
endif;
add_filter( 'after_switch_theme', 'lawyer_landing_page_pro_setup_pages' );

if( ! function_exists( 'lawyer_landing_page_pro_get_the_archive_title' ) ) :
/**
 * Filter Archive Title
*/
function lawyer_landing_page_pro_get_the_archive_title( $title ){
    
    $faq_header         = get_theme_mod( 'faq_archive_title', __( 'Frequently Asked Questions', 'lawyer-landing-page-pro' ) );
    $portfolio_header   = get_theme_mod( 'portfolio_archive_title', __( 'Portfolios', 'lawyer-landing-page-pro' ) );
    $service_header     = get_theme_mod( 'service_archive_title', __( 'Services', 'lawyer-landing-page-pro' ) );
    $team_header        = get_theme_mod( 'team_archive_title', __( 'Meet The Team', 'lawyer-landing-page-pro' ) );
    $testimonail_header = get_theme_mod( 'testimonial_archive_title', __( 'What People are Saying', 'lawyer-landing-page-pro' ) );
    
    if( is_category() ){
        $title = single_cat_title( '', false );
    }elseif ( is_tag() ){
        $title = single_tag_title( '', false );
    }elseif( is_author() ){
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    }elseif ( is_year() ) {
        $title = get_the_date( __( 'Y', 'lawyer-landing-page-pro' ) );
    }elseif ( is_month() ) {
        $title = get_the_date( __( 'F Y', 'lawyer-landing-page-pro' ) );
    }elseif ( is_day() ) {
        $title = get_the_date( __( 'F j, Y', 'lawyer-landing-page-pro' ) );
    }elseif ( is_post_type_archive() ) {
        if( is_post_type_archive( 'service' ) ){
            $title = $service_header ? $service_header : post_type_archive_title( '', false );  
        }elseif( is_post_type_archive( 'faq' ) ){
            $title = $faq_header ? $faq_header : post_type_archive_title( '', false );
        }elseif( is_post_type_archive( 'portfolio' ) ){
            $title = $portfolio_header ? $portfolio_header : post_type_archive_title( '', false );
        }elseif( is_post_type_archive( 'team' ) ){
            $title = $team_header ? $team_header : post_type_archive_title( '', false );
        }elseif( is_post_type_archive( 'testimonial' ) ){
            $title = $testimonail_header ? $testimonail_header : post_type_archive_title( '', false );
        }else{
            $title = post_type_archive_title( '', false );
        }        
    } 
    
    return $title;
}
endif;
add_filter( 'get_the_archive_title', 'lawyer_landing_page_pro_get_the_archive_title' );

if( ! function_exists( 'lawyer_landing_page_pro_testimonail_archive') ):
/**
 * Ajax Callback for Testiminial content in home page.
*/
function lawyer_landing_page_pro_testimonail_archive(){
    $id = $_REQUEST['post_id']; // It goes through esc_sql() in WP_Query
    $qry = new WP_Query( array(    	
    	'post_type'   => 'testimonial',
    	'post_status' => 'publish',
        'p'           => $id
    ));
        
    if ( !empty( $id ) && $qry->have_posts() ) : 
        ob_start(); 
        while ( $qry->have_posts() ) : $qry->the_post(); ?>
        <div class="testimonial-holder">
    		<?php the_content(); ?>
	    </div>
        <?php
        endwhile;
        echo ob_get_clean();
    else : 
    
    ob_start(); ?>
        <div class="testimonial-holder">
    		<p>Amazing theme by its simplicity. Brillant and easy to run. Above all for a landing page we must create in a short time. Quick, efficient and meets your expectations. Very Satisfaied with their service.</p>
	    </div>
    <?php
    echo ob_get_clean();
    
    endif;
    
    wp_die(); // this is required to terminate immediately and return a proper response
}
endif;
add_action( 'wp_ajax_lawyer_landing_page_pro_testimonial', 'lawyer_landing_page_pro_testimonail_archive' );
add_action( 'wp_ajax_nopriv_lawyer_landing_page_pro_testimonial', 'lawyer_landing_page_pro_testimonail_archive' );

if( ! function_exists( 'lawyer_landing_page_pro_page_attribute_post' ) ):
/**
 * Add Page attribute in post for post ordering
*/
function lawyer_landing_page_pro_page_attribute_post(){
    add_post_type_support( 'faq', 'page-attributes' );    
    add_post_type_support( 'team', 'page-attributes' );
}
endif;
add_action( 'init', 'lawyer_landing_page_pro_page_attribute_post' );

if( ! function_exists( 'lawyer_landing_page_pro_columns_head' ) ) :
/**
 * Adds a `Featured Image` column header in the item list admin page.
 *
 * @param array $defaults
 * @return array
 */
function lawyer_landing_page_pro_columns_head( $defaults ){
	   
    if( get_post_type() === 'faq' ){
        $defaults['menu_order'] = __( 'Order', 'lawyer-landing-page-pro' );
    }
    if( get_post_type() === 'team' ){
        $defaults['team_order'] = __( 'Order', 'lawyer-landing-page-pro' );
    }
    
	return $defaults;
}
endif;
add_filter( 'manage_posts_columns', 'lawyer_landing_page_pro_columns_head' );

if( ! function_exists( 'lawyer_landing_page_pro_columns_content' ) ) :
/**
 * @param string $column_name The name of the column to display.
 * @param int $post_ID The ID of the current post.
 */
function lawyer_landing_page_pro_columns_content( $column_name, $post_ID ){
	global $post;
    
    if( $column_name == 'menu_order' ){
        echo $post->menu_order;
    }  
    if( $column_name == 'team_order' ){
        echo $post->menu_order;
    } 
}
endif;
add_action( 'manage_posts_custom_column', 'lawyer_landing_page_pro_columns_content', 10, 2 );

if( ! function_exists( 'lawyer_landing_page_pro_order_column_sortable' ) ) :
/**
* make column sortable
*/
function lawyer_landing_page_pro_order_column_sortable( $columns ){
    $columns['menu_order'] = 'menu_order';
    return $columns;
}
endif;
add_filter( 'manage_edit-faq_sortable_columns', 'lawyer_landing_page_pro_order_column_sortable' );

if( ! function_exists( 'lawyer_landing_page_pro_team_order_column_sortable' ) ) :
    /**
    * make column sortable
    */
    function lawyer_landing_page_pro_team_order_column_sortable( $columns ){
        $columns['team_order'] = 'menu_order';
        return $columns;
    }
endif;
add_filter( 'manage_edit-team_sortable_columns', 'lawyer_landing_page_pro_team_order_column_sortable' );



if( ! function_exists( 'lawyer_landing_page_pro_og_header' ) ) :
/**
 * Add og meta tags in header for social sharing
*/
function lawyer_landing_page_pro_og_header() {
    if( is_single() ){
        global $post;
        
        $post_thumbnail_id = get_post_thumbnail_id( $post->ID );
        if( $post_thumbnail_id ){
            $featured_image = wp_get_attachment_image_url( $post_thumbnail_id, 'lawyer-landing-page-portfolio' );
        }
        
        if( has_excerpt( $post->ID ) ){
            $description = $post->post_excerpt;
        }
        else {
            $description = lawyer_landing_page_pro_truncate( $post->post_content, 250 );
        }
    
        if( $post_thumbnail_id && $featured_image && $description ){ ?>
            <meta property="og:url"         content="<?php echo esc_url( get_permalink( $post->ID ) ); ?>" />
            <meta property="og:type"        content="article" />
            <meta property="og:title"       content="<?php echo esc_html( $post->post_title )?>" />
            <meta property="og:description" content="<?php echo esc_html( $description ); ?>" />
            <meta property="og:image"       content="<?php echo esc_url( $featured_image ); ?>" />
        <?php
        }
    }
}
endif;
add_action( 'wp_head', 'lawyer_landing_page_pro_og_header' );

if( ! function_exists( 'lawyer_landing_page_pro_single_post_schema' ) ) :
/**
 * Single Post Schema
 *
 * @return string
 */
function lawyer_landing_page_pro_single_post_schema() {
    if ( is_singular( 'post' ) ) {
        global $post;
        $custom_logo_id = get_theme_mod( 'custom_logo' );

        $site_logo   = wp_get_attachment_image_src( $custom_logo_id , 'lawyer-landing-page-pro-schema' );
        $images      = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
        $excerpt     = lawyer_landing_page_pro_escape_text_tags( $post->post_excerpt );
        $content     = $excerpt === "" ? mb_substr( lawyer_landing_page_pro_escape_text_tags( $post->post_content ), 0, 110 ) : $excerpt;
        $schema_type = ! empty( $custom_logo_id ) && has_post_thumbnail( $post->ID ) ? "BlogPosting" : "Blog";

        $args = array(
            "@context"  => "http://schema.org",
            "@type"     => $schema_type,
            "mainEntityOfPage" => array(
                "@type" => "WebPage",
                "@id"   => get_permalink( $post->ID )
            ),
            "headline"  => get_the_title( $post->ID ),
            "image"     => array(
                "@type"  => "ImageObject",
                "url"    => $images[0],
                "width"  => $images[1],
                "height" => $images[2]
            ),
            "datePublished" => get_the_time( DATE_ISO8601, $post->ID ),
            "dateModified"  => get_post_modified_time(  DATE_ISO8601, __return_false(), $post->ID ),
            "author"        => array(
                "@type"     => "Person",
                "name"      => lawyer_landing_page_pro_escape_text_tags( get_the_author_meta( 'display_name', $post->post_author ) )
            ),
            "publisher" => array(
                "@type"       => "Organization",
                "name"        => get_bloginfo( 'name' ),
                "description" => get_bloginfo( 'description' ),
                "logo"        => array(
                    "@type"   => "ImageObject",
                    "url"     => $site_logo[0],
                    "width"   => $site_logo[1],
                    "height"  => $site_logo[2]
                )
            ),
            "description" => ( class_exists('WPSEO_Meta') ? WPSEO_Meta::get_value( 'metadesc' ) : $content )
        );

        if ( has_post_thumbnail( $post->ID ) ) :
            $args['image'] = array(
                "@type"  => "ImageObject",
                "url"    => $images[0],
                "width"  => $images[1],
                "height" => $images[2]
            );
        endif;

        if ( ! empty( $custom_logo_id ) ) :
            $args['publisher'] = array(
                "@type"       => "Organization",
                "name"        => get_bloginfo( 'name' ),
                "description" => get_bloginfo( 'description' ),
                "logo"        => array(
                    "@type"   => "ImageObject",
                    "url"     => $site_logo[0],
                    "width"   => $site_logo[1],
                    "height"  => $site_logo[2]
                )
            );
        endif;

        echo '<script type="application/ld+json">' , PHP_EOL;
        if ( version_compare( PHP_VERSION, '5.4.0' , '>=' ) ) {
            echo wp_json_encode( $args, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES | JSON_PRETTY_PRINT ) , PHP_EOL;
        } else {
            echo wp_json_encode( $args ) , PHP_EOL;
        }
        echo '</script>' , PHP_EOL;
    }
}
endif;
add_action( 'wp_head', 'lawyer_landing_page_pro_single_post_schema' );