<?php
/**
 * Lawyer Landing Page Theme Customizer.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_modify_sections( $wp_customize ){

	if ( version_compare( get_bloginfo('version'),'4.9', '>=') ) {
		$wp_customize->get_section( 'static_front_page' )->title = __( 'Static Front Page', 'lawyer-landing-page-pro' );
	}

}
add_action( 'customize_register', 'lawyer_landing_page_pro_modify_sections' );


$lawyer_landing_page_pro_panels       = array( 'header','home', 'about', 'typography', 'general', 'custom' );
$lawyer_landing_page_pro_sections     = array( 'info', 'post-page', 'footer', 'sidebar', 'styling', 'contact', 'performance' );
$lawyer_landing_page_pro_sub_sections = array(
    'header'     => array( 'layout', 'misc', 'archive' ),
    'home'       => array( 'banner','about', 'practice', 'why', 'service', 'stat', 'portfolio', 'testimonial', 'promotional', 'team', 'faq', 'blog', 'client', 'contact', 'sort' ),
    'about'      => array( 'intro', 'stat', 'service', 'practice', 'video', 'client', 'sort' ),    
    'typography' => array( 'body', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
    'general'    => array( 'basic', 'breadcrumb', 'post-meta', 'share', 'google' ),
);

foreach( $lawyer_landing_page_pro_sections as $s ){
    require get_template_directory() . '/inc/customizer/sections/' . $s . '.php';
}

foreach( $lawyer_landing_page_pro_panels as $p ){
   require get_template_directory() . '/inc/customizer/panels/' . $p . '.php';
}

foreach( $lawyer_landing_page_pro_sub_sections as $k => $v ){
    foreach( $v as $w ){        
        require get_template_directory() . '/inc/customizer/panels/' . $k . '/' . $w . '.php';
    }
}

/**
 * Sanitization Functions
*/
require get_template_directory() . '/inc/customizer/sanitization-functions.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function lawyer_landing_page_pro_customize_preview_js() {
	$build  = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '/build' : '';
    $suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';
	wp_enqueue_script( 'lawyer_landing_page_pro_customizer', get_template_directory_uri() . '/js' . $build . '/customizer' . $suffix . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'lawyer_landing_page_pro_customize_preview_js' );

/**
 * Filter for rara repeater conrol labels.
*/
add_filter( 'rara/rara-repeater/l10n', 'lawyer_landing_page_pro_rara_repeater_string' );
function lawyer_landing_page_pro_rara_repeater_string(){
    return $translation_strings = array(
			'no-image-selected' => __( 'No image selected', 'lawyer-landing-page-pro' ),
			'remove'            => __( 'Remove', 'lawyer-landing-page-pro' ),            
            'select-image'      => __( 'Select Image', 'lawyer-landing-page-pro' ),			
            'select-category'   => __( 'Select Category', 'lawyer-landing-page-pro' ),            
			'latest-posts'      => __( 'Latest Posts', 'lawyer-landing-page-pro' ),
			'delete'            => __( 'Delete', 'lawyer-landing-page-pro' ),
			'close'             => __( 'Close', 'lawyer-landing-page-pro' ),			
		);
}

/**
 * Filter for Repeater control labels.
*/
add_filter( 'rara/repeater/l10n', 'lawyer_landing_page_pro_repeater_strings' );
function lawyer_landing_page_pro_repeater_strings(){
    return $translation_strings = array(
			'row'               => esc_attr__( 'row', 'lawyer-landing-page-pro' ),
			'add-new'           => esc_attr__( 'Add new', 'lawyer-landing-page-pro' ),
			'select-page'       => esc_attr__( 'Select a Page', 'lawyer-landing-page-pro' ),
			'limit-rows'        => esc_attr__( 'Limit: %s rows', 'lawyer-landing-page-pro' ),
			'hex-value'         => esc_attr__( 'Hex Value', 'lawyer-landing-page-pro' ),
			'no-image-selected' => esc_attr__( 'No Image Selected', 'lawyer-landing-page-pro' ),
			'remove'            => esc_attr__( 'Remove', 'lawyer-landing-page-pro' ),
			'add-image'         => esc_attr__( 'Add Image', 'lawyer-landing-page-pro' ),
			'change-image'      => esc_attr__( 'Change Image', 'lawyer-landing-page-pro' ),
			'no-file-selected'  => esc_attr__( 'No File Selected', 'lawyer-landing-page-pro' ),
			'add-file'          => esc_attr__( 'Add File', 'lawyer-landing-page-pro' ),
			'change-file'       => esc_attr__( 'Change File', 'lawyer-landing-page-pro' ),
    );
}

/**
 * Filter for google font variants labels
*/
add_filter( 'rara-fonts/fonts/font_variants', 'lawyer_landing_page_pro_fonts_variants' );
function lawyer_landing_page_pro_fonts_variants(){
    return $font_variant = array(
			'100'       => esc_attr__( 'Ultra-Light 100', 'lawyer-landing-page-pro' ),
			'100italic' => esc_attr__( 'Ultra-Light 100 Italic', 'lawyer-landing-page-pro' ),
			'200'       => esc_attr__( 'Light 200', 'lawyer-landing-page-pro' ),
			'200italic' => esc_attr__( 'Light 200 Italic', 'lawyer-landing-page-pro' ),
			'300'       => esc_attr__( 'Book 300', 'lawyer-landing-page-pro' ),
			'300italic' => esc_attr__( 'Book 300 Italic', 'lawyer-landing-page-pro' ),
			'regular'   => esc_attr__( 'Normal 400', 'lawyer-landing-page-pro' ),
			'italic'    => esc_attr__( 'Normal 400 Italic', 'lawyer-landing-page-pro' ),
			'500'       => esc_attr__( 'Medium 500', 'lawyer-landing-page-pro' ),
			'500italic' => esc_attr__( 'Medium 500 Italic', 'lawyer-landing-page-pro' ),
			'600'       => esc_attr__( 'Semi-Bold 600', 'lawyer-landing-page-pro' ),
			'600italic' => esc_attr__( 'Semi-Bold 600 Italic', 'lawyer-landing-page-pro' ),
			'700'       => esc_attr__( 'Bold 700', 'lawyer-landing-page-pro' ),
			'700italic' => esc_attr__( 'Bold 700 Italic', 'lawyer-landing-page-pro' ),
			'800'       => esc_attr__( 'Extra-Bold 800', 'lawyer-landing-page-pro' ),
			'800italic' => esc_attr__( 'Extra-Bold 800 Italic', 'lawyer-landing-page-pro' ),
			'900'       => esc_attr__( 'Ultra-Bold 900', 'lawyer-landing-page-pro' ),
			'900italic' => esc_attr__( 'Ultra-Bold 900 Italic', 'lawyer-landing-page-pro' ),
		);
}

/**
 * Filter for standard font
*/
add_filter( 'rara-fonts/fonts/standard_fonts', 'lawyer_landing_page_pro_stantard_fonts' );
function lawyer_landing_page_pro_stantard_fonts(){
    return $standard_font = array(
		'serif'      => array(
			'label' => _x( 'Serif', 'font style', 'lawyer-landing-page-pro' ),
			'stack' => 'serif',
		),
		'sans-serif' => array(
			'label' => _x( 'Sans Serif', 'font style', 'lawyer-landing-page-pro' ),
			'stack' => 'sans-serif',
		),
		'monospace'  => array(
			'label' => _x( 'Monospace', 'font style', 'lawyer-landing-page-pro' ),
			'stack' => 'monospace',
		),
    );
}

/**
 * Filter for typography strings
*/
add_filter( 'rara-typography-control/il8n/strings', 'lawyer_landing_page_pro_typography_strings' );
function lawyer_landing_page_pro_typography_strings(){
    return $typo_string = array(
			'on'                 => esc_attr__( 'ON', 'lawyer-landing-page-pro' ),
			'off'                => esc_attr__( 'OFF', 'lawyer-landing-page-pro' ),
			'all'                => esc_attr__( 'All', 'lawyer-landing-page-pro' ),
			'cyrillic'           => esc_attr__( 'Cyrillic', 'lawyer-landing-page-pro' ),
			'cyrillic-ext'       => esc_attr__( 'Cyrillic Extended', 'lawyer-landing-page-pro' ),
			'devanagari'         => esc_attr__( 'Devanagari', 'lawyer-landing-page-pro' ),
			'greek'              => esc_attr__( 'Greek', 'lawyer-landing-page-pro' ),
			'greek-ext'          => esc_attr__( 'Greek Extended', 'lawyer-landing-page-pro' ),
			'khmer'              => esc_attr__( 'Khmer', 'lawyer-landing-page-pro' ),
			'latin'              => esc_attr__( 'Latin', 'lawyer-landing-page-pro' ),
			'latin-ext'          => esc_attr__( 'Latin Extended', 'lawyer-landing-page-pro' ),
			'vietnamese'         => esc_attr__( 'Vietnamese', 'lawyer-landing-page-pro' ),
			'hebrew'             => esc_attr__( 'Hebrew', 'lawyer-landing-page-pro' ),
			'arabic'             => esc_attr__( 'Arabic', 'lawyer-landing-page-pro' ),
			'bengali'            => esc_attr__( 'Bengali', 'lawyer-landing-page-pro' ),
			'gujarati'           => esc_attr__( 'Gujarati', 'lawyer-landing-page-pro' ),
			'tamil'              => esc_attr__( 'Tamil', 'lawyer-landing-page-pro' ),
			'telugu'             => esc_attr__( 'Telugu', 'lawyer-landing-page-pro' ),
			'thai'               => esc_attr__( 'Thai', 'lawyer-landing-page-pro' ),
			'serif'              => _x( 'Serif', 'font style', 'lawyer-landing-page-pro' ),
			'sans-serif'         => _x( 'Sans Serif', 'font style', 'lawyer-landing-page-pro' ),
			'monospace'          => _x( 'Monospace', 'font style', 'lawyer-landing-page-pro' ),
			'font-family'        => esc_attr__( 'Font Family', 'lawyer-landing-page-pro' ),
			'font-size'          => esc_attr__( 'Font Size', 'lawyer-landing-page-pro' ),
			'font-weight'        => esc_attr__( 'Font Weight', 'lawyer-landing-page-pro' ),
			'line-height'        => esc_attr__( 'Line Height', 'lawyer-landing-page-pro' ),
			'font-style'         => esc_attr__( 'Font Style', 'lawyer-landing-page-pro' ),
			'letter-spacing'     => esc_attr__( 'Letter Spacing', 'lawyer-landing-page-pro' ),
			'text-align'         => esc_attr__( 'Text Align', 'lawyer-landing-page-pro' ),
			'text-transform'     => esc_attr__( 'Text Transform', 'lawyer-landing-page-pro' ),
			'none'               => esc_attr__( 'None', 'lawyer-landing-page-pro' ),
			'uppercase'          => esc_attr__( 'Uppercase', 'lawyer-landing-page-pro' ),
			'lowercase'          => esc_attr__( 'Lowercase', 'lawyer-landing-page-pro' ),
			'top'                => esc_attr__( 'Top', 'lawyer-landing-page-pro' ),
			'bottom'             => esc_attr__( 'Bottom', 'lawyer-landing-page-pro' ),
			'left'               => esc_attr__( 'Left', 'lawyer-landing-page-pro' ),
			'right'              => esc_attr__( 'Right', 'lawyer-landing-page-pro' ),
			'center'             => esc_attr__( 'Center', 'lawyer-landing-page-pro' ),
			'justify'            => esc_attr__( 'Justify', 'lawyer-landing-page-pro' ),
			'color'              => esc_attr__( 'Color', 'lawyer-landing-page-pro' ),
			'select-font-family' => esc_attr__( 'Select a font-family', 'lawyer-landing-page-pro' ),
			'variant'            => esc_attr__( 'Variant', 'lawyer-landing-page-pro' ),
			'style'              => esc_attr__( 'Style', 'lawyer-landing-page-pro' ),
			'size'               => esc_attr__( 'Size', 'lawyer-landing-page-pro' ),
			'height'             => esc_attr__( 'Height', 'lawyer-landing-page-pro' ),
			'spacing'            => esc_attr__( 'Spacing', 'lawyer-landing-page-pro' ),
			'ultra-light'        => esc_attr__( 'Ultra-Light 100', 'lawyer-landing-page-pro' ),
			'ultra-light-italic' => esc_attr__( 'Ultra-Light 100 Italic', 'lawyer-landing-page-pro' ),
			'light'              => esc_attr__( 'Light 200', 'lawyer-landing-page-pro' ),
			'light-italic'       => esc_attr__( 'Light 200 Italic', 'lawyer-landing-page-pro' ),
			'book'               => esc_attr__( 'Book 300', 'lawyer-landing-page-pro' ),
			'book-italic'        => esc_attr__( 'Book 300 Italic', 'lawyer-landing-page-pro' ),
			'regular'            => esc_attr__( 'Normal 400', 'lawyer-landing-page-pro' ),
			'italic'             => esc_attr__( 'Normal 400 Italic', 'lawyer-landing-page-pro' ),
			'medium'             => esc_attr__( 'Medium 500', 'lawyer-landing-page-pro' ),
			'medium-italic'      => esc_attr__( 'Medium 500 Italic', 'lawyer-landing-page-pro' ),
			'semi-bold'          => esc_attr__( 'Semi-Bold 600', 'lawyer-landing-page-pro' ),
			'semi-bold-italic'   => esc_attr__( 'Semi-Bold 600 Italic', 'lawyer-landing-page-pro' ),
			'bold'               => esc_attr__( 'Bold 700', 'lawyer-landing-page-pro' ),
			'bold-italic'        => esc_attr__( 'Bold 700 Italic', 'lawyer-landing-page-pro' ),
			'extra-bold'         => esc_attr__( 'Extra-Bold 800', 'lawyer-landing-page-pro' ),
			'extra-bold-italic'  => esc_attr__( 'Extra-Bold 800 Italic', 'lawyer-landing-page-pro' ),
			'ultra-bold'         => esc_attr__( 'Ultra-Bold 900', 'lawyer-landing-page-pro' ),
			'ultra-bold-italic'  => esc_attr__( 'Ultra-Bold 900 Italic', 'lawyer-landing-page-pro' ),
			'invalid-value'      => esc_attr__( 'Invalid Value', 'lawyer-landing-page-pro' ),
		);
}