<?php
/**
 * Stat Counter Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_about_stat( $wp_customize ) {

    /** Stat Counter Section */
    $wp_customize->add_section(
        'about_stat_counter_settings',
        array(
            'title'    => __( 'Stats Counter Section', 'lawyer-landing-page-pro' ),
            'priority' => 20,
            'panel'    => 'about_page_settings',
        )
    );
    
    /** Background Image */
    $wp_customize->add_setting(
        'about_stat_counter_bg_image',
        array(
            'default'           => get_template_directory_uri() . '/images/demo/back.jpg',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_image',
        )
    );
    
    $wp_customize->add_control(
       new WP_Customize_Image_Control(
           $wp_customize,
           'about_stat_counter_bg_image',
           array(
               'label'       => __( 'Background Image', 'lawyer-landing-page-pro' ),
               'description' => __( 'Upload background image for stat counter section.', 'lawyer-landing-page-pro' ),
               'section'     => 'about_stat_counter_settings',               
           )
       )
    );
    
    /** Background Color*/
    $wp_customize->add_setting( 
        'about_stat_counter_color', array(
            'default'           => '#a2d1ed',
            'sanitize_callback' => 'sanitize_hex_color'
        ) 
    );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'about_stat_counter_color', 
            array(
                'label'       => __( 'Background Color', 'lawyer-landing-page-pro' ),
                'description' => __( 'Background Color will be applied if no background image is set.', 'lawyer-landing-page-pro' ),
                'section'     => 'about_stat_counter_settings',                
            )
        )
    );
    
    if( is_rara_toolkit_activated() ){
        $description = __( 'To add widgets in this section you have to install the Rara Theme Tool Kit Pro which you have received along with this theme.', 'lawyer-landing-page-pro' );    
    }else{
        $description = sprintf( __( 'To add widgets in this section you have to install the %1$sRara Theme Tool Kit Pro%2$s which you have received along with this theme.', 'lawyer-landing-page-pro' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' );       
    }
    
    /** Stat Counter Note */
    $wp_customize->add_setting(
		'about_stat_note',
		array(
			'sanitize_callback' => 'wp_kses_post'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Info_Text( 
			$wp_customize,
			'about_stat_note',
			array(
				'section'     => 'about_stat_counter_settings', 
                'label'       => __( 'NOTE:', 'lawyer-landing-page-pro' ),
                'description' => $description,
			)
		)
   );

    $wp_customize->add_setting(
        'about_counter_note',
        array(
            'sanitize_callback' => 'wp_kses_post'
        )
    );

    $wp_customize->add_control(
        new Rara_Controls_Info_Text( 
            $wp_customize,
            'about_counter_note',
            array(
                'section' => 'about_stat_counter_settings',
                'description' => sprintf( '<hr><b>%1$s</b>', __( 'Add RARA: Stat Counter Widget for about page counter widgets.', 'lawyer-landing-page-pro' ) ),
            )
        )
    );

    $stat_section = $wp_customize->get_section( 'sidebar-widgets-about-counter' );   
    if ( ! empty( $stat_section ) ) {
        $stat_section->panel     = 'about_page_settings';
        $stat_section->priority  = 20;
        $wp_customize->get_section( 'sidebar-widgets-about-counter' )->title = __( 'Stats Counter Section','lawyer-landing-page-pro' );
        $wp_customize->get_control( 'about_stat_counter_bg_image' )->section  = 'sidebar-widgets-about-counter';
        $wp_customize->get_control( 'about_stat_counter_bg_image' )->priority = -1;
        $wp_customize->get_control( 'about_stat_counter_color' )->section  = 'sidebar-widgets-about-counter';
        $wp_customize->get_control( 'about_stat_counter_color' )->priority = -1;
        $wp_customize->get_control( 'about_stat_note' )->section  = 'sidebar-widgets-about-counter';
        $wp_customize->get_control( 'about_stat_note' )->priority = -1;
        $wp_customize->get_control( 'about_counter_note' )->section  = 'sidebar-widgets-about-counter';
        $wp_customize->get_control( 'about_counter_note' )->priority = -1;
    }
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_about_stat' );