<?php
/**
 * Google Map Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_contact_google( $wp_customize ) {
    
    /** Zoom Level */
    $zoom = array();
    for($z = 1; $z < 20; $z++){
        $zoom[$z] = $z;    
    }
    
    /** Google Settings */
    $wp_customize->add_section(
        'google_map_settings',
        array(
            'title'    => __( 'Google Map Settings', 'lawyer-landing-page-pro' ),
            'priority' => 40,
            'panel'    => 'general_setting',
        )
    );
    
    /** Enable Scrolling Wheel */
    $wp_customize->add_setting(
        'ed_map_scroll',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_map_scroll',
			array(
				'section'	  => 'google_map_settings',
				'label'		  => __( 'Enable Scrolling Wheel', 'lawyer-landing-page-pro' ),
				'description' => __( 'Zoom map on Scrolling.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Enable Map Controls */
    $wp_customize->add_setting(
        'ed_map_controls',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_map_controls',
			array(
				'section'	  => 'google_map_settings',
				'label'		  => __( 'Enable Map Controls', 'lawyer-landing-page-pro' ),
				'description' => __( 'Controls icons that appears above Map.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Enable Map Marker */
    $wp_customize->add_setting(
        'ed_map_marker',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_map_marker',
			array(
				'section'	  => 'google_map_settings',
				'label'		  => __( 'Enable Map Marker', 'lawyer-landing-page-pro' ),
				'description' => __( 'Marker icons that appears above Map.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Marker Title  */
    $wp_customize->add_setting(
        'marker_title',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'marker_title',
        array(
            'label'       => __( 'Marker Title', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the Marker Title.', 'lawyer-landing-page-pro' ),
            'section'     => 'google_map_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_google_map_ac'                        
        )
    );
    
    /** Google Map API Key  */
    $wp_customize->add_setting(
        'map_api',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'map_api',
        array(
            'label'       => __( 'Google Map API Key', 'lawyer-landing-page-pro' ),
            'description' => sprintf( __( 'Enter the google map api key here. You can get API key from %1$shere.%2$s', 'lawyer-landing-page-pro' ), '<a href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank">', '</a>' ),
            'section'     => 'google_map_settings',
            'type'        => 'text',                        
        )
    );
    
    /** Latitude  */
    $wp_customize->add_setting(
        'latitude',
        array(
            'default'           => 27.730511,
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_number_floatval',
        )
    );
    
    $wp_customize->add_control(
        'latitude',
        array(
            'label'       => __( 'Latitude', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the Latitude of your location.', 'lawyer-landing-page-pro' ),
            'section'     => 'google_map_settings',
            'type'        => 'number',                        
        )
    );
    
    /** Longitude  */
    $wp_customize->add_setting(
        'longitude',
        array(
            'default'           => 85.3300588,
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_number_floatval',
        )
    );
    
    $wp_customize->add_control(
        'longitude',
        array(
            'label'       => __( 'Longitude', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the Longitude of your location.', 'lawyer-landing-page-pro' ),
            'section'     => 'google_map_settings',
            'type'        => 'number',                        
        )
    );
    
    /** Map Height  */
    $wp_customize->add_setting(
        'map_height',
        array(
            'default'           => 380,
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_number_absint',
        )
    );
    
    $wp_customize->add_control(
        'map_height',
        array(
            'label'       => __( 'Map Height', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the height of map, for example: 300.', 'lawyer-landing-page-pro' ),
            'section'     => 'google_map_settings',
            'type'        => 'number',                        
        )
    );
    
    /** Zoom Level */
    $wp_customize->add_setting(
		'map_zoom',
		array(
			'default'			=> '17',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'map_zoom',
    		array(
                'label'   => __( 'Zoom Level', 'lawyer-landing-page-pro' ),
                'section' => 'google_map_settings',            
    			'choices' => $zoom,
     		)
		)
	);
    
    /** Map Type */
    $wp_customize->add_setting(
		'map_type',
		array(
			'default'			=> 'TERRAIN',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'map_type',
    		array(
                'label'   => __( 'Map Type', 'lawyer-landing-page-pro' ),
                'section' => 'google_map_settings',            
    			'choices' => array(
                    'ROADMAP'   => __( 'ROADMAP', 'lawyer-landing-page-pro' ),
                    'SATELLITE' => __( 'SATELLITE', 'lawyer-landing-page-pro' ),
                    'HYBRID'    => __( 'HYBRID', 'lawyer-landing-page-pro' ),
                    'TERRAIN'   => __( 'TERRAIN', 'lawyer-landing-page-pro' )
                )
     		)
		)
	);
            
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_contact_google' );

/**
 * Active Callback for map marker
*/
function lawyer_landing_page_pro_google_map_ac( $control ){
    
    $ed_marker  = $control->manager->get_setting( 'ed_map_marker' )->value();
    
    if ( $ed_marker == true ) return true;
    
    return false;
}