<?php
/**
 * Header Miscellaneous Options
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_header_misc( $wp_customize ) {
    
    $wp_customize->add_section( 'header_misc_setting', array(
        'title'    => __( 'Misc Settings', 'lawyer-landing-page-pro' ),
        'priority' => 30,
        'panel'    => 'header_setting',
    ) );
    
    /** Section Menu */
    $wp_customize->add_setting(
        'ed_section_menu',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu',
			array(
				'section'	  => 'header_misc_setting',
				'label'		  => __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description' => __( 'Enable to make one page scrolling home page.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Enable/Disable Home Link */
    $wp_customize->add_setting(
        'ed_home_link',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_home_link',
			array(
				'section'	  => 'header_misc_setting',
				'label'		  => __( 'Home Link', 'lawyer-landing-page-pro' ),
				'description' => __( 'Enable to display "Home" link in section menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_header_ac'
			)
		)
	);
    
    /** Enable/Disable Sticky Header */
    $wp_customize->add_setting(
        'ed_sticky_header',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_sticky_header',
			array(
				'section'	  => 'header_misc_setting',
				'label'		  => __( 'Sticky Header', 'lawyer-landing-page-pro' ),
				'description' => __( 'Enable to make header sticky.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Enable/Disable Search Form */
    $wp_customize->add_setting(
        'ed_search',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_search',
			array(
				'section'	  => 'header_misc_setting',
				'label'		  => __( 'Search Form', 'lawyer-landing-page-pro' ),
				'description' => __( 'Enable to show search form in header.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Phone Label  */
    $wp_customize->add_setting(
        'phone_label',
        array(
            'default'           => __( 'Free Case Consultation', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'phone_label',
        array(
            'label'       => __( 'Phone Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'Add phone label in header. This label will not be visibile in header One, Three, Six and Seven.', 'lawyer-landing-page-pro' ),
            'section'     => 'header_misc_setting',
            'type'        => 'text',
        )
    );
    
    /** Phone Number  */
    $wp_customize->add_setting(
        'phone',
        array(
            'default'           => __( '(888) 123-45678', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'phone',
        array(
            'label'       => __( 'Phone Number', 'lawyer-landing-page-pro' ),
            'description' => __( 'Add phone no. in header.', 'lawyer-landing-page-pro' ),
            'section'     => 'header_misc_setting',
            'type'        => 'text',
        )
    );
    
    /** Quote Button Label  */
    $wp_customize->add_setting(
        'button_label',
        array(
            'default'           => __( 'Consultation Request', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'button_label',
        array(
            'label'       => __( 'Request Button Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'Add Request Button in header. This button will not be visible in header One and Six.', 'lawyer-landing-page-pro' ),
            'section'     => 'header_misc_setting',
            'type'        => 'text',
        )
    );
    
    /** Enable/Disable Search Form */
    $wp_customize->add_setting(
        'ed_internal_link',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_internal_link',
			array(
				'section'	  => 'header_misc_setting',
				'label'		  => __( 'Enable Request Button Internal Link.', 'lawyer-landing-page-pro' ),
				'description' => __( 'Enabling will display list of page/post to select.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Consultation Request Url  */
    $wp_customize->add_setting(
        'button_url',
        array(
            'default'           => __( '#', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    
    $wp_customize->add_control(
        'button_url',
        array(
            'label'       => __( 'Consultation Request Url', 'lawyer-landing-page-pro' ),
            'description' => __( 'Add button external url here.', 'lawyer-landing-page-pro' ),
            'section'     => 'header_misc_setting',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_button_ac'
        )
    );
    
    /** Button Post */
    $wp_customize->add_setting(
		'button_post',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'button_post',
    		array(
                'label'	      => __( 'Choose Post/Page', 'lawyer-landing-page-pro' ),
                'section'     => 'header_misc_setting',
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
                'active_callback' => 'lawyer_landing_page_pro_button_ac'	
     		)
		)
	);
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_header_misc' );

/**
 * Active Callback
*/
function lawyer_landing_page_pro_header_ac( $control ){
    
    $ed_sec_menu = $control->manager->get_setting( 'ed_section_menu' )->value();
    $control_id  = $control->id;
    
    if ( $control_id == 'ed_home_link' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'ed_menu_label' && $ed_sec_menu == true ) return true;    
    
    return false;
}

function lawyer_landing_page_pro_button_ac( $control ){
    $ed_ext_btn = $control->manager->get_setting( 'ed_internal_link' )->value();
    $control_id = $control->id;
    
    if ( $control_id == 'button_url' && $ed_ext_btn == false ) return true;
    if ( $control_id == 'button_post' && $ed_ext_btn == true ) return true;    
    
    return false;
}