<?php
/**
 * About Section Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_about( $wp_customize ) {

    /** about Section */
    $wp_customize->add_section(
        'about_settings',
        array(
            'title'    => __( 'About Section', 'lawyer-landing-page-pro' ),
            'priority' => 20,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_about',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_about',
			array(
				'section'		=> 'about_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_about',
        array(
            'default'           => __( 'About', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_about',
        array(
            'label'       => __( 'About Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'about_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** about page */
    $wp_customize->add_setting(
		'about_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'about_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description. If there is excerpt then excerpt will be displayed in place of description.', 'lawyer-landing-page-pro' ),
                'section'     => 'about_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    /** Select About Post */
    $wp_customize->add_setting(
		'about_post',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'about_post',
    		array(
                'label'       => __( 'Select About Post/Page', 'lawyer-landing-page-pro' ),
                'description' => __( 'You can add extra description about your company by selecting Post/Page here.', 'lawyer-landing-page-pro' ),
                'section'     => 'about_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    /** About Post/Page Excerpt Character */
    $wp_customize->add_setting( 'about_excerpt_char', array(
        'default'           => 500,
        'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Slider_Control( 
			$wp_customize,
			'about_excerpt_char',
			array(
				'section'		=> 'about_settings',
				'label'			=> __( 'About Post/Page Excerpt Character', 'lawyer-landing-page-pro' ),                
				'choices'		=> array(
					'min' 	=> 100,
					'max' 	=> 750,
					'step'	=> 10,
				)
			)
		)
	);
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_about' );

/**
 * Active Callback for display menu label in each home page section
*/
function lawyer_landing_page_pro_section_menu_ac( $control ){
    
    $control_id              = $control->id;
    $ed_sec_menu             = $control->manager->get_setting( 'ed_section_menu' )->value();
    $ed_sec_menu_about       = $control->manager->get_setting( 'ed_section_menu_about' )->value();
    $ed_sec_menu_practice    = $control->manager->get_setting( 'ed_section_menu_practice' )->value();
    $ed_sec_menu_whyus       = $control->manager->get_setting( 'ed_section_menu_whyus' )->value();
    $ed_sec_menu_service     = $control->manager->get_setting( 'ed_section_menu_service' )->value();
    $ed_sec_menu_portfolio   = $control->manager->get_setting( 'ed_section_menu_portfolio' )->value();
    $ed_sec_menu_testimonial = $control->manager->get_setting( 'ed_section_menu_testimonial' )->value();
    $ed_sec_menu_team        = $control->manager->get_setting( 'ed_section_menu_team' )->value();
    $ed_sec_menu_faq         = $control->manager->get_setting( 'ed_section_menu_faq' )->value();
    $ed_sec_menu_blog        = $control->manager->get_setting( 'ed_section_menu_blog' )->value();
    $ed_sec_menu_client      = $control->manager->get_setting( 'ed_section_menu_client' )->value();
    $ed_sec_menu_contact     = $control->manager->get_setting( 'ed_section_menu_contact' )->value();
    
    if ( $control_id == 'ed_section_menu_about' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_about' && $ed_sec_menu == true && $ed_sec_menu_about == true ) return true;
    
    if ( $control_id == 'ed_section_menu_practice' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_practice' && $ed_sec_menu == true && $ed_sec_menu_practice == true ) return true;
    
    if ( $control_id == 'ed_section_menu_whyus' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_why_us' && $ed_sec_menu == true && $ed_sec_menu_whyus == true ) return true;
    
    if ( $control_id == 'ed_section_menu_service' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_service' && $ed_sec_menu == true && $ed_sec_menu_service == true ) return true;
    
    if ( $control_id == 'ed_section_menu_portfolio' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_portfolio' && $ed_sec_menu == true && $ed_sec_menu_portfolio == true ) return true;
    
    if ( $control_id == 'ed_section_menu_testimonial' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_testimonial' && $ed_sec_menu == true && $ed_sec_menu_testimonial == true ) return true;

    if ( $control_id == 'ed_section_menu_team' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_team' && $ed_sec_menu == true && $ed_sec_menu_team == true ) return true;

    if ( $control_id == 'ed_section_menu_faq' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_faq' && $ed_sec_menu == true && $ed_sec_menu_faq == true ) return true;

    if ( $control_id == 'ed_section_menu_blog' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_blog' && $ed_sec_menu == true && $ed_sec_menu_blog == true ) return true;

    if ( $control_id == 'ed_section_menu_client' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_client' && $ed_sec_menu == true && $ed_sec_menu_client == true ) return true;
    
    if ( $control_id == 'ed_section_menu_contact' && $ed_sec_menu == true ) return true;
    if ( $control_id == 'section_menu_contact' && $ed_sec_menu == true && $ed_sec_menu_contact == true ) return true;
    
    return false;
}