<?php
/**
 * Banner Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_banner( $wp_customize ) {

    $wp_customize->add_section( 'banner_section_settings', array(
        'title'      => __( 'Banner/Slider Settings', 'lawyer-landing-page-pro' ),
        'priority'   => 10,
        'panel'      => 'home_page_settings',
    ) );

    $wp_customize->add_setting(
		'ed_banner_section',
		array(
			'default'			=> 'static_banner',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'ed_banner_section',
    		array(
                'label'	      => __( 'Banner Options', 'lawyer-landing-page-pro' ),
                'description' => __( 'Choose banner as static image with form or as a slider.', 'lawyer-landing-page-pro' ),
    			'section'     => 'banner_section_settings',
    			'choices'     => array(
                    'no_banner'     => __( 'Disable Banner Section', 'lawyer-landing-page-pro' ),
                    'static_banner' => __( 'Static Banner with Form', 'lawyer-landing-page-pro' ),
                    'slider_banner' => __( 'Banner as Slider', 'lawyer-landing-page-pro' ),
                ),	
     		)
		)
	);

	/** Banner Section Note */ 
    $wp_customize->add_setting(
		'banner_note',
		array(
			'sanitize_callback' => 'wp_kses_post'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Info_Text( 
			$wp_customize,
			'banner_note',
			array(
				'section' => 'banner_section_settings',
				'label'   => __( 'Banner Section', 'lawyer-landing-page-pro' ),
                'description' => __( 'The featured image and content of Static Front Page will be displayed in the banner section. To add or edit the content of Static Front Page, go to Dashboard >> Pages > All Pages and edit the page that is set as static Front Page.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
    
    /** Drop Down of CF7 only if plugin enabled */
    if( is_cf7_activated() ){
        
        /** Banner Form */
        $wp_customize->add_setting(
    		'banner_form',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
        
        $wp_customize->add_control(
            'banner_form',
            array(
                'label'       => __( 'Banner Form', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enter the Contact Form 7 Shortcode. Ex. [contact-form-7 id="186" title="Google contact"]', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
                'type'        => 'text',
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
            )
        );
        
    }else{
        
        $wp_customize->add_setting(
    		'form_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Info_Text( 
    			$wp_customize,
    			'form_note',
    			array(
    				'section' => 'banner_section_settings', 
                    'label'       => __( 'Banner Form', 'lawyer-landing-page-pro' ),   				
                    'description' => __( 'Please install Contact Form 7 Plugin to show form in banner.', 'lawyer-landing-page-pro' ),
                    'active_callback' => 'lawyer_landing_page_pro_banner_ac'
    			)
    		)
	   );
        
    }

	/*************
    Slider Functionality
    *************/

    /** Select Category */
    $wp_customize->add_setting(
		'slider_type',
		array(
			'default'			=> 'post',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_type',
    		array(
                'label'	      => __( 'Choose Slider Type', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => array(
                    'post'   => __( 'Post/Page', 'lawyer-landing-page-pro' ),
                    'cat'    => __( 'Category', 'lawyer-landing-page-pro' ),
                    'custom' => __( 'Custom', 'lawyer-landing-page-pro' ),
                ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'                	
     		)
		)
	);
    
    /** Select Post One */
    $wp_customize->add_setting(
		'slider_post_one',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_post_one',
    		array(
                'label'	      => __( 'Choose Post One', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'	
     		)
		)
	);
    
    /** Select Post Two */
    $wp_customize->add_setting(
		'slider_post_two',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_post_two',
    		array(
                'label'	      => __( 'Choose Post Two', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'	
     		)
		)
	);
    
    /** Select Post Three */
    $wp_customize->add_setting(
		'slider_post_three',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_post_three',
    		array(
                'label'	      => __( 'Choose Post Three', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'	
     		)
		)
	);
    
    /** Select Post Four */
    $wp_customize->add_setting(
		'slider_post_four',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_post_four',
    		array(
                'label'	      => __( 'Choose Post Four', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'	
     		)
		)
	);
    
    /** Select Post Five */
    $wp_customize->add_setting(
		'slider_post_five',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_post_five',
    		array(
                'label'	      => __( 'Choose Post Five', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'	
     		)
		)
	);
    
    /** Select Category */
    $wp_customize->add_setting(
		'slider_cat',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_cat',
    		array(
                'label'	      => __( 'Slider Category', 'lawyer-landing-page-pro' ),
                'description' => __( 'Choose slider category for banner.', 'lawyer-landing-page-pro' ),
    			'section'     => 'banner_section_settings',
    			'choices'     => lawyer_landing_page_pro_get_categories(),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'	
     		)
		)
	);
    
    /** Add Slides */
    $wp_customize->add_setting( 
        new Rara_Repeater_Setting( 
            $wp_customize, 
            'slider_custom', 
            array(
                'default' => '',                             
            ) 
        ) 
    );
    
    $wp_customize->add_control(
		new Rara_Control_Repeater(
			$wp_customize,
			'slider_custom',
			array(
				'section' => 'banner_section_settings',				
				'label'	  => __( 'Add Sliders', 'lawyer-landing-page-pro' ),
                'fields'  => array(
                    'thumbnail' => array(
                        'type'  => 'image', 
                        'label' => __( 'Add Image', 'lawyer-landing-page-pro' ),                
                    ),
                    'title'     => array(
                        'type'  => 'text',
                        'label' => __( 'Title', 'lawyer-landing-page-pro' ),
                    ),
                    'content'   => array(
                        'type'  => 'textarea',
                        'label' => __( 'Content', 'lawyer-landing-page-pro' ),
                    ),
                    'link'     => array(
                        'type'  => 'text',
                        'label' => __( 'Link', 'lawyer-landing-page-pro' ),
                    ),
                ),
                'row_label' => array(
                    'type'  => 'field',
                    'value' => __( 'Slide', 'lawyer-landing-page-pro' ),
                    'field' => 'title'
                ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'                                              
			)
		)
	);
    
    /** Read More Text */
    $wp_customize->add_setting(
        'slider_readmore',
        array(
            'default'           => __( 'Read More', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'slider_readmore',
        array(
            'label'       => __( 'Readmore Text', 'lawyer-landing-page-pro' ),
            'section'     => 'banner_section_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_banner_ac'
        )
    );

    /**************
	Slider Controls
    *************/
    /** Banner Section Note */ 
    $wp_customize->add_setting(
		'banner_slider_note',
		array(
			'sanitize_callback' => 'wp_kses_post'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Info_Text( 
			$wp_customize,
			'banner_slider_note',
			array(
				'section' => 'banner_section_settings',
                'description' => sprintf( '<hr><b>%1$s</b>', __( 'You can customize this slider settings as per your need', 'lawyer-landing-page-pro' ) ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
    
    /** Slider Auto */
    $wp_customize->add_setting(
        'slider_auto',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'slider_auto',
			array(
				'section'     => 'banner_section_settings',
				'label'       => __( 'Slider Auto', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable slider auto transition.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
    
    /** Slider Loop */
    $wp_customize->add_setting(
        'slider_loop',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'slider_loop',
			array(
				'section'     => 'banner_section_settings',
				'label'       => __( 'Slider Loop', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable slider loop.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
    
    /** Mouse Drag */
    $wp_customize->add_setting(
        'slider_drag',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'slider_drag',
			array(
				'section'     => 'banner_section_settings',
				'label'       => __( 'Mouse Drag', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable mouse drag.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
    
    /** Slider Caption */
    $wp_customize->add_setting(
        'slider_caption',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'slider_caption',
			array(
				'section'     => 'banner_section_settings',
				'label'       => __( 'Slider Caption', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable slider caption.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
    
    /** Full Image */
    $wp_customize->add_setting(
        'slider_full_image',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'slider_full_image',
			array(
				'section'     => 'banner_section_settings',
				'label'       => __( 'Full Image', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable to use full size image in slider.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'
			)
		)
	);
        
    /** Select Category */
    $wp_customize->add_setting(
		'slider_animation',
		array(
			'default'			=> 'hinge',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'slider_animation',
    		array(
                'label'	      => __( 'Slider Animation', 'lawyer-landing-page-pro' ),
                'section'     => 'banner_section_settings',
    			'choices'     => array(
                    'bounceOut'      => __( 'Bounce Out', 'lawyer-landing-page-pro' ),
                    'bounceOutLeft'  => __( 'Bounce Out Left', 'lawyer-landing-page-pro' ),
                    'bounceOutRight' => __( 'Bounce Out Right', 'lawyer-landing-page-pro' ),
                    'bounceOutUp'    => __( 'Bounce Out Up', 'lawyer-landing-page-pro' ),
                    'bounceOutDown'  => __( 'Bounce Out Down', 'lawyer-landing-page-pro' ),
                    'fadeOut'        => __( 'Fade Out', 'lawyer-landing-page-pro' ),
                    'fadeOutLeft'    => __( 'Fade Out Left', 'lawyer-landing-page-pro' ),
                    'fadeOutRight'   => __( 'Fade Out Right', 'lawyer-landing-page-pro' ),
                    'fadeOutUp'      => __( 'Fade Out Up', 'lawyer-landing-page-pro' ),
                    'fadeOutDown'    => __( 'Fade Out Down', 'lawyer-landing-page-pro' ),
                    'flipOutX'       => __( 'Flip OutX', 'lawyer-landing-page-pro' ),
                    'flipOutY'       => __( 'Flip OutY', 'lawyer-landing-page-pro' ),
                    'hinge'          => __( 'Hinge', 'lawyer-landing-page-pro' ),
                    'pulse'          => __( 'Pulse', 'lawyer-landing-page-pro' ),
                    'rollOut'        => __( 'Roll Out', 'lawyer-landing-page-pro' ),
                    'rollOutLeft'    => __( 'Roll Out Left', 'lawyer-landing-page-pro' ),
                    'rollOutRight'   => __( 'Roll Out Right', 'lawyer-landing-page-pro' ),
                    'rollOutUp'      => __( 'Roll Out Up', 'lawyer-landing-page-pro' ),
                    'rollOutDown'    => __( 'Roll Out Down', 'lawyer-landing-page-pro' ),
                    'rotateOut'      => __( 'Rotate Out', 'lawyer-landing-page-pro' ),
                    'rotateOutLeft'  => __( 'Rotate Out Left', 'lawyer-landing-page-pro' ),
                    'rotateOutRight' => __( 'Rotate Out Right', 'lawyer-landing-page-pro' ),
                    'rotateOutUp'    => __( 'Rotate Out Up', 'lawyer-landing-page-pro' ),
                    'rotateOutDown'  => __( 'Rotate Out Down', 'lawyer-landing-page-pro' ),
                    'rubberBand'     => __( 'Rubber Band', 'lawyer-landing-page-pro' ),
                    'shake'          => __( 'Shake', 'lawyer-landing-page-pro' ),
                    'slideOutLeft'   => __( 'Slide Out Left', 'lawyer-landing-page-pro' ),
                    'slideOutRight'  => __( 'Slide Out Right', 'lawyer-landing-page-pro' ),
                    'slideOutUp'     => __( 'Slide Out Up', 'lawyer-landing-page-pro' ),
                    'slideOutDown'   => __( 'Slide Out Down', 'lawyer-landing-page-pro' ),
                    'swing'          => __( 'Swing', 'lawyer-landing-page-pro' ),
                    'tada'           => __( 'Tada', 'lawyer-landing-page-pro' ),
                    'zoomOut'        => __( 'Zoom Out', 'lawyer-landing-page-pro' ),
                    'zoomOutLeft'    => __( 'Zoom Out Left', 'lawyer-landing-page-pro' ),
                    'zoomOutRight'   => __( 'Zoom Out Right', 'lawyer-landing-page-pro' ),
                    'zoomOutUp'      => __( 'Zoom Out Up', 'lawyer-landing-page-pro' ),
                    'zoomOutDown'    => __( 'Zoom Out Down', 'lawyer-landing-page-pro' ),
                ),
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'                	
     		)
		)
	);


}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_banner' );

/**
 * Active Callback
*/
function lawyer_landing_page_pro_banner_ac( $control ){
    
    $ed_banner   = $control->manager->get_setting( 'ed_banner_section' )->value();
    $slider_type = $control->manager->get_setting( 'slider_type' )->value();
    $control_id  = $control->id;
    
    if ( $control_id == 'banner_note' && $ed_banner == 'static_banner' ) return true;
    if ( $control_id == 'banner_form' && $ed_banner == 'static_banner' ) return true;
    if ( $control_id == 'form_note' && $ed_banner == 'static_banner' ) return true;
    if ( $control_id == 'form_color_scheme' && $ed_banner == 'static_banner' ) return true;
    
    if ( $control_id == 'banner_slider_note' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_auto' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_loop' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_drag' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_caption' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_full_image' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_animation' && $ed_banner == 'slider_banner' ) return true;
    
    if ( $control_id == 'slider_type' && $ed_banner == 'slider_banner' ) return true;
    if ( $control_id == 'slider_cat' && $ed_banner == 'slider_banner' && $slider_type == 'cat' ) return true;
    if ( $control_id == 'slider_post_one' && $ed_banner == 'slider_banner' && $slider_type == 'post' ) return true;
    if ( $control_id == 'slider_post_two' && $ed_banner == 'slider_banner' && $slider_type == 'post' ) return true;
    if ( $control_id == 'slider_post_three' && $ed_banner == 'slider_banner' && $slider_type == 'post' ) return true;
    if ( $control_id == 'slider_post_four' && $ed_banner == 'slider_banner' && $slider_type == 'post' ) return true;
    if ( $control_id == 'slider_post_five' && $ed_banner == 'slider_banner' && $slider_type == 'post' ) return true;
    if ( $control_id == 'slider_custom' && $ed_banner == 'slider_banner' && $slider_type == 'custom' ) return true;
    if ( $control_id == 'slider_readmore' && $ed_banner == 'slider_banner' ) return true;
    
    return false;
}