<?php
/**
 * Blog Section Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_blog( $wp_customize ) {
    
    /** Blog Section */
    $wp_customize->add_section(
        'blog_settings',
        array(
            'title'    => __( 'Blog Section', 'lawyer-landing-page-pro' ),
            'priority' => 70,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_blog',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_blog',
			array(
				'section'		=> 'blog_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_blog',
        array(
            'default'           => __( 'Blog', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_blog',
        array(
            'label'       => __( 'Blog Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'blog_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** Blog page */
    $wp_customize->add_setting(
		'blog_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'blog_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description.', 'lawyer-landing-page-pro' ),
                'section'     => 'blog_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    /** Button Label */
    $wp_customize->add_setting(
        'blog_section_button_label',
        array(
            'default'           => __( 'View All Blogs', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'blog_section_button_label',
        array(
            'label'       => __( 'View All Button Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'This button will be visible only when Posts page is selected in Front page display settings.', 'lawyer-landing-page-pro' ),
            'section'     => 'blog_settings',
            'type'        => 'text',
        )
    );
    
    /** Excerpt Character */
    $wp_customize->add_setting( 'blog_excerpt_char', array(
        'default'           => 150,
        'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Slider_Control( 
			$wp_customize,
			'blog_excerpt_char',
			array(
				'section'		=> 'blog_settings',
				'label'			=> __( 'Excerpt Character', 'lawyer-landing-page-pro' ),
				'choices'		=> array(
					'min' 	=> 10,
					'max' 	=> 500,
					'step'	=> 10,
				)
			)
		)
	);
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_blog' );