<?php
/**
 * Client Logo Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_client( $wp_customize ) {
    
    /** Client Section */
    $wp_customize->add_section(
        'logo_settings',
        array(
            'title'    => __( 'Client Logo Section', 'lawyer-landing-page-pro' ),
            'priority' => 75,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_client',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_client',
			array(
				'section'		=> 'logo_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_client',
        array(
            'default'           => __( 'Clients', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_client',
        array(
            'label'       => __( 'Client Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'logo_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** Client page */
    $wp_customize->add_setting(
		'client_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'client_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description.', 'lawyer-landing-page-pro' ),
                'section'     => 'logo_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    if( taxonomy_exists( 'logo_categories' ) ){
        /** Select Category */
        $wp_customize->add_setting(
    		'home_logo_cat',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'home_logo_cat',
        		array(
                    'label'	      => __( 'Logo Category', 'lawyer-landing-page-pro' ),
                    'description' => __( 'Choose logo category for home page.', 'lawyer-landing-page-pro' ),
        			'section'     => 'logo_settings',
        			'choices'     => lawyer_landing_page_pro_get_categories( true, 'logo_categories', true ),
         		)
    		)
    	);
    }else{
        $wp_customize->add_setting(
    		'home_client_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Info_Text( 
    			$wp_customize,
    			'home_client_note',
    			array(
    				'section'     => 'logo_settings', 
                    'label'       => __( 'Logo Category', 'lawyer-landing-page-pro' ),   				
                    'description' => sprintf( __( 'Please add logo category after installing and activating the %1$sRara Theme Tool Kit Pro%2$s which you have received along with this theme. After that logo category will be listed.', 'lawyer-landing-page-pro' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
       );
    }
        
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_client' );