<?php
/**
 * Contact Section Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_contact( $wp_customize ) {

    /** Contact Section */
    $wp_customize->add_section(
        'contact_settings',
        array(
            'title'    => __( 'Contact Section', 'lawyer-landing-page-pro' ),
            'priority' => 80,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_contact',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_contact',
			array(
				'section'		=> 'contact_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_contact',
        array(
            'default'           => __( 'Contact', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_contact',
        array(
            'label'       => __( 'Contact Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** Contact page */
    $wp_customize->add_setting(
		'contact_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'contact_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description. If there is excerpt then excerpt will be displayed in place of description.', 'lawyer-landing-page-pro' ),
                'section'     => 'contact_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    /** Enable Google Map */
    $wp_customize->add_setting(
        'ed_google_map_section',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_google_map_section',
			array(
				'section'	  => 'contact_settings',
				'label'		  => __( 'Enable Google Map', 'lawyer-landing-page-pro' ),
				'description' => __( 'You can change the settings of google map from General Settings > Google Map Settings.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Contact page */
    $wp_customize->add_setting(
		'contact_section_form',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'contact_section_form',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Select page/post to add contact form and additional description. Description of selected page/post will be displayed. Please add contact form 7 shortcode in the selected page content.', 'lawyer-landing-page-pro' ),
                'section'     => 'contact_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_contact' );