<?php
/**
 * FAQ Section Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_faq( $wp_customize ) {

    /** FAQ Section */
    $wp_customize->add_section(
        'faq_settings',
        array(
            'title'    => __( 'FAQ Section', 'lawyer-landing-page-pro' ),
            'priority' => 65,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_faq',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_faq',
			array(
				'section'		=> 'faq_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_faq',
        array(
            'default'           => __( 'FAQs', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_faq',
        array(
            'label'       => __( 'FAQ Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'faq_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** faq page */
    $wp_customize->add_setting(
		'faq_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'faq_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description.', 'lawyer-landing-page-pro' ),
                'section'     => 'faq_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);

    if( is_rara_toolkit_activated() ){
            
        /** No. of FAQ */
        $wp_customize->add_setting(
    		'no_of_faq',
    		array(
    			'default'			=> '6',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'no_of_faq',
        		array(
                    'label'       => __( 'No. of FAQ', 'lawyer-landing-page-pro' ),
                    'description' => __( 'Choose "Select FAQ" to show specific FAQ.', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => array(
                        'select_faq' => __( 'Select FAQ', 'lawyer-landing-page-pro' ),
                        '2'          => __( '2', 'lawyer-landing-page-pro' ),
                        '4'          => __( '4', 'lawyer-landing-page-pro' ),
                        '6'          => __( '6', 'lawyer-landing-page-pro' ),
                        '8'          => __( '8', 'lawyer-landing-page-pro' ),
                        '10'         => __( '10', 'lawyer-landing-page-pro' ),
                    ),
         		)
    		)
    	);
        
        /** FAQ Excerpt Character */
        $wp_customize->add_setting( 'faq_excerpt_char', array(
            'default'           => 150,
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
        ) );
        
        $wp_customize->add_control(
    		new Rara_Controls_Slider_Control( 
    			$wp_customize,
    			'faq_excerpt_char',
    			array(
    				'section'		=> 'faq_settings',
    				'label'			=> __( 'FAQ Excerpt Character', 'lawyer-landing-page-pro' ),
    				'choices'		=> array(
    					'min' 	=> 10,
    					'max' 	=> 500,
    					'step'	=> 10,
    				)
    			)
    		)
    	);
        
        /** Select FAQ One */
        $wp_customize->add_setting(
    		'faq_post_one',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'faq_post_one',
        		array(
                    'label'       => __( 'Select FAQ One', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'faq' ),
                    'active_callback' => 'lawyer_landing_page_pro_faq_ac'
         		)
    		)
    	);
        
        /** Select FAQ Two */
        $wp_customize->add_setting(
    		'faq_post_two',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'faq_post_two',
        		array(
                    'label'       => __( 'Select FAQ Two', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'faq' ),
                    'active_callback' => 'lawyer_landing_page_pro_faq_ac'
         		)
    		)
    	);
        
        /** Select FAQ Three */
        $wp_customize->add_setting(
    		'faq_post_three',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'faq_post_three',
        		array(
                    'label'       => __( 'Select FAQ Three', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'faq' ),
                    'active_callback' => 'lawyer_landing_page_pro_faq_ac'
         		)
    		)
    	);
        
        /** Select FAQ Four */
        $wp_customize->add_setting(
    		'faq_post_four',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'faq_post_four',
        		array(
                    'label'       => __( 'Select FAQ Four', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'faq' ),
                    'active_callback' => 'lawyer_landing_page_pro_faq_ac'
         		)
    		)
    	);
        
        /** Select FAQ five */
        $wp_customize->add_setting(
    		'faq_post_five',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'faq_post_five',
        		array(
                    'label'       => __( 'Select FAQ Five', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'faq' ),
                    'active_callback' => 'lawyer_landing_page_pro_faq_ac'
         		)
    		)
    	);
        
        /** Select FAQ Six */
        $wp_customize->add_setting(
    		'faq_post_six',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'faq_post_six',
        		array(
                    'label'       => __( 'Select FAQ Six', 'lawyer-landing-page-pro' ),
                    'section'     => 'faq_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'faq' ),
                    'active_callback' => 'lawyer_landing_page_pro_faq_ac'
         		)
    		)
    	);
        
        /** Button Label */
        $wp_customize->add_setting(
            'faq_section_button_label',
            array(
                'default'           => __( 'View All FAQs', 'lawyer-landing-page-pro' ),
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        
        $wp_customize->add_control(
            'faq_section_button_label',
            array(
                'label'   => __( 'View All Button Label', 'lawyer-landing-page-pro' ),
                'section' => 'faq_settings',
                'type'    => 'text',
            )
        );
        
        /** Body Background */
        $wp_customize->add_setting( 'faq_order', array(
            'default'           => 'date',
            'sanitize_callback' => 'esc_attr'
        ) );
        
        $wp_customize->add_control(
    		new Rara_Controls_Radio_Buttonset_Control(
    			$wp_customize,
    			'faq_order',
    			array(
    				'section'	  => 'faq_settings',
    				'label'       => __( 'FAQ Order', 'lawyer-landing-page-pro' ),
                    'description' => __( 'Choose FAQ order for faq section. This setting also works on the FAQ Archive page.', 'lawyer-landing-page-pro' ),
    				'choices'	  => array(
    					'date'       => __( 'Post Date', 'lawyer-landing-page-pro' ),
                        'menu_order' => __( 'Menu Order', 'lawyer-landing-page-pro' ),
    				)
    			)
    		)
    	);
        
    }else{
        $wp_customize->add_setting(
    		'faq_section_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Info_Text( 
    			$wp_customize,
    			'faq_section_note',
    			array(
    				'section'      => 'faq_settings', 
                    'description' => sprintf( __( 'Please install/activate the %1$sRara Theme Tool Kit Pro%2$s which you have received along with this theme for setting related with FAQ post type.', 'lawyer-landing-page-pro' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
        );
    }
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_faq' );

/**
 * Active Callback
*/
function lawyer_landing_page_pro_faq_ac( $control ){
    
    $ed_showall = $control->manager->get_setting( 'no_of_faq' )->value();
    $control_id = $control->id;
    
    if ( $control_id == 'faq_post_one' && $ed_showall == 'select_faq' ) return true;
    if ( $control_id == 'faq_post_two' && $ed_showall == 'select_faq' ) return true;
    if ( $control_id == 'faq_post_three' && $ed_showall == 'select_faq' ) return true;
    if ( $control_id == 'faq_post_four' && $ed_showall == 'select_faq' ) return true;
    if ( $control_id == 'faq_post_five' && $ed_showall == 'select_faq' ) return true;
    if ( $control_id == 'faq_post_six' && $ed_showall == 'select_faq' ) return true;
    
    return false;
}