<?php
/**
 * Portfolio Section Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_portfolio( $wp_customize ) {

    /** Portfolio Section */
    $wp_customize->add_section(
        'portfolio_settings',
        array(
            'title'    => __( 'Portfolio Section', 'lawyer-landing-page-pro' ),
            'priority' => 45,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_portfolio',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_portfolio',
			array(
				'section'		=> 'portfolio_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_portfolio',
        array(
            'default'           => __( 'Portfolio', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_portfolio',
        array(
            'label'       => __( 'Portfolio Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'portfolio_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** Portfolio page */
    $wp_customize->add_setting(
		'portfolio_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'portfolio_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description.', 'lawyer-landing-page-pro' ),
                'section'     => 'portfolio_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    if( is_rara_toolkit_activated() ){
        
        /** No. of Portfolio */
        $wp_customize->add_setting(
    		'no_of_portfolio',
    		array(
    			'default'			=> '6',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'no_of_portfolio',
        		array(
                    'label'       => __( 'No. of Portfolio', 'lawyer-landing-page-pro' ),
                    'description' => __( 'Choose number of Portfolio to display.', 'lawyer-landing-page-pro' ),
                    'section'     => 'portfolio_settings',            
        			'choices'     => array(
                        '3' => __( '3', 'lawyer-landing-page-pro' ),
                        '6' => __( '6', 'lawyer-landing-page-pro' ),
                        '9' => __( '9', 'lawyer-landing-page-pro' ),
                    ),
         		)
    		)
    	);
        
        /** Button Label */
        $wp_customize->add_setting(
            'portfolio_section_button_label',
            array(
                'default'           => __( 'View All Portfolios', 'lawyer-landing-page-pro' ),
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        
        $wp_customize->add_control(
            'portfolio_section_button_label',
            array(
                'label'   => __( 'View All Button Label', 'lawyer-landing-page-pro' ),
                'section' => 'portfolio_settings',
                'type'    => 'text',
            )
        );
    
    }else{
        $wp_customize->add_setting(
    		'portfolio_section_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Info_Text( 
    			$wp_customize,
    			'portfolio_section_note',
    			array(
    				'section'      => 'portfolio_settings', 
                    'description' => sprintf( __( 'Please install/activate the %1$sRara Theme Tool Kit Pro%2$s which you have received along with this theme for setting related with Portfolio post type.', 'lawyer-landing-page-pro' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
        );
    }
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_portfolio' );