<?php
/**
 * Practice Section Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_home_practice( $wp_customize ) {
    
    /** practice Section */
    $wp_customize->add_section(
        'practice_settings',
        array(
            'title'    => __( 'Practice Section', 'lawyer-landing-page-pro' ),
            'priority' => 25,
            'panel'    => 'home_page_settings',
        )
    );
    
    /** Menu Label */
    $wp_customize->add_setting(
        'ed_section_menu_practice',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_section_menu_practice',
			array(
				'section'		=> 'practice_settings',
				'label'			=> __( 'Section Menu', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Disable to hide the section in the menu.', 'lawyer-landing-page-pro' ),
                'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
			)
		)
	);
    
    /** Menu Label  */
    $wp_customize->add_setting(
        'section_menu_practice',
        array(
            'default'           => __( 'Practices', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'section_menu_practice',
        array(
            'label'       => __( 'Practice Section Menu Label', 'lawyer-landing-page-pro' ),
            'description' => __( 'If left blank the selected page title will be used as Section Menu Label.', 'lawyer-landing-page-pro' ),
            'section'     => 'practice_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_section_menu_ac'
        )
    );
    
    /** pratice page */
    $wp_customize->add_setting(
		'practice_section_page',
		array(
			'default'			=> '',
			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
		)
	);

	$wp_customize->add_control(
		new Rara_Controls_Select_Control(
    		$wp_customize,
    		'practice_section_page',
    		array(
                'label'       => __( 'Select Page/Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Title and description of selected page/post will display as section title and description.', 'lawyer-landing-page-pro' ),
                'section'     => 'practice_settings',            
    			'choices'     => lawyer_landing_page_pro_get_posts( array( 'post', 'page' ) ),
     		)
		)
	);
    
    if( is_rara_toolkit_activated() ){
        
        /** No. of Practice */
        $wp_customize->add_setting(
    		'select_practice',
    		array(
    			'default'			=> '4',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'select_practice',
        		array(
                    'label'       => __( 'No. of Practice', 'lawyer-landing-page-pro' ),
                    'description' => __( 'Choose "Select Practice" to show specific Practice.', 'lawyer-landing-page-pro' ),
                    'section'     => 'practice_settings',            
        			'choices'     => array(
                        's_practice' => __( 'Select Practice', 'lawyer-landing-page-pro' ),
                        '4'          => __( '4', 'lawyer-landing-page-pro' ),
                        '8'          => __( '8', 'lawyer-landing-page-pro' ),
                    ),
         		)
    		)
    	);
        
        /** Practice Post/Page Excerpt Character */
        $wp_customize->add_setting( 'practice_excerpt_char', array(
            'default'           => 100,
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
        ) );
        
        $wp_customize->add_control(
    		new Rara_Controls_Slider_Control( 
    			$wp_customize,
    			'practice_excerpt_char',
    			array(
    				'section'		=> 'practice_settings',
    				'label'			=> __( 'Practice Excerpt Character', 'lawyer-landing-page-pro' ),
    				'choices'		=> array(
    					'min' 	=> 10,
    					'max' 	=> 500,
    					'step'	=> 10,
    				)
    			)
    		)
    	);
        
        /** Select Practice One */
        $wp_customize->add_setting(
    		'practice_post_one',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'practice_post_one',
        		array(
                    'label'       => __( 'Select Practice One', 'lawyer-landing-page-pro' ),
                    'section'     => 'practice_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'practice' ),
                    'active_callback' => 'lawyer_landing_page_pro_practice_ac'
         		)
    		)
    	);
        
        /** Select Practice Two */
        $wp_customize->add_setting(
    		'practice_post_two',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'practice_post_two',
        		array(
                    'label'       => __( 'Select Practice Two', 'lawyer-landing-page-pro' ),
                    'section'     => 'practice_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'practice' ),
                    'active_callback' => 'lawyer_landing_page_pro_practice_ac'
         		)
    		)
    	);
        
        /** Select Practice three */
        $wp_customize->add_setting(
    		'practice_post_three',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'practice_post_three',
        		array(
                    'label'       => __( 'Select Practice Three', 'lawyer-landing-page-pro' ),
                    'section'     => 'practice_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'practice' ),
                    'active_callback' => 'lawyer_landing_page_pro_practice_ac'
         		)
    		)
    	);
        
        /** Select Practice four */
        $wp_customize->add_setting(
    		'practice_post_four',
    		array(
    			'default'			=> '',
    			'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Select_Control(
        		$wp_customize,
        		'practice_post_four',
        		array(
                    'label'       => __( 'Select Practice Four', 'lawyer-landing-page-pro' ),
                    'section'     => 'practice_settings',            
        			'choices'     => lawyer_landing_page_pro_get_posts( 'practice' ),
                    'active_callback' => 'lawyer_landing_page_pro_practice_ac'
         		)
    		)
    	);
    
    }else{
        $wp_customize->add_setting(
    		'practice_section_note',
    		array(
    			'sanitize_callback' => 'wp_kses_post'
    		)
    	);
    
    	$wp_customize->add_control(
    		new Rara_Controls_Info_Text( 
    			$wp_customize,
    			'practice_section_note',
    			array(
    				'section' => 'practice_settings', 
                    'description' => sprintf( __( 'Please install/activate the %1$sRara Theme Tool Kit Pro%2$s which you have received along with this theme for setting related with Practice post type.', 'lawyer-landing-page-pro' ), '<a href="' . admin_url( 'themes.php?page=tgmpa-install-plugins' ) . '" target="_blank">', '</a>' ),
    			)
    		)
        );
    }
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_home_practice' );

/**
 * Active Callback
*/
function lawyer_landing_page_pro_practice_ac( $control ){
    
    $ed_showall = $control->manager->get_setting( 'select_practice' )->value();
    $control_id = $control->id;
    
    if ( $control_id == 'practice_post_one' && $ed_showall == 's_practice' ) return true;
    if ( $control_id == 'practice_post_two' && $ed_showall == 's_practice' ) return true;
    if ( $control_id == 'practice_post_three' && $ed_showall == 's_practice' ) return true;
    if ( $control_id == 'practice_post_four' && $ed_showall == 's_practice' ) return true;
    
    return false;
}