<?php
/**
 * Body Typography Options
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_typography_body( $wp_customize ) {

    /** Body Settings */
    $wp_customize->add_section( 'typography_body_section', array(
        'title'      => __( 'Body Settings', 'lawyer-landing-page-pro' ),
        'priority'   => 11,
        'capability' => 'edit_theme_options',
        'panel'      => 'typography_section'
    ) );
    
    /** Body Font */
    $wp_customize->add_setting( 'body_font', array(
		'default' => array(                         // Default font styles				
			'font-family' => 'Raleway',
			'variant'     => 'regular',
		),
		'sanitize_callback' => array( 'Rara_Fonts', 'sanitize_typography' )
	) );

	$wp_customize->add_control( 
        new Rara_Typography_Control( 
            $wp_customize, 
            'body_font', 
            array(
        		'label'   => __( 'Body Font', 'lawyer-landing-page-pro' ),
                'section' => 'typography_body_section',		
        	) 
         ) 
    );
    
    /** Body Font Size */
    $wp_customize->add_setting( 'body_font_size', array(
        'default'           => 16,
        'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Slider_Control( 
			$wp_customize,
			'body_font_size',
			array(
				'section' => 'typography_body_section',
				'label'	  => __( 'Body Font Size', 'lawyer-landing-page-pro' ),
				'choices' => array(
					'min' 	=> 10,
					'max' 	=> 35,
					'step'	=> 1,
				)
			)
		)
	);
    
    /** Body Line Height */
    $wp_customize->add_setting( 'body_line_height', array(
        'default'           => 24,
        'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Slider_Control( 
			$wp_customize,
			'body_line_height',
			array(
				'section' => 'typography_body_section',
				'label'	  => __( 'Body Line Height', 'lawyer-landing-page-pro' ),
				'choices' => array(
					'min' 	=> 15,
					'max' 	=> 50,
					'step'	=> 1,
				)
			)
		)
	);    
    
    /** Body Color */
    $wp_customize->add_setting( 'body_color', array(
        'default'           => '#757575',
        'sanitize_callback' => 'sanitize_hex_color'
    ) );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'body_color', 
            array(
                'label'   => __( 'Body Color', 'lawyer-landing-page-pro' ),
                'section' => 'typography_body_section',                
            )
        )
    );
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_typography_body' );