<?php
/**
 * H5 Typography Options
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_typography_h5( $wp_customize ) {
    
    /** H5 Typography Settings */
    $wp_customize->add_section( 'h5_section', array(
        'title'      => __( 'H5 Settings (Content)', 'lawyer-landing-page-pro' ),
        'priority'   => 27,
        'capability' => 'edit_theme_options',
        'panel'      => 'typography_section'
    ) );
    
    /** H5 Font */
    $wp_customize->add_setting( 'h5_font', array(
		'default' => array(                         // Default font styles				
			'font-family' => 'Raleway',
			'variant'     => 'regular',
		),
		'sanitize_callback' => array( 'Rara_Fonts', 'sanitize_typography' )
	) );

	$wp_customize->add_control( 
        new Rara_Typography_Control( 
            $wp_customize, 
            'h5_font', 
            array(
        		'label'   => __( 'H5 Font', 'lawyer-landing-page-pro' ),
        		'section' => 'h5_section',		
        	) 
         ) 
    );
        
    /** H5 Font Size */
    $wp_customize->add_setting( 'h5_font_size', array(
        'default'           => 24,
        'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Slider_Control( 
			$wp_customize,
			'h5_font_size',
			array(
				'section' => 'h5_section',
				'label'	  => __( 'H5 Font Size', 'lawyer-landing-page-pro' ),
				'choices' => array(
					'min' 	=> 10,
					'max' 	=> 40,
					'step'	=> 1,
				)
			)
		)
	);
    
    /** H5 Line Height */
    $wp_customize->add_setting( 'h5_line_height', array(
        'default'           => 29,
        'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_select'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Slider_Control( 
			$wp_customize,
			'h5_line_height',
			array(
				'section' => 'h5_section',
				'label'	  => __( 'H5 Line Height', 'lawyer-landing-page-pro' ),
				'choices' => array(
					'min' 	=> 10,
					'max' 	=> 65,
					'step'	=> 1,
				)
			)
		)
	);
    
    /** H5 Color */
    $wp_customize->add_setting( 'h5_color', array(
        'default'           => '#353d47',
        'sanitize_callback' => 'sanitize_hex_color'
    ) );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'h5_color', 
            array(
                'label'   => __( 'H5 Color', 'lawyer-landing-page-pro' ),
                'section' => 'h5_section',                
            )
        )
    );
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_typography_h5' );