<?php
/**
 * Contact Page Theme Option.
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_contact( $wp_customize ) {
    
    /** Contact Page Settings */
    $wp_customize->add_panel( 
        'contact_page_settings',
         array(
            'priority'    => 40,
            'capability'  => 'edit_theme_options',
            'title'       => __( 'Contact Page Settings', 'lawyer-landing-page-pro' ),
            'description' => __( 'Customize Contact Page Sections', 'lawyer-landing-page-pro' ),
        ) 
    );
    
    /** Contact Page Settings */
    $wp_customize->add_section( 
        'contact_detail_settings',
         array(            
            'capability'  => 'edit_theme_options',
            'priority' => 25,
            'title'       => __( 'Contact Details Settings', 'lawyer-landing-page-pro' ),
            'panel'    => 'contact_page_settings',
            'description' => __( 'Please add the contact form 7 shortcode in the page with contact page template.', 'lawyer-landing-page-pro' ),
        ) 
    );
    
    /** Enable Google Map */
    $wp_customize->add_setting(
        'ed_google_map',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_google_map',
			array(
				'section'	  => 'contact_detail_settings',
				'label'		  => __( 'Enable Google Map', 'lawyer-landing-page-pro' ),
				'description' => __( 'If disabled the featured image of the page will be displayed if set.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Contact Info Title  */
    $wp_customize->add_setting(
        'contact_info_title',
        array(
            'default'           => __( 'Contact Info', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'contact_info_title',
        array(
            'label'       => __( 'Contact Info Title', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_detail_settings',
            'type'        => 'text',                                 
        )
    );
    
    /** Contact Info Content  */
    $wp_customize->add_setting(
        'contact_info_content',
        array(
            'default'           => __( 'The contact page is just for demonstration purpose. Please DON\'T contact us via the contact form. For any questions or support, contact us on our support forum.', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'wp_kses_post',
        )
    );
    
    $wp_customize->add_control(
        'contact_info_content',
        array(
            'label'       => __( 'Contact Info Content', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_detail_settings',
            'type'        => 'textarea',                                 
        )
    );
    
    /** Contact Address  */
    $wp_customize->add_setting(
        'contact_address',
        array(
            'default'           => __( 'Thamel, Kathmandu, Nepal P.O. Box no. :8942, CPC 599', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'wp_kses_post',
        )
    );
    
    $wp_customize->add_control(
        'contact_address',
        array(
            'label'       => __( 'Contact Address', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the contact address.', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_detail_settings',
            'type'        => 'textarea',                                    
        )
    );
    
    /** Phone as in Header */
    $wp_customize->add_setting(
        'ed_asin_header_phone',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_asin_header_phone',
			array(
				'section'	  => 'contact_detail_settings',
				'label'		  => __( 'Phone as in Header', 'lawyer-landing-page-pro' ),
				'description' => __( 'If enabled the phone used in header will be displayed.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Contact Phone  */
    $wp_customize->add_setting(
        'contact_phone',
        array(
            'default'           => __( '(888) 123-456789', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
        'contact_phone',
        array(
            'label'       => __( 'Contact Phone', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the contact phone.', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_detail_settings',
            'type'        => 'text',
            'active_callback' => 'lawyer_landing_page_pro_contact_ac'                                    
        )
    );
    
    /** Contact Fax  */
    $wp_customize->add_setting(
        'contact_fax',
        array(
            'default'           => __( '+977- 9841927878(Kabiraj), +977- 98410358(Sujan)', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'wp_kses_post',
        )
    );
    
    $wp_customize->add_control(
        'contact_fax',
        array(
            'label'       => __( 'Contact Fax/Phones', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the contact phone. For Multiple Phone numbers seperate with comas. e.g, +977- 9876543210, +977-98410358', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_detail_settings',
            'type'        => 'textarea',                                    
        )
    );
    
    /** Contact Email  */
    $wp_customize->add_setting(
        'contact_email',
        array(
            'default'           => __( 'info@lawyerlanding.com, info@raratheme.com, support@raratheme.com', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'wp_kses_post',
        )
    );
    
    $wp_customize->add_control(
        'contact_email',
        array(
            'label'       => __( 'Contact Email', 'lawyer-landing-page-pro' ),
            'description' => __( 'Enter the contact email. For Multiple Emails seperate with comas. e.g, info@test.com, info@lawyerpro.com', 'lawyer-landing-page-pro' ),
            'section'     => 'contact_detail_settings',
            'type'        => 'textarea',                                    
        )
    );

}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_contact' );

/**
 * Active Callback for contact phone
*/
function lawyer_landing_page_pro_contact_ac( $control ){
    
    $ed_as_in_header  = $control->manager->get_setting( 'ed_asin_header_phone' )->value();
    
    if ( $ed_as_in_header == false ) return true;
    
    return false;
}