<?php
/**
 * Post Page Options
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_postpage( $wp_customize ) {

    $wp_customize->add_section( 'post_page_settings', array(
        'priority'   => 45,
        'capability' => 'edit_theme_options',
        'title'      => __( 'Post Page Settings', 'lawyer-landing-page-pro' ),
    ) );
    
    /** Author Bio */
    $wp_customize->add_setting(
        'ed_bio',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_bio',
			array(
				'section'     => 'post_page_settings',
				'label'       => __( 'Show Author Bio', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable to show Author Bio in Single Post. You have to insert "Biographical Info" from author&rsquo;s Profile page.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Featured Image */
    $wp_customize->add_setting(
        'ed_featured_image',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_featured_image',
			array(
				'section'     => 'post_page_settings',
				'label'       => __( 'Show Featured Image', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable to show Featured Image in Single Post/Page.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Comments */
    $wp_customize->add_setting(
        'ed_comments',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_comments',
			array(
				'section'     => 'post_page_settings',
				'label'       => __( 'Show Comments', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable to show Comments in Single Post/Page.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Highlight Author Comment */
    $wp_customize->add_setting(
        'ed_auth_comments',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_auth_comments',
			array(
				'section'     => 'post_page_settings',
				'label'       => __( 'Highlight Author Comments', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable to higlight Author Comments.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Show Related Post */
    $wp_customize->add_setting(
        'ed_related_post',
        array(
            'default'           => '1',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_checkbox',
        )
    );
    
    $wp_customize->add_control(
		new Rara_Controls_Toggle_Control( 
			$wp_customize,
			'ed_related_post',
			array(
				'section'     => 'post_page_settings',
				'label'       => __( 'Show Related Post', 'lawyer-landing-page-pro' ),
                'description' => __( 'Enable to show related post in Single Post.', 'lawyer-landing-page-pro' ),
			)
		)
	);
    
    /** Related Post label */
    $wp_customize->add_setting(
        'related_post_label',
        array(
            'default'           => __( 'Related Posts', 'lawyer-landing-page-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    
    $wp_customize->add_control(
	   'related_post_label',
		array(
			'section'	      => 'post_page_settings',
			'label'		      => __( 'Related Post Label', 'lawyer-landing-page-pro' ),
            'description'     => __( 'Change related post label in Single Post.', 'lawyer-landing-page-pro' ),
			'type'            => 'text',
            'active_callback' => 'lawyer_landing_page_pro_related_post_label_show'
		)		
	);
    
    /** Related Post Taxonomy */    
    $wp_customize->add_setting( 'related_taxonomy', array(
        'default'           => 'cat',
        'sanitize_callback' => 'esc_attr'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Radio_Buttonset_Control(
			$wp_customize,
			'related_taxonomy',
			array(
				'section'	  => 'post_page_settings',
				'label'       => __( 'Related Post Taxonomy', 'lawyer-landing-page-pro' ),
                'description' => __( 'Choose Categories/Tags to display related post based on in Single Post.', 'lawyer-landing-page-pro' ),
				'choices'	  => array(
					'cat'   => __( 'Category', 'lawyer-landing-page-pro' ),
                    'tag'   => __( 'Tags', 'lawyer-landing-page-pro' ),
				),
                'active_callback' => 'lawyer_landing_page_pro_related_post_label_show'
			)
		)
	);
         
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_postpage' );

/**
 * Active Callback for Related Post Label
*/
function lawyer_landing_page_pro_related_post_label_show( $control ){
    $ed_related = $control->manager->get_setting( 'ed_related_post' )->value();
    
    if ( $ed_related ) return true;
    
    return false;
}