<?php
/**
 * Styling Options
 *
 * @package Lawyer_Landing_Page_Pro
 */

function lawyer_landing_page_pro_customize_register_styling( $wp_customize ) {

    $wp_customize->add_section( 'styling_settings', array(
        'priority'   => 22,
        'capability' => 'edit_theme_options',
        'title'      => __( 'Styling Settings', 'lawyer-landing-page-pro' ),
    ) );
    
    /** Layout Style */
    $wp_customize->add_setting( 'layout_style', array(
        'default'           => 'right-sidebar',
        'sanitize_callback' => 'esc_attr'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Radio_Image_Control(
			$wp_customize,
			'layout_style',
			array(
				'section'		=> 'styling_settings',
				'label'			=> __( 'Layout Style', 'lawyer-landing-page-pro' ),
				'description'	=> __( 'Choose the default sidebar position for your site. The position of the sidebar for individual posts can be set in the post editor.', 'lawyer-landing-page-pro' ),
				'choices'		=> array(
					'left-sidebar' => get_template_directory_uri() . '/images/left-sidebar.png',
                    'right-sidebar' => get_template_directory_uri() . '/images/right-sidebar.png',
				)
			)
		)
	);
    
    /** Primary Color Scheme */
    $wp_customize->add_setting( 'primary_color_scheme', array(
        'default'           => '#168dd2',
        'sanitize_callback' => 'sanitize_hex_color'
    ) );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'primary_color_scheme', 
            array(
                'label'       => __( 'Primary Color Scheme', 'lawyer-landing-page-pro' ),
                'description' => __( 'The theme comes with unlimited color schemes for your theme styling.', 'lawyer-landing-page-pro' ),
                'section'     => 'styling_settings',                
            )
        )
    );
    
    /** Secondary Color Scheme */
    $wp_customize->add_setting( 'secondary_color_scheme', array(
        'default'           => '#fa9d00',
        'sanitize_callback' => 'sanitize_hex_color'
    ) );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'secondary_color_scheme', 
            array(
                'label'       => __( 'Secondary Color Scheme', 'lawyer-landing-page-pro' ),
                'description' => __( 'The theme comes with unlimited color schemes for your theme styling.', 'lawyer-landing-page-pro' ),
                'section'     => 'styling_settings',                
            )
        )
    );
    
    /** Banner Form Color Scheme */
    $wp_customize->add_setting( 'form_color_scheme', array(
        'default'           => '#168dd2',
        'sanitize_callback' => 'sanitize_hex_color'
    ) );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'form_color_scheme', 
            array(
                'label'       => __( 'Banner Form Color Scheme', 'lawyer-landing-page-pro' ),
                'description' => __( 'You can change Banner Form Background Color from here.', 'lawyer-landing-page-pro' ),
                'section'     => 'styling_settings',
                'active_callback' => 'lawyer_landing_page_pro_banner_ac'           
            )
        )
    );
    
    /** Background Color */
    $wp_customize->add_setting( 'bg_color', array(
        'default'           => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color'
    ) );

    $wp_customize->add_control( 
        new WP_Customize_Color_Control( 
            $wp_customize, 
            'bg_color', 
            array(
                'label'       => __( 'Background Color', 'lawyer-landing-page-pro' ),
                'description' => __( 'Pick a color for site background.', 'lawyer-landing-page-pro' ),
                'section'     => 'styling_settings',                
            )
        )
    );
    
    /** Body Background */
    $wp_customize->add_setting( 'body_bg', array(
        'default'           => 'image',
        'sanitize_callback' => 'esc_attr'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Radio_Buttonset_Control(
			$wp_customize,
			'body_bg',
			array(
				'section'	  => 'styling_settings',
				'label'       => __( 'Body Background', 'lawyer-landing-page-pro' ),
                'description' => __( 'Choose body background as image or pattern.', 'lawyer-landing-page-pro' ),
				'choices'	  => array(
					'image'   => __( 'Image', 'lawyer-landing-page-pro' ),
                    'pattern' => __( 'Pattern', 'lawyer-landing-page-pro' ),
				)
			)
		)
	);
    
    /** Background Image */
    $wp_customize->add_setting(
        'bg_image',
        array(
            'default'           => '',
            'sanitize_callback' => 'lawyer_landing_page_pro_sanitize_image',
        )
    );
    
    $wp_customize->add_control(
       new WP_Customize_Image_Control(
           $wp_customize,
           'bg_image',
           array(
               'label'           => __( 'Background Image', 'lawyer-landing-page-pro' ),
               'description'     => __( 'Upload your own custom background image or pattern.', 'lawyer-landing-page-pro' ),
               'section'         => 'styling_settings',
               'active_callback' => 'lawyer_landing_page_pro_body_bg_choice'               
           )
       )
    );    
    
    /** Background Pattern */
    $wp_customize->add_setting( 'bg_pattern', array(
        'default'           => 'nobg',
        'sanitize_callback' => 'esc_attr'
    ) );
    
    $wp_customize->add_control(
		new Rara_Controls_Radio_Image_Control(
			$wp_customize,
			'bg_pattern',
			array(
				'section'		  => 'styling_settings',
				'label'			  => __( 'Background Pattern', 'lawyer-landing-page-pro' ),
				'description'	  => __( 'Choose from any of 63 awesome background patterns for your site background.', 'lawyer-landing-page-pro' ),
				'choices'         => lawyer_landing_page_pro_get_patterns(),
                'active_callback' => 'lawyer_landing_page_pro_body_bg_choice'
			)
		)
	);
    
}
add_action( 'customize_register', 'lawyer_landing_page_pro_customize_register_styling' );

/**
 * Active Callback for Body Background
*/
function lawyer_landing_page_pro_body_bg_choice( $control ){
    
    $body_bg    = $control->manager->get_setting( 'body_bg' )->value();
    $control_id = $control->id;
         
    if ( $control_id == 'bg_image' && $body_bg == 'image' ) return true;
    if ( $control_id == 'bg_pattern' && $body_bg == 'pattern' ) return true;
    
    return false;
}