<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * @package Lawyer_Landing_Page_Pro
 */

if ( ! function_exists( 'lawyer_landing_page_pro_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function lawyer_landing_page_pro_posted_on() {
	
    echo '<span class="posted-on">';
    
    printf( '<a href="%1$s" rel="bookmark"><time class="entry-date published updated" datetime="%2$s">%3$s</time></a>', esc_url( get_permalink() ), esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date( get_option( 'date_format' ) ) ) );
    
    echo '</span>';
}
endif; 

if( ! function_exists( 'lawyer_landing_page_pro_posted_by' ) ) :
/**
 * Post posted by
*/
function lawyer_landing_page_pro_posted_by(){
    printf( '<span class="byline author vcard"><a class="url fn n" href="%1$s">%2$s</a></span>', esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), esc_html( get_the_author() ) );
        
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_comment_count' ) ) :
/**
 * Post Comment count
*/
function lawyer_landing_page_pro_comment_count(){
    if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
        echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'lawyer-landing-page-pro' ), esc_html__( '1 Comment', 'lawyer-landing-page-pro' ), esc_html__( '% Comments', 'lawyer-landing-page-pro' ) );
		echo '</span>';
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_categories' ) ) :
/**
 * Post Categories
*/
function lawyer_landing_page_pro_categories(){
    // Hide category text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'lawyer-landing-page-pro' ) );
		if ( $categories_list && lawyer_landing_page_pro_categorized_blog() ) {
			printf( '<span class="cat-links">%1$s</span>', $categories_list ); // WPCS: XSS OK.
		}
	}
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_tags' ) ) :
/**
 * Post Tags
*/
function lawyer_landing_page_pro_tags(){
    // Hide category text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'lawyer-landing-page-pro' ) );
		if ( $tags_list ) {
			printf( '<span class="tag-links">%1$s</span>', $tags_list ); // WPCS: XSS OK.
		}
	}
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_post_meta' ) ) :
/**
 * Post meta info
*/
function lawyer_landing_page_pro_get_post_meta(){
    $post_meta = get_theme_mod( 'post_meta', array( 'date', 'tag', 'cat', 'comment', 'author' ) );
        
    echo '<div class="entry-meta">';
    
    foreach( $post_meta as $meta ){
        if( $meta === 'date' ) lawyer_landing_page_pro_posted_on();
        if( $meta === 'tag' ) lawyer_landing_page_pro_tags();
        if( $meta === 'cat' ) lawyer_landing_page_pro_categories();        
        if( $meta === 'comment' ) lawyer_landing_page_pro_comment_count();
        if( $meta === 'author' ) lawyer_landing_page_pro_posted_by();
    }
    
    echo '</div>';
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_social_share' ) ) :
/**
 * Get list of social sharing icons
 * http://www.sharelinkgenerator.com/
 * 
*/
function lawyer_landing_page_pro_get_social_share( $share ){
    global $post;
    
    switch( $share ){
        case 'facebook':
        echo '<li><a href="' . esc_url( 'https://www.facebook.com/sharer/sharer.php?u=' . get_the_permalink( $post->ID ) ) . '" rel="nofollow" target="_blank"><i class="fa fa-facebook" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'twitter':
        echo '<li><a href="' . esc_url( 'https://twitter.com/home?status=' . get_the_title( $post->ID ) ) . '&nbsp;' . get_the_permalink( $post->ID ) . '" rel="nofollow" target="_blank"><i class="fa fa-twitter" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'linkedin':
        echo '<li><a href="' . esc_url( 'https://www.linkedin.com/shareArticle?mini=true&url=' . get_the_permalink( $post->ID ) . '&title=' . get_the_title( $post->ID ) ) . '" rel="nofollow" target="_blank"><i class="fa fa-linkedin" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'pinterest':
        echo '<li><a href="' . esc_url( 'https://pinterest.com/pin/create/button/?url=' . get_the_permalink( $post->ID ) . '&description=' . get_the_title( $post->ID )  ) . '" rel="nofollow" target="_blank"><i class="fa fa-pinterest" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'email':
        echo '<li><a href="' . esc_url( 'mailto:?Subject=' . get_the_title( $post->ID ) . '&Body=' . get_the_permalink( $post->ID ) ) . '" rel="nofollow" target="_blank"><i class="fa fa-envelope" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'gplus':
        echo '<li><a href="' . esc_url( 'https://plus.google.com/share?url=' . get_the_permalink( $post->ID ) ) . '" rel="nofollow" target="_blank"><i class="fa fa-google" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'stumble':
        echo '<li><a href="' . esc_url( 'http://www.stumbleupon.com/submit?url=' . get_the_permalink( $post->ID ) . '&title=' . get_the_title( $post->ID ) ) . '" rel="nofollow" target="_blank"><i class="fa fa-stumbleupon" aria-hidden="true"></i></a></li>';
        
        break;
        
        case 'reddit':
        echo '<li><a href="' . esc_url( 'http://www.reddit.com/submit?url=' . get_the_permalink( $post->ID ) . '&title=' . get_the_title( $post->ID ) ) . '" rel="nofollow" target="_blank"><i class="fa fa-reddit" aria-hidden="true"></i></a></li>';
        
        break;                
    }
}
endif;

if ( ! function_exists( 'lawyer_landing_page_pro_entry_footer' ) ) :
/**
 * Prints edit links
 */
function lawyer_landing_page_pro_entry_footer() {	
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'lawyer-landing-page-pro' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_categorized_blog' ) ) :
/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function lawyer_landing_page_pro_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'lawyer_landing_page_pro_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'lawyer_landing_page_pro_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so lawyer_landing_page_pro_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so lawyer_landing_page_pro_categorized_blog should return false.
		return false;
	}
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_excerpt' ) ):  
/**
 * lawyer_landing_page_pro_excerpt can truncate a string up to a number of characters while preserving whole words and HTML tags
 *
 * @param string $text String to truncate.
 * @param integer $length Length of returned string, including ellipsis.
 * @param string $ending Ending to be appended to the trimmed string.
 * @param boolean $exact If false, $text will not be cut mid-word
 * @param boolean $considerHtml If true, HTML tags would be handled correctly
 *
 * @return string Trimmed string.
 * 
 * @link http://alanwhipple.com/2011/05/25/php-truncate-string-preserving-html-tags-words/
 */
function lawyer_landing_page_pro_excerpt($text, $length = 100, $ending = '...', $exact = false, $considerHtml = false) {
	$text = strip_shortcodes( $text );
    $text = lawyer_landing_page_pro_strip_single( 'img', $text );
    $text = lawyer_landing_page_pro_strip_single( 'a', $text );
    $text = lawyer_landing_page_pro_strip_single( 'b', $text );
    $text = lawyer_landing_page_pro_strip_single( 'i', $text );
    
    if ($considerHtml) {
		// if the plain text is shorter than the maximum length, return the whole text
		if (strlen(preg_replace('/<.*?>/', '', $text)) <= $length) {
			return $text;
		}
		// splits all html-tags to scanable lines
		preg_match_all('/(<.+?>)?([^<>]*)/s', $text, $lines, PREG_SET_ORDER);
		$total_length = strlen($ending);
		$open_tags = array();
		$truncate = '';
		foreach ($lines as $line_matchings) {
			// if there is any html-tag in this line, handle it and add it (uncounted) to the output
			if (!empty($line_matchings[1])) {
				// if it's an "empty element" with or without xhtml-conform closing slash
				if (preg_match('/^<(\s*.+?\/\s*|\s*(img|br|input|hr|area|base|basefont|col|frame|isindex|link|meta|param)(\s.+?)?)>$/is', $line_matchings[1])) {
					// do nothing
				// if tag is a closing tag
				} else if (preg_match('/^<\s*\/([^\s]+?)\s*>$/s', $line_matchings[1], $tag_matchings)) {
					// delete tag from $open_tags list
					$pos = array_search($tag_matchings[1], $open_tags);
					if ($pos !== false) {
					unset($open_tags[$pos]);
					}
				// if tag is an opening tag
				} else if (preg_match('/^<\s*([^\s>!]+).*?>$/s', $line_matchings[1], $tag_matchings)) {
					// add tag to the beginning of $open_tags list
					array_unshift($open_tags, strtolower($tag_matchings[1]));
				}
				// add html-tag to $truncate'd text
				$truncate .= $line_matchings[1];
			}
			// calculate the length of the plain text part of the line; handle entities as one character
			$content_length = strlen(preg_replace('/&[0-9a-z]{2,8};|&#[0-9]{1,7};|[0-9a-f]{1,6};/i', ' ', $line_matchings[2]));
			if ($total_length+$content_length> $length) {
				// the number of characters which are left
				$left = $length - $total_length;
				$entities_length = 0;
				// search for html entities
				if (preg_match_all('/&[0-9a-z]{2,8};|&#[0-9]{1,7};|[0-9a-f]{1,6};/i', $line_matchings[2], $entities, PREG_OFFSET_CAPTURE)) {
					// calculate the real length of all entities in the legal range
					foreach ($entities[0] as $entity) {
						if ($entity[1]+1-$entities_length <= $left) {
							$left--;
							$entities_length += strlen($entity[0]);
						} else {
							// no more characters left
							break;
						}
					}
				}
				$truncate .= substr($line_matchings[2], 0, $left+$entities_length);
				// maximum lenght is reached, so get off the loop
				break;
			} else {
				$truncate .= $line_matchings[2];
				$total_length += $content_length;
			}
			// if the maximum length is reached, get off the loop
			if($total_length>= $length) {
				break;
			}
		}
	} else {
		if (strlen($text) <= $length) {
			return $text;
		} else {
			$truncate = substr($text, 0, $length - strlen($ending));
		}
	}
	// if the words shouldn't be cut in the middle...
	if (!$exact) {
		// ...search the last occurance of a space...
		$spacepos = strrpos($truncate, ' ');
		if (isset($spacepos)) {
			// ...and cut the text in this position
			$truncate = substr($truncate, 0, $spacepos);
		}
	}
	// add the defined ending to the text
	$truncate .= $ending;
	if($considerHtml) {
		// close all unclosed html-tags
		foreach ($open_tags as $tag) {
			$truncate .= '</' . $tag . '>';
		}
	}
	return $truncate;
}
endif; // End function_exists

if( ! function_exists( 'lawyer_landing_page_pro_strip_single' ) ) :
/**
 * Strip specific tags from string
 * @link http://www.altafweb.com/2011/12/remove-specific-tag-from-php-string.html
*/
function lawyer_landing_page_pro_strip_single( $tag, $string ){
    $string = preg_replace('/<'.$tag.'[^>]*>/i', '', $string);
    $string = preg_replace('/<\/'.$tag.'>/i', '', $string);
    return $string;
} 
endif;

if( ! function_exists( 'lawyer_landing_page_pro_breadcrumb' ) ) :
/**
 * Breadcrumb 
*/
function lawyer_landing_page_pro_breadcrumb(){
    
    global $post;
    $post_page  = get_option( 'page_for_posts' ); //The ID of the page that displays posts.
    $show_front = get_option( 'show_on_front' ); //What to show on the front page    
    $home       = get_theme_mod( 'breadcrumb_home_text', __( 'Home', 'lawyer-landing-page-pro' ) ); // text for the 'Home' link
    $delimiter  = get_theme_mod( 'breadcrumb_separator', __( '/', 'lawyer-landing-page-pro' ) ); // delimiter between crumbs
    $before     = '<span class="current">'; // tag before the current crumb
    $after      = '</span>'; // tag after the current crumb
    
    if( get_theme_mod( 'ed_breadcrumb' ) && ! is_front_page() ){
        
        echo '<div id="crumbs"><a href="' . esc_url( home_url() ) . '">' . esc_html( $home ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
        
        if( is_home() ){
            
            echo $before . esc_html( single_post_title( '', false ) ) . $after;
            
        }elseif( is_category() ){
            
            $thisCat = get_category( get_query_var( 'cat' ), false );
            
            if( $show_front === 'page' && $post_page ){ //If static blog post page is set
                $p = get_post( $post_page );
                echo ' <a href="' . esc_url( get_permalink( $post_page ) ) . '">' . esc_html( $p->post_title ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';  
            }
            
            if ( $thisCat->parent != 0 ) echo get_category_parents( $thisCat->parent, TRUE, ' <span class="separator">' . $delimiter . '</span> ' );
            echo $before .  esc_html( single_cat_title( '', false ) ) . $after;
        
        }elseif( is_woocommerce_activated() && ( is_product_category() || is_product_tag() ) ){ //For Woocommerce archive page
        
            $current_term = $GLOBALS['wp_query']->get_queried_object();
            
            if ( wc_get_page_id( 'shop' ) ) { //Displaying Shop link in woocommerce archive page
    			$_name = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
                if ( ! $_name ) {
        			$product_post_type = get_post_type_object( 'product' );
        			$_name = $product_post_type->labels->singular_name;
        		}
                echo ' <a href="' . esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ) . '">' . esc_html( $_name ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
    		}

            if( is_product_category() ){
                $ancestors = get_ancestors( $current_term->term_id, 'product_cat' );
                $ancestors = array_reverse( $ancestors );
        		foreach ( $ancestors as $ancestor ) {
        			$ancestor = get_term( $ancestor, 'product_cat' );    
        			if ( ! is_wp_error( $ancestor ) && $ancestor ) {
        				echo ' <a href="' . esc_url( get_term_link( $ancestor ) ) . '">' . esc_html( $ancestor->name ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
        			}
        		}
            }           
            echo $before . esc_html( $current_term->name ) . $after;
            
        } elseif( is_woocommerce_activated() && is_shop() ){ //Shop Archive page
            if ( get_option( 'page_on_front' ) == wc_get_page_id( 'shop' ) ) {
    			return;
    		}
    		$_name = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
    
    		if ( ! $_name ) {
    			$product_post_type = get_post_type_object( 'product' );
    			$_name = $product_post_type->labels->singular_name;
    		}
            echo $before . esc_html( $_name ) . $after;
            
        }elseif( is_tag() ){
            
            echo $before . esc_html( single_tag_title( '', false ) ) . $after;
     
        }elseif( is_author() ){
            
            global $author;
            $userdata = get_userdata( $author );
            echo $before . esc_html( $userdata->display_name ) . $after;
     
        }elseif( is_search() ){
            
            echo $before . esc_html__( 'Search Results for "', 'lawyer-landing-page-pro' ) . esc_html( get_search_query() ) . esc_html__( '"', 'lawyer-landing-page-pro' ) . $after;
        
        }elseif( is_day() ){
            
            echo '<a href="' . esc_url( get_year_link( get_the_time( __( 'Y', 'lawyer-landing-page-pro' ) ) ) ) . '">' . esc_html( get_the_time( __( 'Y', 'lawyer-landing-page-pro' ) ) ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
            echo '<a href="' . esc_url( get_month_link( get_the_time( __( 'Y', 'lawyer-landing-page-pro' ) ), get_the_time( __( 'm', 'lawyer-landing-page-pro' ) ) ) ) . '">' . esc_html( get_the_time( __( 'F', 'lawyer-landing-page-pro' ) ) ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
            echo $before . esc_html( get_the_time( __( 'd', 'lawyer-landing-page-pro' ) ) ) . $after;
        
        }elseif( is_month() ){
            
            echo '<a href="' . esc_url( get_year_link( get_the_time( __( 'Y', 'lawyer-landing-page-pro' ) ) ) ) . '">' . esc_html( get_the_time( __( 'Y', 'lawyer-landing-page-pro' ) ) ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
            echo $before . esc_html( get_the_time( __( 'F', 'lawyer-landing-page-pro' ) ) ) . $after;
        
        }elseif( is_year() ){
            
            echo $before . esc_html( get_the_time( __( 'Y', 'lawyer-landing-page-pro' ) ) ) . $after;
    
        }elseif( is_single() && !is_attachment() ){
            
            if( is_woocommerce_activated() && 'product' === get_post_type() ){ //For Woocommerce single product
        		
        		if ( wc_get_page_id( 'shop' ) ) { //Displaying Shop link in woocommerce archive page
	    			$_name = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
	                if ( ! $_name ) {
	        			$product_post_type = get_post_type_object( 'product' );
	        			$_name = $product_post_type->labels->singular_name;
	        		}
	                echo ' <a href="' . esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ) . '">' . esc_html( $_name ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
	    		}
    		
                if ( $terms = wc_get_product_terms( $post->ID, 'product_cat', array( 'orderby' => 'parent', 'order' => 'DESC' ) ) ) {
        			$main_term = apply_filters( 'woocommerce_breadcrumb_main_term', $terms[0], $terms );
        			$ancestors = get_ancestors( $main_term->term_id, 'product_cat' );
                    $ancestors = array_reverse( $ancestors );
            		foreach ( $ancestors as $ancestor ) {
            			$ancestor = get_term( $ancestor, 'product_cat' );    
            			if ( ! is_wp_error( $ancestor ) && $ancestor ) {
            				echo ' <a href="' . esc_url( get_term_link( $ancestor ) ) . '">' . esc_html( $ancestor->name ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
            			}
            		}
        			echo ' <a href="' . esc_url( get_term_link( $main_term ) ) . '">' . esc_html( $main_term->name ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';
        		}
                
                echo $before . esc_html( get_the_title() ) . $after;
                
            }elseif ( get_post_type() != 'post' ){
                
                $post_type = get_post_type_object( get_post_type() );
                
                if( $post_type->has_archive == true ){// For CPT Archive Link
                   
                   // Add support for a non-standard label of 'archive_title' (special use case).
                   $label = !empty( $post_type->labels->archive_title ) ? $post_type->labels->archive_title : $post_type->labels->name;
                   printf( '<a href="%1$s">%2$s</a>', esc_url( get_post_type_archive_link( get_post_type() ) ), $label );
                   echo '<span class="separator">' . esc_html( $delimiter ) . '</span> ';
    
                }
                echo $before . esc_html( get_the_title() ) . $after;
                
            }else{ //For Post
                
                $cat_object       = get_the_category();
                $potential_parent = 0;
                
                if( $show_front === 'page' && $post_page ){ //If static blog post page is set
                    $p = get_post( $post_page );
                    echo ' <a href="' . esc_url( get_permalink( $post_page ) ) . '">' . esc_html( $p->post_title ) . '</a> <span class="separator">' . esc_html( $delimiter ) . '</span> ';  
                }
                
                if( is_array( $cat_object ) ){ //Getting category hierarchy if any
        
        			//Now try to find the deepest term of those that we know of
        			$use_term = key( $cat_object );
        			foreach( $cat_object as $key => $object )
        			{
        				//Can't use the next($cat_object) trick since order is unknown
        				if( $object->parent > 0  && ( $potential_parent === 0 || $object->parent === $potential_parent ) ){
        					$use_term = $key;
        					$potential_parent = $object->term_id;
        				}
        			}
                    
        			$cat = $cat_object[$use_term];
              
                    $cats = get_category_parents( $cat, TRUE, ' <span class="separator">' . esc_html( $delimiter ) . '</span> ' );
                    $cats = preg_replace( "#^(.+)\s$delimiter\s$#", "$1", $cats ); //NEED TO CHECK THIS
                    echo $cats;
                }
    
                echo $before . esc_html( get_the_title() ) . $after;
                
            }
        
        }elseif( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ){
            
            $post_type = get_post_type_object(get_post_type());
            if( get_query_var('paged') ){
                echo '<a href="' . esc_url( get_post_type_archive_link( $post_type->name ) ) . '">' . esc_html( $post_type->label ) . '</a>';
                echo ' <span class="separator">' . esc_html( $delimiter ) . '</span> ' . $before . sprintf( __('Page %s', 'lawyer-landing-page-pro'), get_query_var('paged') ) . $after;
            }else{
                echo $before . esc_html( $post_type->label ) . $after;
            }
    
        }elseif( is_attachment() ){
            
            $parent = get_post( $post->post_parent );
            $cat = get_the_category( $parent->ID ); 
            if( $cat ){
                $cat = $cat[0];
                echo get_category_parents( $cat, TRUE, ' <span class="separator">' . esc_html( $delimiter ) . '</span> ');
                echo '<a href="' . esc_url( get_permalink( $parent ) ) . '">' . esc_html( $parent->post_title ) . '</a>' . ' <span class="separator">' . esc_html( $delimiter ) . '</span> ';
            }
            echo  $before . esc_html( get_the_title() ) . $after;
        
        }elseif( is_page() && !$post->post_parent ){
            
            echo $before . esc_html( get_the_title() ) . $after;
    
        }elseif( is_page() && $post->post_parent ){
            
            $parent_id  = $post->post_parent;
            $breadcrumbs = array();
            
            while( $parent_id ){
                $page = get_post( $parent_id );
                $breadcrumbs[] = '<a href="' . esc_url( get_permalink( $page->ID ) ) . '">' . esc_html( get_the_title( $page->ID ) ) . '</a>';
                $parent_id  = $page->post_parent;
            }
            $breadcrumbs = array_reverse( $breadcrumbs );
            for ( $i = 0; $i < count( $breadcrumbs) ; $i++ ){
                echo $breadcrumbs[$i];
                if ( $i != count( $breadcrumbs ) - 1 ) echo ' <span class="separator">' . esc_html( $delimiter ) . '</span> ';
            }
            echo ' <span class="separator">' . esc_html( $delimiter ) . '</span> ' . $before . esc_html( get_the_title() ) . $after;
        
        }elseif( is_404() ){
            echo $before . esc_html__( '404 Error - Page Not Found', 'lawyer-landing-page-pro' ) . $after;
        }
        
        if( get_query_var('paged') ) echo __( ' (Page', 'lawyer-landing-page-pro' ) . ' ' . get_query_var('paged') . __( ')', 'lawyer-landing-page-pro' );
        
        echo '</div>';
        
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_pagination' ) ) :
/**
 * Pagination
*/
function lawyer_landing_page_pro_pagination(){
    
    if( is_single() ){
        the_post_navigation();
    }else{        
        $pagination = get_theme_mod( 'pagination_type', 'default' );
        
        switch( $pagination ){
            case 'default': // Default Pagination
            
            the_posts_navigation();
            
            break;
            
            case 'numbered': // Numbered Pagination
            
            the_posts_pagination( array(
                'prev_text'          => __( '<', 'lawyer-landing-page-pro' ),
                'next_text'          => __( '>', 'lawyer-landing-page-pro' ),
                'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'lawyer-landing-page-pro' ) . ' </span>',
             ) );
            
            break;
            
            case 'load_more': // Load More Button
            case 'infinite_scroll': // Auto Infinite Scroll
            
            echo '<div class="pagination"></div>';
            
            break;
            
            default:
            
            the_posts_navigation();
            
            break;
        }
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_section_header' ) ) :
/**
 * Returns Home Page Section header
*/
function lawyer_landing_page_pro_get_section_header( $section_title ){
    
    $header_query = new WP_Query( 
        array(
            'p' => $section_title,
            'post_type' => array( 'post', 'page' ),
        )
    );
        
    if( $section_title && $header_query->have_posts() ){ 
        while( $header_query->have_posts() ){ 
            $header_query->the_post(); ?>
    		<header class="header">
    			<?php 
                    the_title( '<h2 class="title">', '</h2>' );
                    if( has_excerpt() ){
                        the_excerpt();
                    }else{
                        the_content();    
                    }
                     
                ?>
    		</header>
            <?php   
        }
        wp_reset_postdata();
    }    
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_patterns' ) ) :
/**
 * Function to list Custom Pattern
*/
function lawyer_landing_page_pro_get_patterns(){
    $patterns = array();
    $patterns['nobg'] = get_template_directory_uri() . '/images/patterns_thumb/' . 'nobg.png';
    for( $i=0; $i<38; $i++ ){
        $patterns['pattern'.$i] = get_template_directory_uri() . '/images/patterns_thumb/' . 'pattern' . $i .'.png';
    }
    for( $j=1; $j<26; $j++ ){
        $patterns['hbg'.$j] = get_template_directory_uri() . '/images/patterns_thumb/' . 'hbg' . $j . '.png';
    }
    return $patterns;
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_dynamnic_sidebar' ) ) :
/**
 * Function to list dynamic sidebar
*/
function lawyer_landing_page_pro_get_dynamnic_sidebar( $nosidebar = false, $sidebar = false, $default = false ){
    $sidebar_arr = array();
    $sidebars = get_theme_mod( 'sidebar' );
    
    if( $default ) $sidebar_arr['default-sidebar'] = __( 'Default Sidebar', 'lawyer-landing-page-pro' );
    if( $sidebar ) $sidebar_arr['sidebar'] = __( 'Sidebar', 'lawyer-landing-page-pro' );
    
    if( $sidebars ){        
        foreach( $sidebars as $sidebar ){            
            $id = $sidebar['name'] ? sanitize_title( $sidebar['name'] ) : 'rara-sidebar-one';
            $sidebar_arr[$id] = $sidebar['name'];
        }
    }
    
    if( $nosidebar ) $sidebar_arr['no-sidebar'] = __( 'No Sidebar', 'lawyer-landing-page-pro' );
    
    return $sidebar_arr;
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_sidebar' ) ) :
/**
 * Function to retrive page specific sidebar and corresponding body class
 * 
 * @param boolean $sidebar
 * @param boolean $class
 * 
 * @return string dynamic sidebar id / classname
*/
function lawyer_landing_page_pro_sidebar( $sidebar = false, $class = false ){
    
    global $post;
    $return = false;
    $layout = get_theme_mod( 'layout_style', 'right-sidebar' ); //Default Layout Style for Styling Settings
    
    if( ( is_front_page() && is_home() ) || is_home() ){
        //blog/home page 
        $blog_sidebar = get_theme_mod( 'blog_page_sidebar', 'sidebar' );
        
        if( is_active_sidebar( $blog_sidebar ) ){            
            if( $sidebar ) $return = $blog_sidebar; //With Sidebar
            if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; 
            if( $class && $layout == 'left-sidebar' )  $return = 'leftsidebar';
        }else{
            if( $sidebar ) $return = false; //Fullwidth
            if( $class ) $return = 'full-width';
        }        
    }
    
    if( is_archive() ){
        //archive page
        $archive_sidebar = get_theme_mod( 'archive_page_sidebar', 'sidebar' );
        $cat_sidebar     = get_theme_mod( 'cat_archive_page_sidebar', 'default-sidebar' );
        $tag_sidebar     = get_theme_mod( 'tag_archive_page_sidebar', 'default-sidebar' );
        $date_sidebar    = get_theme_mod( 'date_archive_page_sidebar', 'default-sidebar' );
        $author_sidebar  = get_theme_mod( 'author_archive_page_sidebar', 'default-sidebar' );        
        
        if( is_category() ){
            
            if( $cat_sidebar == 'no-sidebar' || ( $cat_sidebar == 'default-sidebar' && $archive_sidebar == 'no-sidebar' ) ){
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }elseif( $cat_sidebar == 'default-sidebar' && $archive_sidebar != 'no-sidebar' && is_active_sidebar( $archive_sidebar ) ){
                if( $sidebar ) $return = $archive_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }elseif( is_active_sidebar( $cat_sidebar ) ){
                if( $sidebar ) $return = $cat_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }
                
        }elseif( is_tag() ){
            
            if( $tag_sidebar == 'no-sidebar' || ( $tag_sidebar == 'default-sidebar' && $archive_sidebar == 'no-sidebar' ) ){
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }elseif( ( $tag_sidebar == 'default-sidebar' && $archive_sidebar != 'no-sidebar' && is_active_sidebar( $archive_sidebar ) ) ){
                if( $sidebar ) $return = $archive_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }elseif( is_active_sidebar( $tag_sidebar ) ){
                if( $sidebar ) $return = $tag_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';              
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }
            
        }elseif( is_author() ){
            
            if( $author_sidebar == 'no-sidebar' || ( $author_sidebar == 'default-sidebar' && $archive_sidebar == 'no-sidebar' ) ){
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }elseif( ( $author_sidebar == 'default-sidebar' && $archive_sidebar != 'no-sidebar' && is_active_sidebar( $archive_sidebar ) ) ){
                if( $sidebar ) $return = $archive_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }elseif( is_active_sidebar( $author_sidebar ) ){
                if( $sidebar ) $return = $author_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }
            
        }elseif( is_date() ){
            
            if( $date_sidebar == 'no-sidebar' || ( $date_sidebar == 'default-sidebar' && $archive_sidebar == 'no-sidebar' ) ){
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }elseif( ( $date_sidebar == 'default-sidebar' && $archive_sidebar != 'no-sidebar' && is_active_sidebar( $archive_sidebar ) ) ){
                if( $sidebar ) $return = $archive_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }elseif( is_active_sidebar( $date_sidebar ) ){
                if( $sidebar ) $return = $date_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }                         
            
        }elseif( is_woocommerce_activated() && ( is_shop() || is_product_category() || is_product_tag() ) ){ //For Woocommerce
            
            if( is_active_sidebar( 'shop-sidebar' ) ){
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }else{
                if( $class ) $return = 'full-width';
            }            
                    
        }else{
            if( $archive_sidebar != 'no-sidebar' && is_active_sidebar( $archive_sidebar ) ){
                if( $sidebar ) $return = $archive_sidebar;
                if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }                      
        }
        
    }
    
    if( is_singular() ){
        $post_sidebar = get_theme_mod( 'single_post_sidebar', 'sidebar' );
        $page_sidebar = get_theme_mod( 'single_page_sidebar', 'sidebar' );
        
        if( get_post_meta( $post->ID, '_lawyer_landing_page_pro_sidebar', true ) ){
            $single_sidebar = get_post_meta( $post->ID, '_lawyer_landing_page_pro_sidebar', true );
        }else{
            $single_sidebar = 'default-sidebar';
        }

        if( get_post_meta( $post->ID, '_lawyer_landing_page_pro_sidebar_layout', true ) ){
            $sidebar_layout = get_post_meta( $post->ID, '_lawyer_landing_page_pro_sidebar_layout', true );
        }else{
            $sidebar_layout = 'default-sidebar';
        }
        
        if( is_page() ){
            
            if( ( $single_sidebar == 'no-sidebar' ) || ( ( $single_sidebar == 'default-sidebar' ) && ( $page_sidebar == 'no-sidebar' ) ) ){
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }elseif( $single_sidebar == 'default-sidebar' && $page_sidebar != 'no-sidebar' && is_active_sidebar( $page_sidebar ) ){
                if( $sidebar ) $return = $page_sidebar;
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'right-sidebar' ) || ( $sidebar_layout == 'right-sidebar' ) ) ) $return = 'rightsidebar';
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'left-sidebar' ) || ( $sidebar_layout == 'left-sidebar' ) ) ) $return = 'leftsidebar';
            }elseif( is_active_sidebar( $single_sidebar ) ){
                if( $sidebar ) $return = $single_sidebar;
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'right-sidebar' ) || ( $sidebar_layout == 'right-sidebar' ) ) ) $return = 'rightsidebar';
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'left-sidebar' ) || ( $sidebar_layout == 'left-sidebar' ) ) ) $return = 'leftsidebar';
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }
            
        }elseif( is_single() ){
            if( is_woocommerce_activated() && 'product' === get_post_type() ){
                if( is_active_sidebar( 'shop-sidebar' ) ){
                    if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
                    if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
                }else{
                    if( $class ) $return = 'full-width';
                }
            }elseif( ( $single_sidebar == 'no-sidebar' ) || ( ( $single_sidebar == 'default-sidebar' ) && ( $post_sidebar == 'no-sidebar' ) ) ){
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }elseif( $single_sidebar == 'default-sidebar' && $post_sidebar != 'no-sidebar' && is_active_sidebar( $post_sidebar ) ){
                if( $sidebar ) $return = $post_sidebar;
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'right-sidebar' ) || ( $sidebar_layout == 'right-sidebar' ) ) ) $return = 'rightsidebar';
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'left-sidebar' ) || ( $sidebar_layout == 'left-sidebar' ) ) ) $return = 'leftsidebar';
            }elseif( is_active_sidebar( $single_sidebar ) ){
                if( $sidebar ) $return = $single_sidebar;
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'right-sidebar' ) || ( $sidebar_layout == 'right-sidebar' ) ) ) $return = 'rightsidebar';
                if( $class && ( ( $sidebar_layout == 'default-sidebar' && $layout == 'left-sidebar' ) || ( $sidebar_layout == 'left-sidebar' ) ) ) $return = 'leftsidebar';
            }else{
                if( $sidebar ) $return = false; //Fullwidth
                if( $class ) $return = 'full-width';
            }
        }
    }
    
    if( is_search() ){
        $search_sidebar = get_theme_mod( 'search_page_sidebar', 'sidebar' );
                
        if( $search_sidebar != 'no-sidebar' && is_active_sidebar( $search_sidebar ) ){
            if( $sidebar ) $return = $search_sidebar;
            if( $class && $layout == 'right-sidebar' ) $return = 'rightsidebar'; //With Sidebar
            if( $class && $layout == 'left-sidebar' ) $return = 'leftsidebar';
        }else{
            if( $sidebar ) $return = false; //Fullwidth
            if( $class ) $return = 'full-width';
        }
        
    }
    
    return $return;        
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_categories' ) ) :
/**
 * Function to list post categories in customizer options
*/
function lawyer_landing_page_pro_get_categories( $select = true, $taxonomy = 'category', $slug = false ){
    
    /* Option list of all categories */
    $categories = array();
    
    $args = array( 
        'hide_empty' => false,
        'taxonomy'   => $taxonomy 
    );
    
    $catlists = get_terms( $args );
    if( $select ) $categories[''] = __( 'Choose Category', 'lawyer-landing-page-pro' );
    foreach( $catlists as $category ){
        if( $slug ){
            $categories[$category->slug] = $category->name;
        }else{
            $categories[$category->term_id] = $category->name;    
        }        
    }
    
    return $categories;
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_posts' ) ) :
/**
 * Fuction to list Custom Post Type
*/
function lawyer_landing_page_pro_get_posts( $post_type = 'post' ){
    
    $args = array(
    	'posts_per_page'   => -1,
    	'post_type'        => $post_type,
    	'post_status'      => 'publish',
    	'suppress_filters' => true 
    );
    $posts_array = get_posts( $args );
    
    // Initate an empty array
    $post_options = array();
    $post_options[''] = __( ' -- Choose -- ', 'lawyer-landing-page-pro' );
    if ( ! empty( $posts_array ) ) {
        foreach ( $posts_array as $posts ) {
            $post_options[ $posts->ID ] = $posts->post_title;
        }
    }
    return $post_options;
    wp_reset_postdata();
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_create_post' ) ) :
/**
 * A function used to programmatically create a post and assign a page template in WordPress. 
 *
 * @link https://tommcfarlin.com/programmatically-create-a-post-in-wordpress/
 * @link https://tommcfarlin.com/programmatically-set-a-wordpress-template/
 */
function lawyer_landing_page_pro_create_post( $title, $slug, $template ) {

	// Setup the author, page
	$author_id = 1;
    
    // Look for the page by the specified title. Set the ID to -1 if it doesn't exist.
    // Otherwise, set it to the page's ID.
    $page = get_page_by_title( $title, OBJECT, 'page' );
    $page_id = ( null == $page ) ? -1 : $page->ID;
    
	// If the page doesn't already exist, then create it
	if( $page_id == -1 ) {

		// Set the post ID so that we know the post was created successfully
		$post_id = wp_insert_post(
			array(
				'comment_status' =>	'closed',
				'ping_status'	 =>	'closed',
				'post_author'	 =>	$author_id,
				'post_name'		 =>	$slug,
				'post_title'	 =>	$title,
				'post_status'	 =>	'publish',
				'post_type'		 =>	'page'
			)
		);
        
        if( $post_id ) update_post_meta( $post_id, '_wp_page_template', $template );

	// Otherwise, we'll stop
	}else{
	   update_post_meta( $page_id, '_wp_page_template', $template );
	} // end if

} // end programmatically_create_post
endif;


if( ! function_exists( 'lawyer_landing_page_pro_get_template_page_url' ) ) :
    /**
     * Fuction to return page url
    */
    function lawyer_landing_page_pro_get_template_page_url( $template_key = '', $post_type = 'page' ){

        if( ! empty( $template_key ) ){
            $args = array(
                'meta_key'      => '_wp_page_template',
                'meta_value'    => $template_key,
                'post_type'     => $post_type,
            );

            $posts_array = get_posts( $args );

            if ( ! empty( $posts_array ) ) {
                foreach ( $posts_array as $posts ) {
                    $post_options[ $posts->ID ] = $posts->ID;    
                    $page_template_url = get_permalink( $post_options[ $posts->ID ] );
                    return $page_template_url;
                }
            }
        } else {
            return false;
        }
    }
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_title' ) ) :
/**
 * Get page title for about page template
*/
function lawyer_landing_page_pro_get_title( $title ){
    $e_title = '';
    $arr = explode(' ', $title);
   
    $count = count($arr);
    if( $count > 1 ){
        for($i=0;$i<$count;$i++){
            if( $i > 0 && $i == $count-1 ){
                $e_title .= '<span>';
            }
            $e_title .= $arr[$i];
            if($i < $count){
                $e_title .= ' ';
            }                        
            if( $i > 0 && $i == $count-1 ){
                $e_title .= '</span>';
            }
        }
        return apply_filters( 'llpp_title', $e_title );
    }else{
        return apply_filters( 'llpp_title', $title );
    }
    //return $title
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_clients' ) ) :
/**
 * Query for Client Logos
*/
function lawyer_landing_page_pro_get_clients( $category ){
    $args = array(
        'post_type'       => 'logo',
        'post_status'     => 'publish',
        'posts_per_page'  => -1,
        'logo_categories' => $category  
    );
    
    $qry = new WP_Query( $args );
    
    if( $qry->have_posts() ){
        echo '<div id="clients-holder" class="owl-carousel">';
        while( $qry->have_posts() ){
            $qry->the_post();
            $link = get_post_meta( get_the_ID(), '_lawyer_landing_page_pro_logo_link', true );
            ?>
            <div class="col">
				<div class="img-holder">
                    <?php 
                        if( $link ) echo '<a href="' . esc_url( $link ) . '" title="' . esc_attr( get_the_title() ) . '">';
                        the_post_thumbnail( 'full', array( 'itemprop' => 'image' )  );					
                        if( $link ) echo '</a>'; 
                    ?>
				</div>
			</div>
            <?php
        }
        echo '</div>';
    }
    wp_reset_postdata();
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_static_banner' ) ) :
/**
 * Query for Static Banner 
*/
function lawyer_landing_page_pro_get_static_banner(){
    
    $show_on_front = get_option( 'show_on_front' );
    $page_on_front = get_option( 'page_on_front' );
    $banner_form   = get_theme_mod( 'banner_form' );
    $demo_content  = get_theme_mod( 'ed_demo', '1' );
    
    if( is_front_page() && $show_on_front == 'page' && $page_on_front ){
        $banner_qry = new WP_Query( "page_id=$page_on_front" );
        if( $banner_qry->have_posts() ){
            while( $banner_qry->have_posts() ){
                $banner_qry->the_post();
                
                $banner_image = wp_get_attachment_image_url( get_post_thumbnail_id(), 'lawyer-landing-page-banner' );
                $style = ' style="background: url(' . esc_url( $banner_image ) . '); background-size: cover; background-position: center;"';
                
                if( has_post_thumbnail() ){ ?>
                    <section id="banner_section" class="banner"<?php echo $style; ?>>
                    	<div class="container">                    		
                            <div class="text">			
                    			<?php 
                                    the_title( '<h2 class="title">', '</h2>' );
                                    the_content(); 
                                ?>
                    		</div>                    		
                            <?php        
                                if( is_cf7_activated() && $banner_form ){
                                    echo do_shortcode( $banner_form );
                                }
                            ?>                            
                    	</div>
                    </section>    
                    <?php
                }elseif( $demo_content ){
                    /** Default Content */
                    lawyer_landing_page_pro_demo_content( 'banner' ); 
                }
            }
        }
        wp_reset_postdata();
    }    
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_banner_slider' ) ) :
/**
 * Query for Banner Slider
*/
function lawyer_landing_page_pro_get_banner_slider(){
    
    if( is_front_page() && get_theme_mod( 'ed_banner_section', 'static_banner' ) === 'slider_banner' ){
        
        $slider_caption    = get_theme_mod( 'slider_caption', '1' );
        $slider_type       = get_theme_mod( 'slider_type', 'post' ); 
        $slider_post_one   = get_theme_mod( 'slider_post_one' );
        $slider_post_two   = get_theme_mod( 'slider_post_two' );
        $slider_post_three = get_theme_mod( 'slider_post_three' );
        $slider_post_four  = get_theme_mod( 'slider_post_four' );
        $slider_post_five  = get_theme_mod( 'slider_post_five' );
        $slider_cat        = get_theme_mod( 'slider_cat' );
        $slider_slides     = get_theme_mod( 'slider_custom' );
        $slider_readmore   = get_theme_mod( 'slider_readmore', __( 'Read More', 'lawyer-landing-page-pro' ) );
        $slider_full_img   = get_theme_mod( 'slider_full_image' );
        
        $slider_posts      = array( $slider_post_one, $slider_post_two, $slider_post_three, $slider_post_four, $slider_post_five );
        $slider_posts      = array_diff( array_unique( $slider_posts ), array('') );
        
        if( $slider_full_img ){
            $img_size = 'full';
        }else{
            $img_size = 'lawyer-landing-page-banner';
        }
        
        if( $slider_type == 'post' || $slider_type == 'cat' ){
            
            $args = array(
                'post_status'         => 'publish',
                'posts_per_page'      => -1,       
                'orderby'             => 'post__in',
                'ignore_sticky_posts' => true
            );
            
            if( $slider_type == 'post' ){
                $args['post_type'] = array( 'post', 'page' );
                $args['post__in']  = $slider_posts;
                $args['orderby']   = 'post__in';
            }elseif( $slider_type == 'cat' ){
                $args['post_type'] = 'post';
                $args['cat']       = $slider_cat;
            }
            
            $qry = new WP_Query( $args );
            
            if( ( ( $slider_posts && $slider_type == 'post' ) || ( $slider_cat && $slider_type == 'cat' ) ) && $qry->have_posts() ){ ?>
                <section id="banner_section" class="banner bslider">
                    <div class="banner-slider owl-theme owl-carousel">
                    <?php    
                    while( $qry->have_posts() ){
                        $qry->the_post();
                        if( has_post_thumbnail() ){ 
                        $image = wp_get_attachment_image_url( get_post_thumbnail_id(), $img_size );     
                        ?>
                        <div>
            				<img class="owl-lazy" data-src="<?php echo esc_url( $image )?>" alt="<?php the_title_attribute(); ?>" />
                            <?php if( $slider_caption && ( get_the_title() || get_the_content() || $slider_readmore ) ){ ?>
            				<div class="banner-text">
            					<div class="container">
            						<div class="table">
            							<div class="table-row">
            								<div class="table-cell">
            									<div class="text-holder">
                                                    <?php 
                                                        if( get_the_title() ) the_title( '<strong class="title">', '</strong>' );
                                                        if( get_the_content() ) echo wpautop( wp_kses_post( force_balance_tags( lawyer_landing_page_pro_excerpt( get_the_content(), 100 ) ) ) ); 
                                                        if( $slider_readmore ) echo '<a href="' . esc_url( get_the_permalink() ) . '" class="btn">' . esc_html( $slider_readmore ) .'</a>';
                                                    ?>
            									</div>
            								</div>
            							</div>
            						</div>
            					</div>
            				</div>
                            <?php } ?>
            			</div>
                        <?php
                        }
                    }
                    ?>
                    </div>
            	</section>
                <?php
            }
            
        }elseif( $slider_type == 'custom' && $slider_slides ){ ?>
            <section id="banner_section" class="banner bslider">
                <div class="banner-slider owl-theme owl-carousel">
                    <?php 
                    foreach( $slider_slides as $slide ){
                        if( $slide['thumbnail'] ){
                        $images = wp_get_attachment_image_url( $slide['thumbnail'], $img_size );
                        ?>
                        <div>
                            <img class="owl-lazy" data-src="<?php echo esc_url( $images ); ?>" alt="<?php echo esc_attr( $slide['title'] ); ?>" />
            				<?php if( $slider_caption && ( $slide['title'] || $slide['content'] || ( $slide['link'] && $slider_readmore ) ) ){ ?>
                                <div class="banner-text">
                					<div class="container">
                						<div class="table">
                							<div class="table-row">
                								<div class="table-cell">
                									<div class="text-holder">
                										<?php 
                                                            if( $slide['title'] ) echo '<strong class="title">' . esc_html( $slide['title'] ) . '</strong>';
                                                            if( $slide['content'] ) echo wpautop( wp_kses_post( $slide['content'] ) );
                                                            if( $slide['link'] && $slider_readmore ) echo '<a href="' . esc_url( $slide['link'] ) . '" class="btn">' . esc_html( $slider_readmore ) . '</a>';
                                                        ?>
                									</div>
                								</div>
                							</div>
                						</div>
                					</div>
                				</div>
                            <?php } ?>
            			</div>
                        <?php 
                        }
                    }
                    ?>
                </div>
			</section>
        <?php
        }
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_portfolio_buttons' ) ) :
/**
 * Query for Portfolio Buttons
*/
function lawyer_landing_page_pro_get_portfolio_buttons( $home = false ){
    if( taxonomy_exists( 'portfolio_categories' ) ){
        if( $home ){
            $no_of_portfolio = (int) get_theme_mod( 'no_of_portfolio', '6' );
            $s = '';
            $i = 0;
            $portfolio_posts = get_posts( array( 'post_type' => 'portfolio', 'post_status' => 'publish', 'posts_per_page' => $no_of_portfolio ) );
            foreach( $portfolio_posts as $portfolio ){
                $terms = get_the_terms( $portfolio->ID, 'portfolio_categories' );
                if( $terms ){
                    foreach( $terms as $term ){
                        $i++;
                        $s .= $term->term_id;
                        $s .= ', ';    
                    }
                }
            }
            $term_ids = explode( ', ', $s );
            $term_ids = array_diff( array_unique( $term_ids ), array('') );
            wp_reset_postdata();//Reseting get_posts            
        }
        
        $args = array(
            'taxonomy'      => 'portfolio_categories',
            'orderby'       => 'name', 
            'order'         => 'ASC',
        );                
        $terms = get_terms( $args );
        if( $terms ){
        ?>
        <div class="button-group filter-button-group">        
            <button data-filter="*" class="is-checked"><?php echo esc_html_e( 'All', 'lawyer-landing-page-pro' ); ?></button><!-- This is HACK for reducing space between inline block elements.
            --><?php
                foreach( $terms as $t ){
                    if( $home ){
                        if( in_array( $t->term_id, $term_ids ) )
                        echo '<button data-filter=".' . esc_attr( $t->slug ) .  '">' . esc_html( $t->name ) . '</button>';
                    }else{
                        echo '<button data-filter=".' . esc_attr( $t->slug ) .  '">' . esc_html( $t->name ) . '</button>';    
                    } 
                    
                } 
            ?>
        </div>            
        <?php
        }
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_portfolios' ) ) :
/**
 * Query for portfolios 
*/
function lawyer_landing_page_pro_get_portfolios( $no_of_portfolio = -1 ){
    $portfolio_qry = new WP_Query( array( 'post_type' => 'portfolio', 'post_status' => 'publish', 'posts_per_page' => $no_of_portfolio ) );
    if( taxonomy_exists( 'portfolio_categories' ) && $portfolio_qry->have_posts() ){ ?>
                        
        <div class="row grid">
    		<?php
            while( $portfolio_qry->have_posts() ){
                $portfolio_qry->the_post();
                $terms = get_the_terms( get_the_ID(), 'portfolio_categories' );
                $s = '';
                $i = 0;
                if( $terms ){
                    foreach( $terms as $t ){
                        $i++;
                        $s .= $t->slug;
                        if( count( $terms ) > $i ){
                            $s .= ' ';
                        }
                    }
                }                    
                if( has_post_thumbnail() ){
                ?>
                <div class="col <?php echo esc_attr( $s );?>">
    				<div class="img-holder">
    					<?php the_post_thumbnail( 'lawyer-landing-page-portfolio', array( 'itemprop' => 'image' ) ); ?>
    					<div class="text-holder">
    						<div class="table">
    							<div class="table-row">
    								<div class="table-cell">
    									<a href="<?php the_permalink(); ?>"><i class="fa fa-link" aria-hidden="true"></i></a>
    								</div>
    							</div>
    						</div>
    					</div>
    				</div>
    				<strong><?php the_title(); ?></strong>
    			</div>
    		    <?php
                }
            }
            ?>
    	</div><!-- .row .grid -->
        <?php
        wp_reset_postdata(); 
    } 
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_site_branding' ) ) :
/**
 * Site Branding
*/
function lawyer_landing_page_pro_site_branding(){ ?>
    <div class="site-branding" itemscope itemtype="http://schema.org/Organization">
        <?php 
	        if( function_exists( 'has_custom_logo' ) && has_custom_logo() ){
                the_custom_logo();
            } 
        ?>
		<div class="text-logo">
            <?php if ( is_front_page() ) : ?>
                <h1 class="site-title" itemprop="name"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" itemprop="url"><?php bloginfo( 'name' ); ?></a></h1>
            <?php else : ?>
                <p class="site-title" itemprop="name"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" itemprop="url"><?php bloginfo( 'name' ); ?></a></p>
            <?php endif;
			$description = get_bloginfo( 'description', 'display' );
			if ( $description || is_customize_preview() ) : ?>
				<p class="site-description" itemprop="description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
			<?php
			endif; ?>
        </div>
    </div><!-- .site-branding -->
    <?php       
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_header_phone' ) ) :
/**
 * Header Phone
*/
function lawyer_landing_page_pro_header_phone( $layout ){
    $phone = get_theme_mod( 'phone', __( '(888) 123-45678', 'lawyer-landing-page-pro' ) ); // from customizer
    $label = get_theme_mod( 'phone_label', __( 'Free Case Consultation', 'lawyer-landing-page-pro' ) );
    
    $layout_array = array( 'two', 'four', 'five', 'eight', 'nine' );
    $layout_arry1 = array( 'two', 'four', 'nine' );
    $layout_arry2 = array( 'five', 'eight' );
    
    if( in_array( $layout, $layout_array ) ) echo '<div class="phone">';
    if( in_array( $layout, $layout_arry1 ) ) echo '<span>' . esc_html( $label ) . '</span>';    
    if( $phone ) echo '<a href="tel:' . preg_replace('/\D/', '', $phone) . '" class="tel-link">' . esc_html( $phone ) . '</a>';
    if( in_array( $layout, $layout_arry2 ) ) echo '<span>' . esc_html( $label ) . '</span>';
    if( in_array( $layout, $layout_array ) ) echo '</div>';
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_header_social' ) ) :
/**
 * Header Social Icons
*/
function lawyer_landing_page_pro_header_social(){
    if( is_active_sidebar( 'header-social' ) ) dynamic_sidebar( 'header-social' );
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_primary_nav' ) ) :
/**
 * Primary Navigation
*/
function lawyer_landing_page_pro_primary_nav(){ 
    $enabled_section = array();
    $ed_section_menu = get_theme_mod( 'ed_section_menu' );
    $ed_home_link    = get_theme_mod( 'ed_home_link', '1' );
    $home_sections   = get_theme_mod( 'sort_home_section', array( 'banner','about', 'practice', 'why', 'service', 'stat', 'portfolio', 'testimonial', 'promotional', 'team', 'faq', 'blog', 'client', 'contact' ) );
    
    $menu_about       = get_theme_mod( 'section_menu_about', __( 'About', 'lawyer-landing-page-pro' ) );
    $menu_practice    = get_theme_mod( 'section_menu_practice', __( 'Practices', 'lawyer-landing-page-pro' ) );
    $menu_why_us      = get_theme_mod( 'section_menu_why_us', __( 'Why Us', 'lawyer-landing-page-pro' ) );
    $menu_service     = get_theme_mod( 'section_menu_service', __( 'Services', 'lawyer-landing-page-pro' ) );
    $menu_portfolio   = get_theme_mod( 'section_menu_portfolio', __( 'Portfolio', 'lawyer-landing-page-pro' ) );
    $menu_testimonial = get_theme_mod( 'section_menu_testimonial', __( 'Testimonials', 'lawyer-landing-page-pro' ) );
    $menu_team        = get_theme_mod( 'section_menu_team', __( 'Team', 'lawyer-landing-page-pro' ) );
    $menu_faq         = get_theme_mod( 'section_menu_faq', __( 'FAQs', 'lawyer-landing-page-pro' ) );
    $menu_blog        = get_theme_mod( 'section_menu_blog', __( 'Blog', 'lawyer-landing-page-pro' ) );
    $menu_client      = get_theme_mod( 'section_menu_client', __( 'Clients', 'lawyer-landing-page-pro' ) );
    $menu_contact     = get_theme_mod( 'section_menu_contact', __( 'Contact', 'lawyer-landing-page-pro' ) );
    
    $menu_label = array();
    if( get_theme_mod( 'ed_section_menu_about', '1' ) ) $menu_label['about'] = ! empty( $menu_about ) ? $menu_about : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'about_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_practice', '1' ) ) $menu_label['practice'] = ! empty( $menu_practice ) ? $menu_practice : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'pratice_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_whyus' ) ) $menu_label['why'] = ! empty( $menu_why_us ) ? $menu_why_us : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'why_us_page' ) );
    if( get_theme_mod( 'ed_section_menu_service', '1' ) ) $menu_label['service'] = ! empty( $menu_service ) ? $menu_service : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'service_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_portfolio', '1' ) ) $menu_label['portfolio'] = ! empty( $menu_portfolio ) ? $menu_portfolio : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'portfolio_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_testimonial', '1' ) ) $menu_label['testimonial'] = ! empty( $menu_testimonial ) ? $menu_testimonial : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'testimonial_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_team', '1' ) ) $menu_label['team'] = ! empty( $menu_team ) ? $menu_team : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'team_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_faq', '1' ) ) $menu_label['faq'] = ! empty( $menu_faq ) ? $menu_faq : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'faq_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_blog', '1' ) ) $menu_label['blog'] = ! empty( $menu_blog ) ? $menu_blog : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'blog_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_client' ) ) $menu_label['client'] = ! empty( $menu_client ) ? $menu_client : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'client_section_page' ) );
    if( get_theme_mod( 'ed_section_menu_contact', '1' ) ) $menu_label['contact'] = ! empty( $menu_contact ) ? $menu_contact : lawyer_landing_page_pro_get_menu_title( get_theme_mod( 'contact_section_page' ) );
        
    foreach( $home_sections as $section ){
        if( array_key_exists( $section, $menu_label ) ){
            $enabled_section[] = array(
                'id'    => $section . '_section',
                'label' => $menu_label[$section],
            );
        }
    }
    if( $ed_section_menu && ( 'page' == get_option( 'show_on_front' ) ) && $enabled_section ){ ?>
        <nav id="site-navigation" class="main-navigation" role="navigation" itemscope itemtype="http://schema.org/SiteNavigationElement">
            <ul>
                <?php if( $ed_home_link ){ ?>
                <li class="<?php if( is_front_page() ) echo esc_attr( 'current-menu-item' ); ?>"><a href="<?php echo esc_url( home_url( '#banner_section' ) ); ?>"><?php esc_html_e( 'Home', 'lawyer-landing-page-pro' ); ?></a></li>
            <?php }
                foreach( $enabled_section as $section ){ 
                    if( $section['label'] ){
            ?>
                    <li><a href="<?php echo esc_url( home_url( '#' . esc_attr( $section['id'] ) ) ); ?>"><?php echo esc_html( $section['label'] );?></a></li>                        
            <?php 
                    } 
                }
            ?>
            </ul>
        </nav>
        <?php
    }else{
    ?>
    <nav id="site-navigation" class="main-navigation" role="navigation">
	   <?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
    </nav>
    <?php
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_secondary_nav' ) ) :
/**
 * Secondary Navigation
*/
function lawyer_landing_page_pro_secondary_nav(){ 
    if( has_nav_menu( 'secondary' ) ){
    ?>
    <div id="mobile-header">
	    <a id="responsive-menu-button" href="#sidr-main">
	    	<i class="fa fa-bars"></i>
	    </a>
	</div>
	<nav id="secondary-navigation" class="secondary-nav" role="navigation">
		<?php wp_nav_menu( array( 'theme_location' => 'secondary', 'menu_id' => 'secondary-menu', 'fallback_cb' => false ) ); ?>
	</nav>
    <?php
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_search_form' ) ) :
/**
 * Header Search Form
*/
function lawyer_landing_page_pro_search_form( $wrap = false ){
    $ed_search_form = get_theme_mod( 'ed_search', '1' );
    
    if( $ed_search_form ){
        if( ! $wrap ){ ?>
        <div class="form-section">
            <a href="javascript:void(0);" id="search-btn"><i class="fa fa-search"></i></a>
            <div class="form-holder">
            <?php }
             
    		get_search_form();
            
        if( ! $wrap ){ ?>
    	   </div>
        </div>
        <?php
        }
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_request_btn' ) ) :
/**
 * Header Request Button
*/
function lawyer_landing_page_pro_request_btn(){
    
    $buton_label = get_theme_mod( 'button_label', __( 'Consultation Request', 'lawyer-landing-page-pro' ) );
    $ed_int_link = get_theme_mod( 'ed_internal_link' );    
    $button_url  = get_theme_mod( 'button_url', '#' );
    $button_post = get_theme_mod( 'button_post' );
    
    if( $ed_int_link ){
        $url = get_permalink( $button_post );
    }else{
        $url = $button_url;
    }
    
    if( $buton_label && ( ( $button_url && ! $ed_int_link ) || ( $button_post && $ed_int_link ) ) ){
        echo '<a href="' . esc_url( $url ) . '" class="btn-request">' . esc_html( $buton_label ) . '</a>';
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_menu_title' ) ) :
/**
 * Function to return page/post tile
*/
function lawyer_landing_page_pro_get_menu_title( $p ){
    $title = get_post( $p );
    return $title->post_title;
}
endif;

if( !function_exists( 'lawyer_landing_page_pro_cpt_has_archive' ) ) :
/**
 * Check if post type supports an archive
 *
 * @param string $post_type post type name
 * @uses get_post_type
 * @global object $post
 * @returns boolean
 * @link https://joshuadnelson.com/code/check-if-post-type-supports-archives/
 */
function lawyer_landing_page_pro_cpt_has_archive( $post_type ) {
	if( !is_string( $post_type ) || !isset( $post_type ) )
		return false;
	
	// find custom post types with archvies
	$args = array(
		'has_archive'	=> true,
		'_builtin'	=> false,
	);
	$output = 'names';
	$archived_custom_post_types = get_post_types( $args, $output );
	
	// if there are no custom post types, then the current post can't be one
	if( empty( $archived_custom_post_types ) )
		return false;
	
	// check if post type is a supports archives
	if ( in_array( $post_type, $archived_custom_post_types ) ) {
	        return true;
	} else {
	        return false;
	}
	
	// if all else fails, return false
	return false;	
	
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_truncate' ) ):  
/**
 * Return Striptags from the content.
 */
function lawyer_landing_page_pro_truncate( $content, $letter_count ) {
	
    $striped_content = strip_shortcodes( $content );
    $striped_content = strip_tags( $striped_content );
    $excerpt         = mb_substr( $striped_content, 0, $letter_count );
    
    if( $striped_content > $excerpt ){
        $excerpt .= '...';
    }
    
    return $excerpt;

}
endif; // End function_exists

if ( ! function_exists( 'lawyer_landing_page_pro_apply_theme_shortcode' ) ) :
    /**
     * Footer Shortcode
    */
    function lawyer_landing_page_pro_apply_theme_shortcode( $string ) {
        if ( empty( $string ) ) {
            return $string;
        }
        $search_shortcode = '[the-year]';
        $replace_string   = date( 'Y' );
        $string           = str_replace( $search_shortcode, $replace_string, $string );

        return $string;
    }
endif;

function lawyer_landing_page_pro_remove_meta_box(){
	 remove_meta_box( 'rttk_faq_id', 'faq', 'side' );
	 remove_meta_box( 'rttk_logo_id', 'logo', 'side' );
	 remove_meta_box( 'rttk_practice_id', 'practice', 'side' );
	 remove_meta_box( 'rttk_service_id', 'service', 'side' );
	 remove_meta_box( 'rttk_portfolio_id', 'portfolio', 'side' );
}
add_action( 'do_meta_boxes', 'lawyer_landing_page_pro_remove_meta_box' );

/**
 * Query for Rara theme toolkit 
 */
function is_rara_toolkit_activated(){
    return class_exists( 'Rara_Theme_Toolkit_Pro' ) ? true : false;
}

/**
 * Query Contact Form 7
 */
function is_cf7_activated() {
	return class_exists( 'WPCF7' ) ? true : false;
}

/**
 * Query Jetpack activation
*/
function is_jetpack_activated( $gallery = false ){
	if( $gallery ){
        return ( class_exists( 'jetpack' ) && Jetpack::is_module_active( 'tiled-gallery' ) ) ? true : false;
	}else{
        return class_exists( 'jetpack' ) ? true : false;
    }           
}

/**
 * Query WooCommerce activation
 */
function is_woocommerce_activated() {
	return class_exists( 'woocommerce' ) ? true : false;
}

if( ! function_exists( 'lawyer_landing_page_pro_escape_text_tags' ) ) :
/**
 * Remove new line tags from string
 *
 * @param $text
 * @return string
 */
function lawyer_landing_page_pro_escape_text_tags( $text ) {
    return (string) str_replace( array( "\r", "\n" ), '', strip_tags( $text ) );
}
endif;