<?php
/**
 * Custom template functions for this theme.
 *
 * @package Lawyer_Landing_Page_Pro
 */

if( ! function_exists( 'lawyer_landing_page_pro_doctype_cb' ) ) :
/**
 * Doctype Declaration
*/
function lawyer_landing_page_pro_doctype_cb(){
    ?>
    <!DOCTYPE html>
    <html <?php language_attributes(); ?>>
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_head' ) ) :
/**
 * Before wp_head 
*/
function lawyer_landing_page_pro_head(){
    ?>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_page_start' ) ) :
/**
 * Page Start
*/
function lawyer_landing_page_pro_page_start(){
    ?>
    <div id="page" class="site">
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_header' ) ) :
/**
 * Header Start
*/
function lawyer_landing_page_pro_header(){
    $header_array = array( 'one', 'two', 'three', 'four', 'five', 'six', 'seven', 'eight', 'nine' );
    $header = get_theme_mod( 'header_layout', 'one' );
    if( in_array( $header, $header_array ) ){            
        get_template_part( 'headers/' . $header );
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_pg_header' ) ) :
/**
 * Page Header for inner pages
*/
function lawyer_landing_page_pro_pg_header(){    
    if( ! is_front_page() ){
        
        $ed_bc = get_theme_mod( 'ed_breadcrumb' ); //from customizer
    
        if( is_single() ){ 
            if( $ed_bc ){ ?>
            
            <div class="top-bar">
        		<div class="container">
                    <?php lawyer_landing_page_pro_breadcrumb(); // breadcrumb ?>
                </div>
            </div>
            
        <?php   
            }
        }else{
            ?>
            <!-- Page Header for inner pages only -->
            <div class="top-bar">
        		<div class="container">
                
                    <header class="page-header">
                        <h1 class="page-title">
                        <?php                
                        
                            if( is_home() ) single_post_title();
                            
                            if( is_page() ) the_title(); //For Page, Post & Attachment
                            
                            if( is_search() ) printf( esc_html__( 'Search Results for "%s"', 'lawyer-landing-page-pro' ), get_search_query() ); 
                            
                            if( is_404() ) echo esc_html__( '404 - Page not Found', 'lawyer-landing-page-pro' ); //For 404
                            
                            /** For Woocommerce */
                            if( is_woocommerce_activated() && ( is_product_category() || is_product_tag() || is_shop() ) ){
                                if( is_shop() ){
                                    if ( get_option( 'page_on_front' ) == wc_get_page_id( 'shop' ) ) {
                                		return;
                                	}
                                	$_name = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
                                
                                	if ( ! $_name ) {
                                		$product_post_type = get_post_type_object( 'product' );
                                		$_name = $product_post_type->labels->singular_name;
                                	}
                                    echo esc_html( $_name );
                                }elseif( is_product_category() || is_product_tag() ){
                                    $current_term = $GLOBALS['wp_query']->get_queried_object();
                                    echo esc_html( $current_term->name );
                                }
                            }else{
                                if( is_archive() ) the_archive_title();
                            }
                        ?>
                        </h1>
                    </header>
                    
                    <?php lawyer_landing_page_pro_breadcrumb(); // breadcrumb ?>
                    
        		</div>
        	</div>
        <?php
        }
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_banner_section' ) ) :
/**
 * Banner Section
*/
function lawyer_landing_page_pro_banner_section(){    
    $banner_option = get_theme_mod( 'ed_banner_section', 'static_banner' );
    
    if( $banner_option === 'static_banner' ){
        lawyer_landing_page_pro_get_static_banner();
    }elseif( $banner_option === 'slider_banner' ){
        lawyer_landing_page_pro_get_banner_slider();
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_content_start' ) ) :
/**
 * Content Start
*/
function lawyer_landing_page_pro_content_start(){
    
    $home_sections = get_theme_mod( 'sort_home_section', array( 'about', 'practice', 'why', 'service', 'stat', 'portfolio', 'testimonial', 'promotional', 'team', 'faq', 'blog', 'client' ) );
    
    $class = is_404() ? 'error-holder' : 'row' ;
    
    if( ! is_page_template( array( 'templates/template-about.php', 'templates/template-contact.php' ) ) && ! is_singular( 'team' ) && ! is_post_type_archive( array( 'faq', 'portfolio', 'service', 'team', 'testimonial' ) ) && !( is_front_page() && ! is_home() && $home_sections ) ){
    ?>
    <div id="content" class="site-content">
        <div class="container">
            <div class="<?php echo esc_attr( $class ); ?>">
    <?php
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_page_content_image' ) ) :
/**
 * Page Featured Image
*/
function lawyer_landing_page_pro_page_content_image(){
    if( has_post_thumbnail() && get_theme_mod( 'ed_featured_image', '1' ) ){
        echo '<div class="post-thumbnail">';
        the_post_thumbnail( 'lawyer-landing-page-without-sidebar', array( 'itemprop' => 'image' ) );    
        echo '</div>';
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_post_content_image' ) ) :
/**
 * Post Featured Image
*/
function lawyer_landing_page_pro_post_content_image(){
    if( has_post_thumbnail() ){ 
        if( is_single() ){
            if( get_theme_mod( 'ed_featured_image', '1' ) ){
                echo '<div class="post-thumbnail">';
                the_post_thumbnail( 'lawyer-landing-page-without-sidebar', array( 'itemprop' => 'image' )  );
                echo '</div>';
            }
        }else{
            echo '<a href="' . esc_url( get_permalink() ) . '" class="post-thumbnail">';
            the_post_thumbnail( 'lawyer-landing-page-without-sidebar', array( 'itemprop' => 'image' )  );
            echo '</a>';
        }
        
    }        
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_post_entry_header' ) ) :
/**
 * Post Entry Header
*/
function lawyer_landing_page_pro_post_entry_header(){
    ?>
    <header class="entry-header">
		<?php
            if( is_single() ){
                the_title( '<h1 class="entry-title" itemprop="headline">', '</h1>' );
            }else{
                the_title( '<h2 class="entry-title" itemprop="headline"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
            }
            
            if ( 'post' === get_post_type() ){ 
                lawyer_landing_page_pro_get_post_meta(); 
            } 
        ?>
	</header><!-- .entry-header -->
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_social_share' ) ) :
/**
 * Social Sharing
*/
function lawyer_landing_page_pro_social_share(){
    $ed_share = get_theme_mod( 'ed_social_sharing' );
    $ed_float = get_theme_mod( 'ed_social_float' );
    $shares   = get_theme_mod( 'social_share', array( 'facebook', 'twitter', 'linkedin', 'pinterest' ) );
    
    if( $ed_share && ( 'post' === get_post_type() ) && is_single() ){   
    ?>
    <div class="social-share<?php if( $ed_float ) echo esc_attr( ' floating-share' ); ?>">
        <ul class="share-links">
            <?php
            foreach( $shares as $share ){
                lawyer_landing_page_pro_get_social_share( $share );                    
            }
            ?>
        </ul>
    </div>
    <?php
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_post_author' ) ) :
/**
 * Author Bio
*/
function lawyer_landing_page_pro_post_author(){
    if( get_theme_mod( 'ed_bio', '1' ) && get_the_author_meta( 'description' ) && ( 'post' === get_post_type() ) ){
    ?>
    <section class="author">
		<h2 class="title"><?php esc_html_e( 'About Author', 'lawyer-landing-page-pro' ); ?></h2>
		<div class="holder">
			<div class="img-holder"><?php echo get_avatar( get_the_author_meta( 'ID' ), 126 ); ?></div>
			<div class="text-holder">
				<h3 class="name"><?php echo esc_html( get_the_author_meta( 'display_name' ) ); ?></h3>				
				<?php echo wpautop( wp_kses_post( get_the_author_meta( 'description' ) ) ); ?>
			</div>
		</div>
	</section>
    <?php  
    }  
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_related_post' ) ) :
/**
 * Similar/related post
*/
function lawyer_landing_page_pro_related_post(){
    global $post;
    $ed_related_post    = get_theme_mod( 'ed_related_post', '1' );
    $related_post_tax   = get_theme_mod( 'related_taxonomy', 'cat' ); // from customizer
    $related_post_label = get_theme_mod( 'related_post_label', __( 'Related Posts', 'lawyer-landing-page-pro' ) );
    
    if( $ed_related_post ){
        
        $args = array(
            'post_type'             => 'post',
            'post_status'           => 'publish',
            'posts_per_page'        => 6,
            'ignore_sticky_posts'   => true,
            'post__not_in'          => array( $post->ID ),
            'orderby'               => 'rand'
        );
        
        if( $related_post_tax == 'cat' ){
           $cats = get_the_category( $post->ID );
            if( $cats ){
                $c = array();
                foreach( $cats as $cat ){
                    $c[] = $cat->term_id; 
                }
                $args['category__in'] = $c;
                
                $qry = new WP_Query( $args );
                
                if( $qry->have_posts() ){
                ?>
                <section class="similar-posts">
            		<h5><?php echo esc_html( $related_post_label ); ?></h5>
            		<div class="row">
                    <?php 
                    while( $qry->have_posts() ){
                        $qry->the_post();
                        ?>
            			<article class="post">
            				<a href="<?php the_permalink(); ?>" class="post-thumbnail">
                            <?php 
                                if( has_post_thumbnail() ){
                                    the_post_thumbnail( 'lawyer-landing-page-blog', array( 'itemprop' => 'image' )  );    
                                }else{
                                    echo '<img src="' . esc_url( get_template_directory_uri() . '/images/fallback/lawyer-landing-page-blog.jpg' ) . '" itemprop="image" />';
                                } 
                            ?>
                            </a>
            				<header class="entry-header">
            					<h3 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
            				</header>
            			</article>
                        <?php
                    }
                    wp_reset_postdata();                
                    ?>
            		</div>
            	</section>
                <?php
                }
            }
        }elseif( $related_post_tax == 'tag' ){
            $tags = get_the_tags( $post->ID );
            if( $tags ){
                $t = array();
                foreach( $tags as $tag ){
                    $t[] = $tag->term_id;
                }
                $args['tag__in'] = $t;    
            
                $qry = new WP_Query( $args );
                
                if( $qry->have_posts() ){
                ?>
                <section class="similar-posts">
            		<h5><?php echo esc_html( $related_post_label ); ?></h5>
            		<div class="row">
                    <?php 
                    while( $qry->have_posts() ){
                        $qry->the_post();
                        ?>
            			<article class="post">
            				<a href="<?php the_permalink(); ?>" class="post-thumbnail">
                            <?php 
                                if( has_post_thumbnail() ){
                                    the_post_thumbnail( 'lawyer-landing-page-blog', array( 'itemprop' => 'image' ) );    
                                }else{
                                    echo '<img src="' . esc_url( get_template_directory_uri() . '/images/fallback/lawyer-landing-page-blog.jpg' ) . '" itemprop="image" />';
                                } 
                            ?>
                            </a>
            				<header class="entry-header">
            					<h3 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
            				</header>
            			</article>
                        <?php
                    }
                    wp_reset_postdata(); 
                    ?>
            		</div>
            	</section>
                <?php
                }
            }
        }
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_get_comment_section' ) ) :
/**
 * Comment template
 * 
*/
function lawyer_landing_page_pro_get_comment_section(){
    // If comments are open or we have at least one comment, load up the comment template.
	if ( get_theme_mod( 'ed_comments', '1' ) && ( comments_open() || get_comments_number() ) ) :
		comments_template();
	endif;
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_content_end' ) ) :
/**
 * Content End
*/
function lawyer_landing_page_pro_content_end(){
    $home_sections = get_theme_mod( 'sort_home_section', array( 'banner','about', 'practice', 'why', 'service', 'stat', 'portfolio', 'testimonial', 'promotional', 'team', 'faq', 'blog', 'client' ) );
    
    if( ! is_page_template( array( 'templates/template-about.php', 'templates/template-contact.php' ) ) && ! is_singular( 'team' ) && ! is_post_type_archive( array( 'faq', 'portfolio', 'service', 'team', 'testimonial' ) ) && !( is_front_page() && ! is_home() && $home_sections ) ){
    ?>
            </div><!-- .row/not-found -->
        </div><!-- .container -->
    </div><!-- #content -->
    <?php
    }
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_footer_start' ) ) :
/**
 * Footer Start
*/
function lawyer_landing_page_pro_footer_start(){
    ?>
    <footer id="colophon" class="site-footer" role="contentinfo" itemscope itemtype="http://schema.org/WPFooter">
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_footer_top' ) ) :
/**
 * Footer Top
*/
function lawyer_landing_page_pro_footer_top(){    
    if( is_active_sidebar( 'footer-one' ) || is_active_sidebar( 'footer-two' ) || is_active_sidebar( 'footer-three' ) ){
    ?>
    <div class="footer-t">
		<div class="container">
			<div class="row">
				<?php if( is_active_sidebar( 'footer-one' ) ){ ?>
					<div class="column">
					   <?php dynamic_sidebar( 'footer-one' ); ?>	
					</div>
                <?php } ?>
				
                <?php if( is_active_sidebar( 'footer-two' ) ){ ?>
                    <div class="column">
					   <?php dynamic_sidebar( 'footer-two' ); ?>	
					</div>
                <?php } ?>
                
                <?php if( is_active_sidebar( 'footer-three' ) ){ ?>
                    <div class="column">
					   <?php dynamic_sidebar( 'footer-three' ); ?>	
					</div>
                <?php } ?>
			</div>
		</div>
	</div>
    <?php 
    }   
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_footer_bottom' ) ) :
/**
 * Footer Bottom
*/
function lawyer_landing_page_pro_footer_bottom(){
    $copyright = get_theme_mod( 'footer_copyright' );
    $ed_alink  = get_theme_mod( 'ed_author_link' );
    $ed_wplink = get_theme_mod( 'ed_wp_link' );    
    ?>
    <div class="footer-b">
		<div class="container">
			<div class="site-info">
				<span class="copyright">
                <?php
                    if( $copyright ){
                        echo wp_kses_post( lawyer_landing_page_pro_apply_theme_shortcode( $copyright ) );
                    }else{
                        esc_html_e( '&copy; Copyright ', 'lawyer-landing-page-pro' ); 
                        echo date_i18n( esc_html__( 'Y', 'lawyer-landing-page-pro' ) );
                        echo ' <a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html( get_bloginfo( 'name' ) ) . '</a>.';    
                    }
                    if ( function_exists( 'the_privacy_policy_link' ) ) {
                        the_privacy_policy_link();
                    }
                ?>
                </span>
                
                <?php 
                if( ! $ed_alink || ! $ed_wplink ){ ?>
                    <span class="by">
                    <?php 
                        if( ! $ed_alink ) {
                            echo '<a href="' . esc_url( 'http://raratheme.com/wordpress-themes/lawyer-landing-page-pro/' ) .'" rel="author" target="_blank">' . esc_html__( 'Lawyer Landing Page Pro by Rara Theme', 'lawyer-landing-page-pro' ) . '</a>.';
                        }
                        
                        if( ! $ed_wplink ) {
                            printf( esc_html__( ' Powered by %s', 'lawyer-landing-page-pro' ), '<a href="'. esc_url( __( 'https://wordpress.org/', 'lawyer-landing-page-pro' ) ) .'" target="_blank">WordPress</a> .' );                        
                        } ?>
                    </span>
                    <?php 
                } 
                ?>                                
			</div>
		</div>
	</div>
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_footer_end' ) ) :
/**
 * Footer End 
*/
function lawyer_landing_page_pro_footer_end(){
    ?>
    </footer><!-- #colophon -->
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_back_to_top' ) ) :
/**
 * Back to Top
*/
function lawyer_landing_page_pro_back_to_top(){
    ?>
    <div id="rara-top"><i class="fa fa-angle-up"></i></div>
    <?php
}
endif;

if( ! function_exists( 'lawyer_landing_page_pro_page_end' ) ) :
/**
 * Page End
*/
function lawyer_landing_page_pro_page_end(){
    ?>
    </div><!-- #page -->
    <?php
}
endif;