<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://raratheme.com
 * @since      1.0.0
 *
 * @package    Rara_Theme_Toolkit_Pro
 * @subpackage Rara_Theme_Toolkit_Pro/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Rara_Theme_Toolkit_Pro
 * @subpackage Rara_Theme_Toolkit_Pro/public
 * @author     Rara Theme <test@testmail.com>
 */
class Rara_Theme_Toolkit_Pro_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = RTTKPRO_PLUGIN_VERSION;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rara_Theme_Toolkit_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rara_Theme_Toolkit_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/rara-theme-toolkit-pro-public.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name.'lightslider', plugin_dir_url( __FILE__ ). 'css/lightslider.min.css', array(), '1.1.5', 'all' );
		wp_enqueue_style( $this->plugin_name.'lightsidr', plugin_dir_url( __FILE__ ). 'css/jquery.sidr.light.min.css', array(), $this->version, 'all' );


	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Rara_Theme_Toolkit_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Rara_Theme_Toolkit_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		$lightslider = apply_filters('rttk_lightslider_enqueue',true);
		if($lightslider == true)
		{
        	wp_enqueue_script( 'lightslider', plugin_dir_url( __FILE__ ) . 'js/lightslider.min.js', array( 'jquery' ), '1.1.6', true );
        }

        wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/rara-theme-toolkit-pro-public.min.js', array( 'jquery' ), $this->version, true );
		
		$all = apply_filters('rttk_all_enqueue',true);
		if($all == true)
		{
			wp_enqueue_script( 'all', plugin_dir_url( __FILE__ ) . 'js/fontawesome/all.min.js', array( 'jquery' ), '5.3.1', true );
		}

		$shims = apply_filters('rttk_shims_enqueue',true);
		if($shims == true)
		{
			wp_enqueue_script( 'v4-shims', plugin_dir_url( __FILE__ ) . 'js/fontawesome/v4-shims.min.js', array( 'jquery' ), '5.3.1', true );
		}
	}

	function raratheme_toolkit_pro_js_defer_files($tag)
	{
		$rttk_assets = apply_filters('rttk_public_assets_enqueue',true);

		if( is_admin() || $rttk_assets == true ) return $tag;

		$async_files = apply_filters( 'raratheme_toolkit_pro_js_async_files', array(
			plugin_dir_url( __FILE__ ) . 'js/odometer.min.js', 
			plugin_dir_url( __FILE__ ) . 'js/lightslider.min.js',
			plugin_dir_url( __FILE__ ) . 'js/waypoint.min.js',
	        plugin_dir_url( __FILE__ ) . 'js/rara-theme-toolkit-pro-public.min.js',
	        plugin_dir_url( __FILE__ ) . 'js/jquery.magnific-popup.min.js',
	        plugin_dir_url( __FILE__ ) . 'js/fontawesome/all.min.js',
	        plugin_dir_url( __FILE__ ) . 'js/fontawesome/v4-shims.min.js'	
		 ) );
		
		$add_async = false;
		foreach( $async_files as $file ){
			if( strpos( $tag, $file ) !== false ){
				$add_async = true;
				break;
			}
		}

		if( $add_async ) $tag = str_replace( ' src', ' defer="defer" src', $tag );

		return $tag;
}

}
